@@ -4,7 +4,7 @@ import os
 class Configure(config.package.GNUPackage):
   def __init__(self, framework):
     config.package.GNUPackage.__init__(self, framework)
-    self.version         = '2.32.0'
+    self.version         = '3.0.0'
     self.minversion      = '2.14'
     self.versionname     = 'HYPRE_RELEASE_VERSION'
     self.versioninclude  = 'HYPRE_config.h'
@@ -23,23 +23,26 @@ class Configure(config.package.GNUPackage):
     config.package.GNUPackage.setupHelp(self,help)
     import nargs
     help.addArgument('HYPRE', '-with-hypre-gpu-arch=<string>',  nargs.ArgString(None, 0, 'Value passed to hypre\'s --with-gpu-arch= configure option'))
-    help.addArgument('HYPRE', '-download-hypre-openmp', nargs.ArgBool(None, 1, 'Let hypre use OpenMP if available'))    
+    help.addArgument('HYPRE', '-download-hypre-openmp', nargs.ArgBool(None, 1, 'Let hypre use OpenMP if available'))
     return
 
   def setupDependencies(self, framework):
     config.package.GNUPackage.setupDependencies(self, framework)
-    self.openmp        = framework.require('config.packages.openmp',self)
+    self.openmp        = framework.require('config.packages.OpenMP',self)
     self.cxxlibs       = framework.require('config.packages.cxxlibs',self)
     self.blasLapack    = framework.require('config.packages.BlasLapack',self)
     self.mpi           = framework.require('config.packages.MPI',self)
     self.mathlib       = framework.require('config.packages.mathlib',self)
-    self.cuda          = framework.require('config.packages.cuda',self)
-    self.hip           = framework.require('config.packages.hip',self)
-    self.openmp        = framework.require('config.packages.openmp',self)
+    self.cuda          = framework.require('config.packages.CUDA',self)
+    self.hip           = framework.require('config.packages.HIP',self)
+    self.sycl          = framework.require('config.packages.SYCL',self)
+    self.umpire        = framework.require('config.packages.Umpire',self)
+    self.openmp        = framework.require('config.packages.OpenMP',self)
     self.compilerFlags = framework.require('config.compilerFlags', self)
     self.scalar        = framework.require('PETSc.options.scalarTypes',self)
+    self.languages     = framework.require('PETSc.options.languages',self)
     self.deps          = [self.mpi,self.blasLapack,self.cxxlibs,self.mathlib]
-    self.odeps         = [self.cuda,self.hip,self.openmp]
+    self.odeps         = [self.cuda,self.hip,self.openmp,self.umpire]
     if self.setCompilers.isCrayKNL(None,self.log):
       self.installwithbatch = 0
 
@@ -89,6 +92,7 @@ class Configure(config.package.GNUPackage):
     devflags = ''
     hipbuild = False
     cudabuild = False
+    syclbuild = False
     hasharch = 'with-gpu-arch' in args
     if self.hip.found:
       stdflag  = '-std=c++14'
@@ -109,7 +113,7 @@ class Configure(config.package.GNUPackage):
       devflags += ' '.join(self.removeVisibilityFlag(self.getCompilerFlags().split())) + ' ' + self.setCompilers.HIPPPFLAGS + ' ' + self.mpi.includepaths + ' ' + self.headers.toString(self.dinclude)
       self.popLanguage()
     elif self.cuda.found:
-      stdflag   = '-std=c++11'
+      stdflag   = '-std=c++17'
       cudabuild = True
       if not hasattr(self.cuda, 'cudaDir'):
         raise RuntimeError('CUDA directory not detected! Mail configure.log to petsc-maint@mcs.anl.gov.')
@@ -128,16 +132,47 @@ class Configure(config.package.GNUPackage):
       devflags += ' '.join(('','-expt-extended-lambda',stdflag,'-x','cu',''))
       devflags += self.updatePackageCUDAFlags(self.getCompilerFlags()) + ' ' + self.setCompilers.CUDAPPFLAGS + ' ' + self.mpi.includepaths+ ' ' + self.headers.toString(self.dinclude)
       self.popLanguage()
+    elif self.sycl.found:
+      syclbuild = True
+      args.append('--with-sycl')
+      if hasattr(self.sycl, 'targets'):
+        args.append('--with-sycl-target='+self.sycl.targets)
+      if hasattr(self.sycl, 'syclArch'):
+        # e.g., --with-sycl-target-backend="'-device pvc'"
+        args.append('--with-sycl-target-backend="\'-device {dev}\'"'.format(dev=self.sycl.syclArch))
+      self.pushLanguage(self.languages.clanguage) # If with sycl, PETSc's build compiler must be a sycl compiler
+      cucc = self.getCompiler()
+      devflags += ' '.join(self.removeVisibilityFlag(self.getCompilerFlags().split())) + ' ' + self.setCompilers.SYCLPPFLAGS + ' ' + self.mpi.includepaths + ' ' + self.headers.toString(self.dinclude)
+      self.popLanguage()
     elif self.openmp.found and self.argDB['download-hypre-openmp']:
       args.append('--with-openmp')
       self.usesopenmp = 'yes'
 
+    # If building for CUDA or HIP, checks whether Umpire is available or not
+    if (cudabuild or hipbuild):
+      if not hasattr(self, 'umpire') or not self.umpire.found:
+        self.logPrintWarning('Compiling HYPRE with GPU support but without Umpire support (not recommended). For best performance, consider reconfiguring --with-umpire-dir or with --download-umpire')
+        args.append('--without-umpire')
+      else:
+        args.append('--with-umpire')
+        # Include path
+        try:
+          incdir = self.umpire.include[0]
+        except Exception:
+          incdir = os.path.join(self.umpire.installDir,'include')
+        args.append('--with-umpire-include="'+incdir+'"')
+        # Library path and libs
+        libdir = os.path.join(self.umpire.installDir,'lib')
+        args.append('--with-umpire-lib-dirs="'+libdir+'"')
+        args.append('--with-umpire-libs="camp umpire"')
+
     if self.usesopenmp == 'no':
       if hasattr(self,'openmp') and hasattr(self.openmp,'ompflag'):
         args = self.rmValueArgStartsWith(args,['CC','CXX','FC'],self.openmp.ompflag)
 
-    args.append('CUCC="'+cucc+'"')
-    args.append('CUFLAGS="'+devflags+'"')
+    if cucc:
+      args.append('CUCC="'+cucc+'"')
+      args.append('CUFLAGS="'+devflags+'"')
 
     # explicitly tell hypre BLAS/LAPACK mangling since it may not match Fortran mangling
     if self.blasLapack.mangling == 'underscore':
@@ -153,7 +188,7 @@ class Configure(config.package.GNUPackage):
     args.append('--without-superlu')
 
     if self.getDefaultIndexSize() == 64:
-      if cudabuild or hipbuild: # HYPRE 2.23 supports only mixedint configurations with CUDA/HIP
+      if cudabuild or hipbuild or syclbuild: # HYPRE 2.23 supports only mixedint configurations with CUDA/HIP/SYCL
         args.append('--enable-bigint=no --enable-mixedint=yes')
       else:
         args.append('--enable-bigint')
@@ -186,6 +221,7 @@ class Configure(config.package.GNUPackage):
     if 'MSYSTEM' in os.environ and os.environ['MSYSTEM'].endswith('64'):
       args.append('--host=x86_64-linux-gnu')
 
+    self.logPrintBox('hypre examples are available at '+os.path.join(self.packageDir,'examples'))
     return args
 
   def consistencyChecks(self):
