@@ -149,7 +149,7 @@ class Configure(config.base.Configure):
                  'readlink','realpath','usleep','sleep','_sleep',
                  'uname','snprintf','_snprintf','lseek','_lseek','time','fork','stricmp',
                  'strcasecmp','bzero','dlopen','dlsym','dlclose','dlerror',
-                 '_set_output_format','_mkdir','socket','gethostbyname','fpresetsticky',
+                 '_mkdir','socket','gethostbyname','fpresetsticky',
                  'fpsetsticky','__gcov_dump']
     libraries = [(['fpe'],'handle_sigfpes')]
     librariessock = [(['socket','nsl'],'socket')]
@@ -193,13 +193,18 @@ class Configure(config.base.Configure):
         with self.setCompilers.Language('CUDA'):
           fd.write('cudacompiler='+self.setCompilers.getCompiler()+'\n')
           fd.write('cudaflags_extra='+self.setCompilers.getCompilerFlags().strip()+'\n')
-          p = self.framework.require('config.packages.cuda')
+          p = self.framework.require('config.packages.CUDA')
           fd.write('cudalib='+self.libraries.toStringNoDupes(p.lib)+'\n')
           fd.write('cudainclude='+self.headers.toStringNoDupes(p.include)+'\n')
           if hasattr(self.setCompilers,'CUDA_CXX'):
             fd.write('cuda_cxx='+self.setCompilers.CUDA_CXX+'\n')
             fd.write('cuda_cxxflags='+self.setCompilers.CUDA_CXXFLAGS+'\n')
       fd.write('mpiexec='+self.mpi.mpiexec+'\n')
+      if self.python.path:
+        if 'PYTHONPATH' in os.environ:
+          fd.write('PETSCPYTHONPATH='+':'.join(self.python.path)+':'+os.environ['PYTHONPATH']+'\n')
+        else:
+          fd.write('PETSCPYTHONPATH='+':'.join(self.python.path)+'\n')
 
       fd.write('\n')
       fd.write('Name: PETSc\n')
@@ -331,7 +336,9 @@ prepend-path PATH "%s"
     if hasattr(self.compilers, 'FC'):
       if self.framework.argDB['with-fortran-bindings']:
         if not self.fortran.fortranIsF90:
-          raise RuntimeError('Error! Fortran compiler "'+self.compilers.FC+'" does not support F90! PETSc fortran bindings require a F90 compiler')
+          raise RuntimeError('Error! Fortran compiler "'+self.compilers.FC+'" does not support F90! PETSc Fortran bindings require a F90 compiler')
+        if not self.fortran.fortranBoolIsInteroperable:
+          raise RuntimeError('Error! Fortran compiler "'+self.compilers.FC+'" does not have a C-interoperable Bool type! PETSc Fortran bindings require an interoperable Bool')
         self.addDefine('USE_FORTRAN_BINDINGS','1')
         if not self.ftncmdline.have_command_argument:
           raise RuntimeError('Error! Fortran compiler "'+self.compilers.FC+'" does not support F2003 GET_COMMAND_ARGUMENT()!')
@@ -474,8 +481,9 @@ prepend-path PATH "%s"
       self.addMakeMacro('PETSC_SNES_LIB','${PETSC_WITH_EXTERNAL_LIB}')
       self.addMakeMacro('PETSC_TS_LIB','${PETSC_WITH_EXTERNAL_LIB}')
       self.addMakeMacro('PETSC_TAO_LIB','${PETSC_WITH_EXTERNAL_LIB}')
+      self.addMakeMacro('PETSC_ML_LIB','${PETSC_WITH_EXTERNAL_LIB}')
     else:
-      pkgs = ['tao', 'ts', 'snes', 'ksp', 'dm', 'mat', 'vec', 'sys']
+      pkgs = ['ml', 'tao', 'ts', 'snes', 'ksp', 'dm', 'mat', 'vec', 'sys']
       def liblist_basic(libs):
         return [ '-lpetsc'+lib+self.LIB_NAME_SUFFIX for lib in libs]
       def liblist(libs):
@@ -489,13 +497,14 @@ prepend-path PATH "%s"
       self.addMakeMacro('PETSC_SNES_LIB',liblist(pkgs[-6:]))
       self.addMakeMacro('PETSC_TS_LIB',  liblist(pkgs[-7:]))
       self.addMakeMacro('PETSC_TAO_LIB', liblist(pkgs[-8:]))
-    self.addMakeMacro('PETSC_LIB','${PETSC_TAO_LIB}')
+      self.addMakeMacro('PETSC_ML_LIB', liblist(pkgs[-9:]))
+    self.addMakeMacro('PETSC_LIB','${PETSC_ML_LIB}')
     self.addMakeMacro('PETSC_LIB_BASIC',self.petsclib)
 
     if not os.path.exists(os.path.join(self.petscdir.dir,self.arch.arch,'lib')):
       os.makedirs(os.path.join(self.petscdir.dir,self.arch.arch,'lib'))
 
-# add a makefile endtry for display
+    # add a makefile entry for display
     if self.framework.argDB['with-display']:
       self.addMakeMacro('DISPLAY',self.framework.argDB['with-display'])
 
@@ -504,7 +513,12 @@ prepend-path PATH "%s"
 
     if self.framework.argDB['with-tau-perfstubs']:
       self.addDefine('HAVE_TAU_PERFSTUBS',1)
-    return
+
+    if self.python.path:
+      if 'PYTHONPATH' in os.environ:
+        self.addMakeMacro('PETSCPYTHONPATH',':'.join(self.python.path)+':'+os.environ['PYTHONPATH'])
+      else:
+        self.addMakeMacro('PETSCPYTHONPATH',':'.join(self.python.path))
 
   def dumpConfigInfo(self):
     import time
@@ -1369,6 +1383,10 @@ char assert_aligned[(sizeof(struct mystruct)==16)*2-1];
     return
 
   def generateFortranBindings(self):
+    '''Remove any current Fortran bindings from previous ./configure runs because they may not be needed this run'''
+    import shutil
+    dir = os.path.join(self.arch.arch,'ftn')
+    if os.path.isdir(dir): shutil.rmtree(dir)
     if hasattr(self.compilers, 'FC') and self.framework.argDB['with-fortran-bindings']:
       self.logPrintBox('Generating Fortran binding')
       try:
