@@ -47,6 +47,7 @@ struct _DMOps {
   PetscErrorCode (*getlocaltoglobalmapping)(DM);
   PetscErrorCode (*createfieldis)(DM, PetscInt *, char ***, IS **);
   PetscErrorCode (*createcoordinatedm)(DM, DM *);
+  PetscErrorCode (*createcellcoordinatedm)(DM, DM *);
   PetscErrorCode (*createcoordinatefield)(DM, DMField *);
 
   PetscErrorCode (*getcoloring)(DM, ISColoringType, ISColoring *);
@@ -55,6 +56,7 @@ struct _DMOps {
   PetscErrorCode (*createrestriction)(DM, DM, Mat *);
   PetscErrorCode (*createmassmatrix)(DM, DM, Mat *);
   PetscErrorCode (*createmassmatrixlumped)(DM, Vec *, Vec *);
+  PetscErrorCode (*creategradientmatrix)(DM, DM, Mat *);
   PetscErrorCode (*hascreateinjection)(DM, PetscBool *);
   PetscErrorCode (*createinjection)(DM, DM, Mat *);
 
@@ -101,9 +103,9 @@ struct _DMOps {
   PetscErrorCode (*getcompatibility)(DM, DM, PetscBool *, PetscBool *);
 };
 
-PETSC_EXTERN PetscErrorCode DMLocalizeCoordinate_Internal(DM, PetscInt, const PetscScalar[], const PetscScalar[], PetscScalar[]);
-PETSC_EXTERN PetscErrorCode DMLocalizeCoordinateReal_Internal(DM, PetscInt, const PetscReal[], const PetscReal[], PetscReal[]);
-PETSC_EXTERN PetscErrorCode DMLocalizeAddCoordinate_Internal(DM, PetscInt, const PetscScalar[], const PetscScalar[], PetscScalar[]);
+PETSC_INTERN PetscErrorCode DMLocalizeCoordinate_Internal(DM, PetscInt, const PetscScalar[], const PetscScalar[], PetscScalar[]);
+PETSC_INTERN PetscErrorCode DMLocalizeCoordinateReal_Internal(DM, PetscInt, const PetscReal[], const PetscReal[], PetscReal[]);
+PETSC_INTERN PetscErrorCode DMLocalizeAddCoordinate_Internal(DM, PetscInt, const PetscScalar[], const PetscScalar[], PetscScalar[]);
 
 PETSC_INTERN PetscErrorCode DMCountNonCyclicReferences(PetscObject, PetscInt *);
 
@@ -301,9 +303,9 @@ struct _p_DM {
   /* Periodicity */
   PetscReal *Lstart, *L, *maxCell; /* Size of periodic box and max cell size for determining periodicity */
   PetscBool  sparseLocalize;       /* Localize coordinates only for cells near periodic boundary */
-  /* Null spaces -- of course I should make this have a variable number of fields */
-  NullSpaceFn nullspaceConstructors[10];
-  NullSpaceFn nearnullspaceConstructors[10];
+  /* Null spaces */
+  NullSpaceFn *nullspaceConstructors;
+  NullSpaceFn *nearnullspaceConstructors;
   /* Fields are represented by objects */
   PetscInt     Nf;       /* Number of fields defined on the total domain */
   RegionField *fields;   /* Array of discretization fields with regions of validity */
@@ -346,10 +348,10 @@ PETSC_EXTERN PetscLogEvent DM_View;
 PETSC_EXTERN PetscLogEvent DM_AdaptInterpolator;
 PETSC_EXTERN PetscLogEvent DM_ProjectFunction;
 
-PETSC_EXTERN PetscErrorCode DMCreateGlobalVector_Section_Private(DM, Vec *);
-PETSC_EXTERN PetscErrorCode DMCreateLocalVector_Section_Private(DM, Vec *);
+PETSC_INTERN PetscErrorCode DMCreateGlobalVector_Section_Private(DM, Vec *);
+PETSC_INTERN PetscErrorCode DMCreateLocalVector_Section_Private(DM, Vec *);
 
-PETSC_EXTERN PetscErrorCode DMView_GLVis(DM, PetscViewer, PetscErrorCode (*)(DM, PetscViewer));
+PETSC_INTERN PetscErrorCode DMView_GLVis(DM, PetscViewer, PetscErrorCode (*)(DM, PetscViewer));
 
 /*
 
@@ -535,12 +537,12 @@ static inline PetscErrorCode DMGetGlobalFieldOffset_Private(DM dm, PetscInt poin
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PETSC_EXTERN PetscErrorCode DMGetCoordinateDegree_Internal(DM, PetscInt *);
+PETSC_INTERN PetscErrorCode DMGetCoordinateDegree_Internal(DM, PetscInt *);
 PETSC_INTERN PetscErrorCode DMGetLocalBoundingBox_Coordinates(DM, PetscReal[], PetscReal[], PetscInt[], PetscInt[]);
 PETSC_INTERN PetscErrorCode DMGetIsoperiodicPointSF_Internal(DM dm, PetscSF *sf);
 
-PETSC_EXTERN PetscErrorCode DMGetBasisTransformDM_Internal(DM, DM *);
-PETSC_EXTERN PetscErrorCode DMGetBasisTransformVec_Internal(DM, Vec *);
+PETSC_INTERN PetscErrorCode DMGetBasisTransformDM_Internal(DM, DM *);
+PETSC_INTERN PetscErrorCode DMGetBasisTransformVec_Internal(DM, Vec *);
 PETSC_INTERN PetscErrorCode DMConstructBasisTransform_Internal(DM);
 
 PETSC_INTERN PetscErrorCode DMGetLocalBoundingIndices_DMDA(DM, PetscReal[], PetscReal[]);
