@@ -148,7 +148,7 @@ typedef struct _p_PetscObject {
 
 .seealso: `PetscObject`, `PetscObjectDestroy()`
 S*/
-PETSC_EXTERN_TYPEDEF typedef PetscErrorCode(PetscObjectDestroyFn)(PetscObject *obj);
+PETSC_EXTERN_TYPEDEF typedef PetscErrorCode PetscObjectDestroyFn(PetscObject *obj);
 
 PETSC_EXTERN_TYPEDEF typedef PetscObjectDestroyFn *PetscObjectDestroyFunction;
 
@@ -166,7 +166,7 @@ PETSC_EXTERN_TYPEDEF typedef PetscObjectDestroyFn *PetscObjectDestroyFunction;
 
 .seealso: `PetscObject`, `PetscObjectDestroy()`, `PetscViewer`, `PetscObjectView()`
 S*/
-PETSC_EXTERN_TYPEDEF typedef PetscErrorCode(PetscObjectViewFn)(PetscObject obj, PetscViewer v);
+PETSC_EXTERN_TYPEDEF typedef PetscErrorCode PetscObjectViewFn(PetscObject obj, PetscViewer v);
 
 PETSC_EXTERN_TYPEDEF typedef PetscObjectViewFn *PetscObjectViewFunction;
 
@@ -449,14 +449,8 @@ struct PetscAssertPointerImpl {
       #define PETSC_ASSERT_POINTER_IMPL_SPECIALIZATION(T, PETSC_TYPE) \
         template <> \
         struct PetscAssertPointerImpl<T *> { \
-          PETSC_NODISCARD static constexpr PetscDataType type() noexcept \
-          { \
-            return PETSC_TYPE; \
-          } \
-          PETSC_NODISCARD static constexpr const char *string() noexcept \
-          { \
-            return PetscStringize(T); \
-          } \
+          PETSC_NODISCARD static constexpr PetscDataType type() noexcept { return PETSC_TYPE; } \
+          PETSC_NODISCARD static constexpr const char   *string() noexcept { return PetscStringize(T); } \
         }; \
         template <> \
         struct PetscAssertPointerImpl<const T *> : PetscAssertPointerImpl<T *> { }; \
@@ -633,6 +627,11 @@ PETSC_ASSERT_POINTER_IMPL_SPECIALIZATION(PetscComplex, PETSC_COMPLEX);
         (void)(a); \
         (void)(b); \
       } while (0)
+    #define PetscValidLogicalCollectiveIntComm(a, b, arg) \
+      do { \
+        (void)(a); \
+        (void)(b); \
+      } while (0)
     #define PetscValidLogicalCollectiveCount(a, b, arg) \
       do { \
         (void)(a); \
@@ -726,7 +725,7 @@ PETSC_ASSERT_POINTER_IMPL_SPECIALIZATION(PetscComplex, PETSC_COMPLEX);
     #define PetscValidLogicalCollectiveScalar(a, b, arg) \
       do { \
         PetscScalar b0 = (b); \
-        PetscReal   b1[5], b2[5]; \
+        PetscReal   b1[5]; \
         if (PetscIsNanScalar(b0)) { \
           b1[4] = 1; \
         } else { \
@@ -736,13 +735,13 @@ PETSC_ASSERT_POINTER_IMPL_SPECIALIZATION(PetscComplex, PETSC_COMPLEX);
         b1[1] = PetscRealPart(b0); \
         b1[2] = -PetscImaginaryPart(b0); \
         b1[3] = PetscImaginaryPart(b0); \
-        PetscCallMPI(MPIU_Allreduce(b1, b2, 5, MPIU_REAL, MPIU_MAX, PetscObjectComm((PetscObject)(a)))); \
-        PetscCheck(b2[4] > 0 || (PetscEqualReal(-b2[0], b2[1]) && PetscEqualReal(-b2[2], b2[3])), PetscObjectComm((PetscObject)(a)), PETSC_ERR_ARG_WRONG, "Scalar value must be same on all processes, argument # %d", arg); \
+        PetscCallMPI(MPIU_Allreduce(MPI_IN_PLACE, b1, 5, MPIU_REAL, MPIU_MAX, PetscObjectComm((PetscObject)(a)))); \
+        PetscCheck(b1[4] > 0 || (PetscEqualReal(-b1[0], b1[1]) && PetscEqualReal(-b1[2], b1[3])), PetscObjectComm((PetscObject)(a)), PETSC_ERR_ARG_WRONG, "Scalar value must be same on all processes, argument # %d", arg); \
       } while (0)
 
     #define PetscValidLogicalCollectiveReal(a, b, arg) \
       do { \
-        PetscReal b0 = (b), b1[3], b2[3]; \
+        PetscReal b0 = (b), b1[3]; \
         if (PetscIsNanReal(b0)) { \
           b1[2] = 1; \
         } else { \
@@ -750,53 +749,62 @@ PETSC_ASSERT_POINTER_IMPL_SPECIALIZATION(PetscComplex, PETSC_COMPLEX);
         }; \
         b1[0] = -b0; \
         b1[1] = b0; \
-        PetscCallMPI(MPIU_Allreduce(b1, b2, 3, MPIU_REAL, MPIU_MAX, PetscObjectComm((PetscObject)(a)))); \
-        PetscCheck(b2[2] > 0 || PetscEqualReal(-b2[0], b2[1]), PetscObjectComm((PetscObject)(a)), PETSC_ERR_ARG_WRONG, "Real value must be same on all processes, argument # %d", arg); \
+        PetscCallMPI(MPIU_Allreduce(MPI_IN_PLACE, b1, 3, MPIU_REAL, MPIU_MAX, PetscObjectComm((PetscObject)(a)))); \
+        PetscCheck(b1[2] > 0 || PetscEqualReal(-b1[0], b1[1]), PetscObjectComm((PetscObject)(a)), PETSC_ERR_ARG_WRONG, "Real value must be same on all processes, argument # %d", arg); \
       } while (0)
 
     #define PetscValidLogicalCollectiveInt(a, b, arg) \
       do { \
-        PetscInt b0 = (b), b1[2], b2[2]; \
+        PetscInt b0 = (b), b1[2]; \
         b1[0]       = -b0; \
         b1[1]       = b0; \
-        PetscCallMPI(MPIU_Allreduce(b1, b2, 2, MPIU_INT, MPI_MAX, PetscObjectComm((PetscObject)(a)))); \
-        PetscCheck(-b2[0] == b2[1], PetscObjectComm((PetscObject)(a)), PETSC_ERR_ARG_WRONG, "Int value must be same on all processes, argument # %d", arg); \
+        PetscCallMPI(MPIU_Allreduce(MPI_IN_PLACE, b1, 2, MPIU_INT, MPI_MAX, PetscObjectComm((PetscObject)(a)))); \
+        PetscCheck(-b1[0] == b1[1], PetscObjectComm((PetscObject)(a)), PETSC_ERR_ARG_WRONG, "Int value must be same on all processes, argument # %d", arg); \
+      } while (0)
+
+    #define PetscValidLogicalCollectiveIntComm(a, b, arg) \
+      do { \
+        PetscInt b1[2]; \
+        b1[0] = -b; \
+        b1[1] = b; \
+        PetscCallMPI(MPIU_Allreduce(MPI_IN_PLACE, b1, 2, MPIU_INT, MPI_MAX, a)); \
+        PetscCheck(-b1[0] == b1[1], a, PETSC_ERR_ARG_WRONG, "Int value must be same on all processes, argument # %d", arg); \
       } while (0)
 
     #define PetscValidLogicalCollectiveCount(a, b, arg) \
       do { \
-        PetscCount b0 = (b), b1[2], b2[2]; \
+        PetscCount b0 = (b), b1[2]; \
         b1[0]         = -b0; \
         b1[1]         = b0; \
-        PetscCallMPI(MPIU_Allreduce(b1, b2, 2, MPIU_COUNT, MPI_MAX, PetscObjectComm((PetscObject)(a)))); \
-        PetscCheck(-b2[0] == b2[1], PetscObjectComm((PetscObject)(a)), PETSC_ERR_ARG_WRONG, "Int value must be same on all processes, argument # %d", arg); \
+        PetscCallMPI(MPIU_Allreduce(MPI_IN_PLACE, b1, 2, MPIU_COUNT, MPI_MAX, PetscObjectComm((PetscObject)(a)))); \
+        PetscCheck(-b1[0] == b1[1], PetscObjectComm((PetscObject)(a)), PETSC_ERR_ARG_WRONG, "Int value must be same on all processes, argument # %d", arg); \
       } while (0)
 
     #define PetscValidLogicalCollectiveMPIInt(a, b, arg) \
       do { \
-        PetscMPIInt b0 = (b), b1[2], b2[2]; \
+        PetscMPIInt b0 = (b), b1[2]; \
         b1[0]          = -b0; \
         b1[1]          = b0; \
-        PetscCallMPI(MPIU_Allreduce(b1, b2, 2, MPI_INT, MPI_MAX, PetscObjectComm((PetscObject)(a)))); \
-        PetscCheck(-b2[0] == b2[1], PetscObjectComm((PetscObject)(a)), PETSC_ERR_ARG_WRONG, "PetscMPIInt value must be same on all processes, argument # %d", arg); \
+        PetscCallMPI(MPIU_Allreduce(MPI_IN_PLACE, b1, 2, MPI_INT, MPI_MAX, PetscObjectComm((PetscObject)(a)))); \
+        PetscCheck(-b1[0] == b1[1], PetscObjectComm((PetscObject)(a)), PETSC_ERR_ARG_WRONG, "PetscMPIInt value must be same on all processes, argument # %d", arg); \
       } while (0)
 
     #define PetscValidLogicalCollectiveBool(a, b, arg) \
       do { \
-        PetscMPIInt b0 = (PetscMPIInt)(b), b1[2], b2[2]; \
-        b1[0]          = -b0; \
-        b1[1]          = b0; \
-        PetscCallMPI(MPIU_Allreduce(b1, b2, 2, MPI_INT, MPI_MAX, PetscObjectComm((PetscObject)(a)))); \
-        PetscCheck(-b2[0] == b2[1], PetscObjectComm((PetscObject)(a)), PETSC_ERR_ARG_WRONG, "Bool value must be same on all processes, argument # %d", arg); \
+        PetscBool b0 = (PetscBool)(b), b1[2]; \
+        b1[0]        = !b0; \
+        b1[1]        = b0; \
+        PetscCallMPI(MPIU_Allreduce(MPI_IN_PLACE, b1, 2, MPIU_BOOL, MPI_LAND, PetscObjectComm((PetscObject)(a)))); \
+        PetscCheck(!b1[0] == b1[1], PetscObjectComm((PetscObject)(a)), PETSC_ERR_ARG_WRONG, "Bool value must be same on all processes, argument # %d", arg); \
       } while (0)
 
     #define PetscValidLogicalCollectiveEnum(a, b, arg) \
       do { \
-        PetscMPIInt b0 = (PetscMPIInt)(b), b1[2], b2[2]; \
+        PetscMPIInt b0 = (PetscMPIInt)(b), b1[2]; \
         b1[0]          = -b0; \
         b1[1]          = b0; \
-        PetscCallMPI(MPIU_Allreduce(b1, b2, 2, MPI_INT, MPI_MAX, PetscObjectComm((PetscObject)(a)))); \
-        PetscCheck(-b2[0] == b2[1], PetscObjectComm((PetscObject)(a)), PETSC_ERR_ARG_WRONG, "Enum value must be same on all processes, argument # %d", arg); \
+        PetscCallMPI(MPIU_Allreduce(MPI_IN_PLACE, b1, 2, MPI_INT, MPI_MAX, PetscObjectComm((PetscObject)(a)))); \
+        PetscCheck(-b1[0] == b1[1], PetscObjectComm((PetscObject)(a)), PETSC_ERR_ARG_WRONG, "Enum value must be same on all processes, argument # %d", arg); \
       } while (0)
 
     #define PetscCheckSorted(n, idx) \
@@ -1025,7 +1033,7 @@ M*/
 
 .seealso: `PetscObjectStateGet()`, `PetscObject`
 M*/
-#define PetscObjectStateIncrease(obj) ((obj)->state++, PETSC_SUCCESS)
+#define PetscObjectStateIncrease(obj) ((PetscErrorCode)((obj)->state++, PETSC_SUCCESS))
 
 PETSC_EXTERN PetscErrorCode PetscObjectStateGet(PetscObject, PetscObjectState *);
 PETSC_EXTERN PetscErrorCode PetscObjectStateSet(PetscObject, PetscObjectState);
@@ -1093,7 +1101,7 @@ M*/
           `PetscObjectComposedDataGetIntstar()`, `PetscObjectComposedDataSetIntstar()`, `PetscObject`,
           `PetscObjectCompose()`, `PetscObjectQuery()`
 M*/
-#define PetscObjectComposedDataGetInt(obj, id, data, flag) (((obj)->intcomposedstate ? (data = (obj)->intcomposeddata[id], flag = (PetscBool)((obj)->intcomposedstate[id] == (obj)->state)) : (flag = PETSC_FALSE)), PETSC_SUCCESS)
+#define PetscObjectComposedDataGetInt(obj, id, data, flag) ((PetscErrorCode)(((obj)->intcomposedstate ? (data = (obj)->intcomposeddata[id], flag = (PetscBool)((obj)->intcomposedstate[id] == (obj)->state)) : (flag = PETSC_FALSE)), PETSC_SUCCESS))
 
 /*MC
    PetscObjectComposedDataSetIntstar - attach `PetscInt` array data to a `PetscObject` that may be accessed later with `PetscObjectComposedDataGetIntstar()`
@@ -1206,7 +1214,7 @@ M*/
           `PetscObjectComposedDataSetIntstar()`, `PetscObjectComposedDataGetInt()`, `PetscObject`,
           `PetscObjectCompose()`, `PetscObjectQuery()`
 M*/
-#define PetscObjectComposedDataGetReal(obj, id, data, flag) (((obj)->realcomposedstate ? (data = (obj)->realcomposeddata[id], flag = (PetscBool)((obj)->realcomposedstate[id] == (obj)->state)) : (flag = PETSC_FALSE)), PETSC_SUCCESS)
+#define PetscObjectComposedDataGetReal(obj, id, data, flag) ((PetscErrorCode)(((obj)->realcomposedstate ? (data = (obj)->realcomposeddata[id], flag = (PetscBool)((obj)->realcomposedstate[id] == (obj)->state)) : (flag = PETSC_FALSE)), PETSC_SUCCESS))
 
 /*MC
    PetscObjectComposedDataSetRealstar - attach `PetscReal` array data to a `PetscObject` that may be retrieved with `PetscObjectComposedDataGetRealstar()`
@@ -1396,16 +1404,16 @@ M*/
   #define PetscObjectComposedDataGetScalarstar(obj, id, data, flag) PetscObjectComposedDataGetRealstar(obj, id, data, flag)
 #endif
 
-PETSC_EXTERN PetscMPIInt Petsc_Counter_keyval;
-PETSC_EXTERN PetscMPIInt Petsc_InnerComm_keyval;
-PETSC_EXTERN PetscMPIInt Petsc_OuterComm_keyval;
-PETSC_EXTERN PetscMPIInt Petsc_Seq_keyval;
-PETSC_EXTERN PetscMPIInt Petsc_ShmComm_keyval;
+PETSC_INTERN PetscMPIInt Petsc_Counter_keyval;
+PETSC_INTERN PetscMPIInt Petsc_InnerComm_keyval;
+PETSC_INTERN PetscMPIInt Petsc_OuterComm_keyval;
+PETSC_INTERN PetscMPIInt Petsc_Seq_keyval;
+PETSC_INTERN PetscMPIInt Petsc_ShmComm_keyval;
 PETSC_EXTERN PetscMPIInt Petsc_CreationIdx_keyval;
-PETSC_EXTERN PetscMPIInt Petsc_Garbage_HMap_keyval;
+PETSC_INTERN PetscMPIInt Petsc_Garbage_HMap_keyval;
 
-PETSC_EXTERN PetscMPIInt Petsc_SharedWD_keyval;
-PETSC_EXTERN PetscMPIInt Petsc_SharedTmp_keyval;
+PETSC_INTERN PetscMPIInt Petsc_SharedWD_keyval;
+PETSC_INTERN PetscMPIInt Petsc_SharedTmp_keyval;
 
 struct PetscCommStash {
   struct PetscCommStash *next;
@@ -1605,61 +1613,3 @@ struct _n_PetscObjectList {
   PetscObject     obj;
   PetscObjectList next;
 };
-
-/*MC
-   PeOP - indicates an argument to a PETSc function is optional and one can pass `NULL` instead. This is used by the Fortran API generator
-
-   Level: developer
-
-   Example:
-.vb
-   PetscErrorCode XXXX(Vec v, PeOp PetscObject obj, PeOp PetscInt *idx, PeOp PetscInt *array[])
-.ve
-
-   Notes:
-   This is not part of the PETSc public API and should only be used in PETSc source code.
-
-   Put this in the function declaration in front of each variable that is optional
-
-   Developer Note:
-   Shortened form of PETSc optional
-
-.seealso: `PeNS`, `PeNSS`, `PeCtx`, `PetscInitialize()`
-M*/
-#define PeOp
-
-/*MC
-   PeNS - indicates a function that does not use the PETSc standard arguments which make it easy to generate automatic language stubs for other languages
-
-   Level: developer
-
-   Notes:
-   This is not part of the PETSc public API and should only be used in PETSc source code.
-
-   Put this at the end of the function declaration closing parenthesis
-
-   Developer Note:
-   Shortened form of PETSc non-standard
-
-.seealso: `PeOp`, `PeNSS`, `PeCtx`, `PetscInitialize()`
-M*/
-#define PeNS
-
-/*MC
-   PeNSS - indicates a function that needs a special treatment in the C-side stub when generating the binding for other languages
-
-   Level: developer
-
-   Notes:
-   This is not part of the PETSc public API and should only be used in PETSc source code.
-
-   Put this at the end of the function declaration closing parenthesis
-
-   It is similar to PeNS; in Fortran it will generate the Fortran interface definition automatically but not the C stub, which should be added manually under the appropriate `ftn-custom` directory
-
-   Developer Note:
-   Shortened form of PETSc non-standard stub
-
-.seealso: `PeOp`, `PeNS`, `PeCtx`, `PetscInitialize()`
-M*/
-#define PeNSS
