@@ -47,6 +47,7 @@
   #define PetscErfReal(a)         erff(a)
   #define PetscCeilReal(a)        ceilf(a)
   #define PetscFloorReal(a)       floorf(a)
+  #define PetscRintReal(a)        rintf(a)
   #define PetscFmodReal(a, b)     fmodf(a, b)
   #define PetscCopysignReal(a, b) copysignf(a, b)
   #define PetscTGamma(a)          tgammaf(a)
@@ -81,6 +82,7 @@
   #define PetscErfReal(a)         erf(a)
   #define PetscCeilReal(a)        ceil(a)
   #define PetscFloorReal(a)       floor(a)
+  #define PetscRintReal(a)        rint(a)
   #define PetscFmodReal(a, b)     fmod(a, b)
   #define PetscCopysignReal(a, b) copysign(a, b)
   #define PetscTGamma(a)          tgamma(a)
@@ -115,6 +117,7 @@
   #define PetscErfReal(a)         erfq(a)
   #define PetscCeilReal(a)        ceilq(a)
   #define PetscFloorReal(a)       floorq(a)
+  #define PetscRintReal(a)        rintq(a)
   #define PetscFmodReal(a, b)     fmodq(a, b)
   #define PetscCopysignReal(a, b) copysignq(a, b)
   #define PetscTGamma(a)          tgammaq(a)
@@ -149,6 +152,7 @@
   #define PetscErfReal(a)         erff(a)
   #define PetscCeilReal(a)        ceilf(a)
   #define PetscFloorReal(a)       floorf(a)
+  #define PetscRintReal(a)        rintf(a)
   #define PetscFmodReal(a, b)     fmodf(a, b)
   #define PetscCopysignReal(a, b) copysignf(a, b)
   #define PetscTGamma(a)          tgammaf(a)
@@ -697,7 +701,7 @@ M*/
 #define PetscAbsInt(a) (((a) < 0) ? (-(a)) : (a))
 
 /*MC
-   PetscAbsReal - Returns the absolute value of an real number
+   PetscAbsReal - Returns the absolute value of a real number
 
    Synopsis:
    #include <petscmath.h>
@@ -708,7 +712,7 @@ M*/
 
    Level: beginner
 
-.seealso: `PetscMax()`, `PetscMin()`, `PetscAbsInt()`, `PetscSqr()`
+.seealso: `PetscReal`, `PetscMax()`, `PetscMin()`, `PetscAbsInt()`, `PetscSqr()`
 M*/
 #if defined(PETSC_USE_REAL_SINGLE)
   #define PetscAbsReal(a) fabsf(a)
@@ -741,6 +745,33 @@ M*/
 M*/
 #define PetscSqr(a) ((a) * (a))
 
+/*MC
+   PetscRealConstant - a compile time macro that ensures a given constant real number is properly represented in the configured
+   precision of `PetscReal` be it half, single, double or 128-bit representation
+
+   Synopsis:
+   #include <petscmath.h>
+   PetscReal PetscRealConstant(real_number)
+
+   Not Collective
+
+   Input Parameter:
+.   v1 - the real number, for example 1.5
+
+   Level: beginner
+
+   Note:
+   For example, if PETSc is configured with `--with-precision=__float128` and one writes
+.vb
+   PetscReal d = 1.5;
+.ve
+   the result is 1.5 in double precision extended to 128 bit representation, meaning it is very far from the correct value. Hence, one should write
+.vb
+   PetscReal d = PetscRealConstant(1.5);
+.ve
+
+.seealso: `PetscReal`
+M*/
 #if defined(PETSC_USE_REAL_SINGLE)
   #define PetscRealConstant(constant) constant##F
 #elif defined(PETSC_USE_REAL_DOUBLE)
@@ -754,9 +785,107 @@ M*/
 /*
      Basic constants
 */
+/*MC
+  PETSC_PI - the value of $ \pi$ to the correct precision of `PetscReal`.
+
+  Level: beginner
+
+.seealso: `PetscReal`, `PETSC_PHI`, `PETSC_SQRT2`
+M*/
+
+/*MC
+  PETSC_PHI - the value of $ \phi$, the Golden Ratio, to the correct precision of `PetscReal`.
+
+  Level: beginner
+
+.seealso: `PetscReal`, `PETSC_PI`, `PETSC_SQRT2`
+M*/
+
+/*MC
+  PETSC_SQRT2 - the value of $ \sqrt{2} $ to the correct precision of `PetscReal`.
+
+  Level: beginner
+
+.seealso: `PetscReal`, `PETSC_PI`, `PETSC_PHI`
+M*/
+
+/*MC
+  PETSC_E - the value of Euler's constant $ e $ to the correct precision of `PetscReal`.
+
+  Level: beginner
+
+.seealso: `PetscReal`, `PETSC_PI`, `PETSC_PHI`
+M*/
+
 #define PETSC_PI    PetscRealConstant(3.1415926535897932384626433832795029)
 #define PETSC_PHI   PetscRealConstant(1.6180339887498948482045868343656381)
 #define PETSC_SQRT2 PetscRealConstant(1.4142135623730950488016887242096981)
+#define PETSC_E     PetscRealConstant(2.7182818284590452353602874713526625)
+
+/*MC
+  PETSC_MAX_REAL - the largest real value that can be stored in a `PetscReal`
+
+  Level: beginner
+
+.seealso: `PETSC_MIN_REAL`, `PETSC_REAL_MIN`, `PETSC_MACHINE_EPSILON`, `PETSC_SQRT_MACHINE_EPSILON`, `PETSC_SMALL`
+M*/
+
+/*MC
+  PETSC_MIN_REAL - the smallest real value that can be stored in a `PetscReal`, generally this is - `PETSC_MAX_REAL`
+
+  Level: beginner
+
+.seealso `PETSC_MAX_REAL`, `PETSC_REAL_MIN`, `PETSC_MACHINE_EPSILON`, `PETSC_SQRT_MACHINE_EPSILON`, `PETSC_SMALL`
+M*/
+
+/*MC
+  PETSC_REAL_MIN - the smallest positive normalized real value that can be stored in a `PetscReal`.
+
+  Level: beginner
+
+  Note:
+  See <https://en.wikipedia.org/wiki/Subnormal_number> for a discussion of normalized and subnormal floating point numbers
+
+  Developer Note:
+  The naming is confusing as there is both a `PETSC_REAL_MIN` and `PETSC_MIN_REAL` with different meanings.
+
+.seealso `PETSC_MAX_REAL`, `PETSC_MIN_REAL`, `PETSC_MACHINE_EPSILON`, `PETSC_SQRT_MACHINE_EPSILON`, `PETSC_SMALL`
+M*/
+
+/*MC
+  PETSC_MACHINE_EPSILON - the machine epsilon for the precision of `PetscReal`
+
+  Level: beginner
+
+  Note:
+  See <https://en.wikipedia.org/wiki/Machine_epsilon>
+
+.seealso `PETSC_MAX_REAL`, `PETSC_MIN_REAL`, `PETSC_REAL_MIN`, `PETSC_SQRT_MACHINE_EPSILON`, `PETSC_SMALL`
+M*/
+
+/*MC
+  PETSC_SQRT_MACHINE_EPSILON - the square root of the machine epsilon for the precision of `PetscReal`
+
+  Level: beginner
+
+  Note:
+  See `PETSC_MACHINE_EPSILON`
+
+.seealso `PETSC_MAX_REAL`, `PETSC_MIN_REAL`, `PETSC_REAL_MIN`, `PETSC_MACHINE_EPSILON`, `PETSC_SMALL`
+M*/
+
+/*MC
+  PETSC_SMALL - an arbitrary "small" number which depends on the precision of `PetscReal` used in some PETSc examples
+  and in `PetscApproximateLTE()` and `PetscApproximateGTE()` to determine if a computation was successful.
+
+  Level: beginner
+
+  Note:
+  See `PETSC_MACHINE_EPSILON`
+
+.seealso `PetscApproximateLTE()`, `PetscApproximateGTE()`, `PETSC_MAX_REAL`, `PETSC_MIN_REAL`, `PETSC_REAL_MIN`, `PETSC_MACHINE_EPSILON`,
+         `PETSC_SQRT_MACHINE_EPSILON`
+M*/
 
 #if defined(PETSC_USE_REAL_SINGLE)
   #define PETSC_MAX_REAL             3.40282346638528860e+38F
@@ -897,6 +1026,10 @@ struct /* __attribute__((packed, aligned(alignof(PetscInt *)))) */ petsc_mpiu_2i
   PetscInt a;
   PetscInt b;
 };
+struct __attribute__((packed)) petsc_mpiu_int_mpiint {
+  PetscInt    a;
+  PetscMPIInt b;
+};
 /*
  static_assert(sizeof(struct petsc_mpiu_2int) == 2 * sizeof(PetscInt), "");
  static_assert(alignof(struct petsc_mpiu_2int) == alignof(PetscInt *), "");
@@ -907,8 +1040,10 @@ struct /* __attribute__((packed, aligned(alignof(PetscInt *)))) */ petsc_mpiu_2i
  pass! So we just comment it out...
 */
 PETSC_EXTERN MPI_Datatype MPIU_2INT /* PETSC_ATTRIBUTE_MPI_TYPE_TAG_LAYOUT_COMPATIBLE(struct petsc_mpiu_2int) */;
+PETSC_EXTERN MPI_Datatype MPIU_INT_MPIINT /* PETSC_ATTRIBUTE_MPI_TYPE_TAG_LAYOUT_COMPATIBLE(struct petsc_mpiu_int_mpiint) */;
 #else
-  #define MPIU_2INT MPI_2INT
+  #define MPIU_2INT       MPI_2INT
+  #define MPIU_INT_MPIINT MPI_2INT
 #endif
 PETSC_EXTERN MPI_Datatype MPI_4INT;
 PETSC_EXTERN MPI_Datatype MPIU_4INT;
@@ -1037,13 +1172,9 @@ M*/
 M*/
 #define PetscApproximateGTE(x, b) ((x) >= (PetscRealConstant(b) - PETSC_SMALL))
 
-/*MC
+/*@C
    PetscCeilInt - Returns the ceiling of the quotation of two positive integers
 
-   Synopsis:
-   #include <petscmath.h>
-   PetscInt PetscCeilInt(PetscInt x,PetscInt y)
-
    Not Collective
 
    Input Parameters:
@@ -1057,10 +1188,34 @@ M*/
   PetscInt n = PetscCeilInt(10, 3); // n has the value of 4
 .ve
 
-.seealso: `PetscMax()`, `PetscMin()`, `PetscAbsInt()`, `PetscAbsReal()`, `PetscApproximateLTE()`
-M*/
-#define PetscCeilInt(x, y) ((((PetscInt)(x)) / ((PetscInt)(y))) + ((((PetscInt)(x)) % ((PetscInt)(y))) ? 1 : 0))
+.seealso: `PetscCeilInt64()`, `PetscMax()`, `PetscMin()`, `PetscAbsInt()`, `PetscAbsReal()`, `PetscApproximateLTE()`
+@*/
+static inline PetscInt PetscCeilInt(PetscInt x, PetscInt y)
+{
+  return x / y + (x % y ? 1 : 0);
+}
 
-#define PetscCeilInt64(x, y) ((((PetscInt64)(x)) / ((PetscInt64)(y))) + ((((PetscInt64)(x)) % ((PetscInt64)(y))) ? 1 : 0))
+/*@C
+   PetscCeilInt64 - Returns the ceiling of the quotation of two positive integers
+
+   Not Collective
+
+   Input Parameters:
++   x - the numerator
+-   y - the denominator
+
+   Level: advanced
+
+  Example\:
+.vb
+  PetscInt64 n = PetscCeilInt64(10, 3); // n has the value of 4
+.ve
+
+.seealso: `PetscCeilInt()`, `PetscMax()`, `PetscMin()`, `PetscAbsInt()`, `PetscAbsReal()`, `PetscApproximateLTE()`
+@*/
+static inline PetscInt64 PetscCeilInt64(PetscInt64 x, PetscInt64 y)
+{
+  return x / y + (x % y ? 1 : 0);
+}
 
 PETSC_EXTERN PetscErrorCode PetscLinearRegression(PetscInt, const PetscReal[], const PetscReal[], PetscReal *, PetscReal *);
