@@ -2,19 +2,21 @@
 #define PETSCVERSION_H
 #include <petscconf.h>
 
+/* MANSEC = Sys */
+
 #define PETSC_VERSION_RELEASE    1
 #define PETSC_VERSION_MAJOR      3
-#define PETSC_VERSION_MINOR      23
-#define PETSC_VERSION_SUBMINOR   4
-#define PETSC_RELEASE_DATE       "Mar 28, 2025"
-#define PETSC_VERSION_DATE       "Jun 30, 2025"
+#define PETSC_VERSION_MINOR      24
+#define PETSC_VERSION_SUBMINOR   0
+#define PETSC_RELEASE_DATE       "Sep 29, 2025"
+#define PETSC_VERSION_DATE       "Sep 22, 2025"
 
 #if !defined(PETSC_VERSION_GIT)
-#define PETSC_VERSION_GIT        "v3.23.4"
+#define PETSC_VERSION_GIT        "v3.23.6-648-g57746368439"
 #endif
 
 #if !defined(PETSC_VERSION_DATE_GIT)
-#define PETSC_VERSION_DATE_GIT   "2025-06-30 14:29:56 -0500"
+#define PETSC_VERSION_DATE_GIT   "2025-09-22 13:56:13 -0500"
 #endif
 
 #define PETSC_VERSION_EQ(MAJOR,MINOR,SUBMINOR) \
