@@ -225,9 +225,8 @@ static PetscErrorCode DMCreateFieldDecomposition_DA(DM dm, PetscInt *len, char *
   }
   if (namelist) {
     PetscCall(PetscMalloc1(dof, namelist));
-    if (dd->fieldname) {
-      for (i = 0; i < dof; i++) PetscCall(PetscStrallocpy(dd->fieldname[i], &(*namelist)[i]));
-    } else SETERRQ(PETSC_COMM_SELF, PETSC_ERR_SUP, "Currently DMDA must have fieldnames");
+    PetscCheck(dd->fieldname, PETSC_COMM_SELF, PETSC_ERR_SUP, "Currently DMDA must have fieldnames");
+    for (i = 0; i < dof; i++) PetscCall(PetscStrallocpy(dd->fieldname[i], &(*namelist)[i]));
   }
   if (dmlist) {
     DM da;
@@ -424,6 +423,7 @@ PETSC_EXTERN PetscErrorCode DMCreate_DA(DM da)
   da->ops->clone                     = DMClone_DA;
   da->ops->load                      = DMLoad_DA;
   da->ops->createcoordinatedm        = DMCreateCoordinateDM_DA;
+  da->ops->createcellcoordinatedm    = NULL;
   da->ops->createsubdm               = DMCreateSubDM_DA;
   da->ops->createfielddecomposition  = DMCreateFieldDecomposition_DA;
   da->ops->createdomaindecomposition = DMCreateDomainDecomposition_DA;
