@@ -345,7 +345,7 @@ static PetscErrorCode DMPlexCreatePartitionerGraph_ViaMat(DM dm, PetscInt height
   /* Interpolated and parallel case */
 
   /* numbering */
-  PetscCall(DMGetPointSF(dm, &sfPoint));
+  PetscCall(DMGetIsoperiodicPointSF_Internal(dm, &sfPoint));
   PetscCall(DMPlexGetHeightStratum(dm, height, &cStart, &cEnd));
   PetscCall(DMPlexGetHeightStratum(dm, height + 1, &fStart, &fEnd));
   PetscCall(DMPlexCreateNumbering_Plex(dm, cStart, cEnd, 0, &N, sfPoint, &cis));
@@ -806,9 +806,8 @@ PetscErrorCode PetscPartitionerDMPlexPartition(PetscPartitioner part, DM dm, Pet
       PetscCall(DMPlexGetHeightStratum(dm, part->height, &pStart, &pEnd));
       PetscCall(PetscSectionCreate(PETSC_COMM_SELF, &vertSection));
       PetscCall(PetscSectionSetChart(vertSection, 0, numVertices));
-      if (globalNumbering) {
-        PetscCall(ISGetIndices(globalNumbering, &gid));
-      } else gid = NULL;
+      if (globalNumbering) PetscCall(ISGetIndices(globalNumbering, &gid));
+      else gid = NULL;
       for (p = pStart, v = 0; p < pEnd; ++p) {
         PetscInt dof = 1;
 
@@ -1330,7 +1329,7 @@ PetscErrorCode DMPlexPartitionLabelInvert(DM dm, DMLabel rootLabel, PetscSF proc
       counter += rcounts[r];
     }
     if (counter > PETSC_MPI_INT_MAX) locOverflow = PETSC_TRUE;
-    PetscCallMPI(MPIU_Allreduce(&locOverflow, &mpiOverflow, 1, MPIU_BOOL, MPI_LOR, comm));
+    PetscCallMPI(MPIU_Allreduce(&locOverflow, &mpiOverflow, 1, MPI_C_BOOL, MPI_LOR, comm));
     if (!mpiOverflow) {
       PetscCall(PetscInfo(dm, "Using MPI_Alltoallv() for mesh distribution\n"));
       PetscCall(PetscIntCast(counter, &leafSize));
