@@ -133,7 +133,7 @@ static PetscErrorCode DMPlexComputeAnchorAdjacencies(DM dm, PetscBool useCone, P
           for (nd = 0; nd < qAdjDof - qAdjCDof; ++nd) adj[aOff++] = (qAdjOff < 0 ? -(qAdjOff + 1) : qAdjOff) + nd;
         }
       }
-      PetscCall(PetscSortRemoveDupsInt(&aDof, &adj[aOffOrig]));
+      PetscCall(PetscSortRemoveDupsInt(&aDof, PetscSafePointerPlusOffset(adj, aOffOrig)));
       PetscCall(PetscSectionSetDof(adjSec, p, aDof));
     }
     *anchorAdj = adj;
@@ -151,10 +151,45 @@ static PetscErrorCode DMPlexComputeAnchorAdjacencies(DM dm, PetscBool useCone, P
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
+// Determine if any of the local adjancencies match a leaf and root of the pointSF.
+// When using isoperiodic boundary conditions, it is possible for periodic (leaf) and donor (root) pairs to be on the same rank.
+// This check is done to ensure the adjancency in these cases is only counted for one of the mesh points rather than both.
+static inline PetscErrorCode AdjancencyContainsLeafRootPair(PetscInt num_pairs, const PetscInt leaves[], const PetscInt roots[], PetscInt numAdj, const PetscInt tmpAdj[], PetscInt *num_leaves_found, PetscInt leaves_found[])
+{
+  PetscInt root_index = -1, leaf_, num_roots_found = 0;
+
+  PetscFunctionBeginUser;
+  *num_leaves_found = 0;
+  for (PetscInt q = 0; q < numAdj; q++) {
+    const PetscInt padj = tmpAdj[q];
+    PetscCall(PetscFindInt(padj, num_pairs, roots, &root_index));
+    if (root_index >= 0) {
+      leaves_found[num_roots_found] = root_index; // Initially use leaves_found to store pair indices
+      num_roots_found++;
+      break;
+    }
+  }
+  if (num_roots_found == 0) PetscFunctionReturn(PETSC_SUCCESS);
+
+  for (PetscInt i = 0; i < num_roots_found; i++) {
+    leaf_ = leaves[root_index];
+    for (PetscInt q = 0; q < numAdj; q++) {
+      if (tmpAdj[q] == leaf_) {
+        leaves_found[*num_leaves_found] = leaf_;
+        (*num_leaves_found)++;
+        continue;
+      }
+    }
+  }
+
+  PetscCall(PetscIntSortSemiOrdered(*num_leaves_found, leaves_found));
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+
 static PetscErrorCode DMPlexCreateAdjacencySection_Static(DM dm, PetscInt bs, PetscSF sfDof, PetscBool useCone, PetscBool useClosure, PetscBool useAnchors, PetscSection *sA, PetscInt **colIdx)
 {
   MPI_Comm           comm;
-  PetscMPIInt        size;
+  PetscMPIInt        myrank;
   PetscBool          doCommLocal, doComm, debug = PETSC_FALSE;
   PetscSF            sf, sfAdj;
   PetscSection       section, sectionGlobal, leafSectionAdj, rootSectionAdj, sectionAdj, anchorSectionAdj;
@@ -162,20 +197,20 @@ static PetscErrorCode DMPlexCreateAdjacencySection_Static(DM dm, PetscInt bs, Pe
   const PetscInt    *leaves;
   const PetscSFNode *remotes;
   PetscInt           dim, pStart, pEnd, numDof, globalOffStart, globalOffEnd, numCols;
-  PetscInt          *tmpAdj = NULL, *adj, *rootAdj, *anchorAdj = NULL, *cols, *remoteOffsets;
-  PetscInt           adjSize;
+  PetscInt          *tmpAdj = NULL, *adj, *rootAdj, *anchorAdj = NULL, *cols, *remoteOffsets, *rootsMyRankPair = NULL, *leavesMyRankPair = NULL;
+  PetscInt           adjSize, numMyRankPair = 0;
 
   PetscFunctionBegin;
   PetscCall(PetscObjectGetComm((PetscObject)dm, &comm));
   PetscCall(PetscOptionsGetBool(NULL, NULL, "-dm_view_preallocation", &debug, NULL));
-  PetscCallMPI(MPI_Comm_size(comm, &size));
+  PetscCallMPI(MPI_Comm_rank(comm, &myrank));
   PetscCall(DMGetDimension(dm, &dim));
-  PetscCall(DMGetPointSF(dm, &sf));
+  PetscCall(DMGetIsoperiodicPointSF_Internal(dm, &sf));
   PetscCall(DMGetLocalSection(dm, &section));
   PetscCall(DMGetGlobalSection(dm, &sectionGlobal));
   PetscCall(PetscSFGetGraph(sf, &nroots, NULL, NULL, NULL));
-  doCommLocal = (size > 1) && (nroots >= 0) ? PETSC_TRUE : PETSC_FALSE;
-  PetscCall(MPIU_Allreduce(&doCommLocal, &doComm, 1, MPIU_BOOL, MPI_LAND, comm));
+  doCommLocal = nroots >= 0 ? PETSC_TRUE : PETSC_FALSE;
+  PetscCallMPI(MPIU_Allreduce(&doCommLocal, &doComm, 1, MPI_C_BOOL, MPI_LAND, comm));
   /* Create section for dof adjacency (dof ==> # adj dof) */
   PetscCall(PetscSectionGetChart(section, &pStart, &pEnd));
   PetscCall(PetscSectionGetStorageSize(section, &numDof));
@@ -183,8 +218,23 @@ static PetscErrorCode DMPlexCreateAdjacencySection_Static(DM dm, PetscInt bs, Pe
   PetscCall(PetscSectionSetChart(leafSectionAdj, 0, numDof));
   PetscCall(PetscSectionCreate(comm, &rootSectionAdj));
   PetscCall(PetscSectionSetChart(rootSectionAdj, 0, numDof));
-  /*   Fill in the ghost dofs on the interface */
   PetscCall(PetscSFGetGraph(sf, NULL, &nleaves, &leaves, &remotes));
+
+  // Store leaf-root pairs if remote.rank is the current rank
+  if (nleaves >= 0) PetscCall(PetscMalloc2(nleaves, &rootsMyRankPair, nleaves, &leavesMyRankPair));
+  for (PetscInt l = 0; l < nleaves; l++) {
+    if (remotes[l].rank == myrank) {
+      rootsMyRankPair[numMyRankPair]  = remotes[l].index;
+      leavesMyRankPair[numMyRankPair] = leaves[l];
+      numMyRankPair++;
+    }
+  }
+  PetscCall(PetscIntSortSemiOrdered(numMyRankPair, rootsMyRankPair));
+  PetscCall(PetscIntSortSemiOrdered(numMyRankPair, leavesMyRankPair));
+  if (debug) {
+    PetscCall(PetscPrintf(comm, "Roots on the same rank:\n"));
+    PetscCall(PetscIntView(numMyRankPair, rootsMyRankPair, NULL));
+  }
   /*
    section        - maps points to (# dofs, local dofs)
    sectionGlobal  - maps points to (# dofs, global dofs)
@@ -247,7 +297,7 @@ static PetscErrorCode DMPlexCreateAdjacencySection_Static(DM dm, PetscInt bs, Pe
     PetscCall(PetscSectionInvalidateMaxDof_Internal(rootSectionAdj));
   }
   if (debug) {
-    PetscCall(PetscPrintf(comm, "Adjancency Section for Preallocation on Roots:\n"));
+    PetscCall(PetscPrintf(comm, "Adjacency Section for Preallocation on Roots:\n"));
     PetscCall(PetscSectionView(rootSectionAdj, NULL));
   }
   /* Add in local adjacency sizes for owned dofs on interface (roots) */
@@ -276,14 +326,14 @@ static PetscErrorCode DMPlexCreateAdjacencySection_Static(DM dm, PetscInt bs, Pe
   }
   PetscCall(PetscSectionSetUp(rootSectionAdj));
   if (debug) {
-    PetscCall(PetscPrintf(comm, "Adjancency Section for Preallocation on Roots after local additions:\n"));
+    PetscCall(PetscPrintf(comm, "Adjacency Section for Preallocation on Roots after local additions:\n"));
     PetscCall(PetscSectionView(rootSectionAdj, NULL));
   }
   /* Create adj SF based on dof SF */
   PetscCall(PetscSFCreateRemoteOffsets(sfDof, rootSectionAdj, leafSectionAdj, &remoteOffsets));
   PetscCall(PetscSFCreateSectionSF(sfDof, rootSectionAdj, remoteOffsets, leafSectionAdj, &sfAdj));
   PetscCall(PetscFree(remoteOffsets));
-  if (debug && size > 1) {
+  if (debug) {
     PetscCall(PetscPrintf(comm, "Adjacency SF for Preallocation:\n"));
     PetscCall(PetscSFView(sfAdj, NULL));
   }
@@ -326,11 +376,8 @@ static PetscErrorCode DMPlexCreateAdjacencySection_Static(DM dm, PetscInt bs, Pe
   }
   /* Debugging */
   if (debug) {
-    IS tmp;
     PetscCall(PetscPrintf(comm, "Leaf adjacency indices\n"));
-    PetscCall(ISCreateGeneral(comm, adjSize, adj, PETSC_USE_POINTER, &tmp));
-    PetscCall(ISView(tmp, NULL));
-    PetscCall(ISDestroy(&tmp));
+    PetscCall(PetscSectionArrayView(leafSectionAdj, adj, PETSC_INT, NULL));
   }
   /* Gather adjacent indices to root */
   PetscCall(PetscSectionGetStorageSize(rootSectionAdj, &adjSize));
@@ -358,11 +405,8 @@ static PetscErrorCode DMPlexCreateAdjacencySection_Static(DM dm, PetscInt bs, Pe
   PetscCall(PetscFree(adj));
   /* Debugging */
   if (debug) {
-    IS tmp;
     PetscCall(PetscPrintf(comm, "Root adjacency indices after gather\n"));
-    PetscCall(ISCreateGeneral(comm, adjSize, rootAdj, PETSC_USE_POINTER, &tmp));
-    PetscCall(ISView(tmp, NULL));
-    PetscCall(ISDestroy(&tmp));
+    PetscCall(PetscSectionArrayView(rootSectionAdj, rootAdj, PETSC_INT, NULL));
   }
   /* Add in local adjacency indices for owned dofs on interface (roots) */
   for (p = pStart; p < pEnd; ++p) {
@@ -403,11 +447,8 @@ static PetscErrorCode DMPlexCreateAdjacencySection_Static(DM dm, PetscInt bs, Pe
   }
   /* Debugging */
   if (debug) {
-    IS tmp;
-    PetscCall(PetscPrintf(comm, "Root adjacency indices\n"));
-    PetscCall(ISCreateGeneral(comm, adjSize, rootAdj, PETSC_USE_POINTER, &tmp));
-    PetscCall(ISView(tmp, NULL));
-    PetscCall(ISDestroy(&tmp));
+    PetscCall(PetscPrintf(comm, "Adjacency Section for Preallocation on Roots before compression:\n"));
+    PetscCall(PetscSectionArrayView(rootSectionAdj, rootAdj, PETSC_INT, NULL));
   }
   /* Compress indices */
   PetscCall(PetscSectionSetUp(rootSectionAdj));
@@ -430,18 +471,18 @@ static PetscErrorCode DMPlexCreateAdjacencySection_Static(DM dm, PetscInt bs, Pe
   }
   /* Debugging */
   if (debug) {
-    IS tmp;
-    PetscCall(PetscPrintf(comm, "Adjancency Section for Preallocation on Roots after compression:\n"));
-    PetscCall(PetscSectionView(rootSectionAdj, NULL));
-    PetscCall(PetscPrintf(comm, "Root adjacency indices after compression\n"));
-    PetscCall(ISCreateGeneral(comm, adjSize, rootAdj, PETSC_USE_POINTER, &tmp));
-    PetscCall(ISView(tmp, NULL));
-    PetscCall(ISDestroy(&tmp));
+    PetscCall(PetscPrintf(comm, "Adjacency Section for Preallocation on Roots after compression:\n"));
+    PetscCall(PetscSectionArrayView(rootSectionAdj, rootAdj, PETSC_INT, NULL));
   }
   /* Build adjacency section: Maps global indices to sets of adjacent global indices */
   PetscCall(PetscSectionGetOffsetRange(sectionGlobal, &globalOffStart, &globalOffEnd));
   PetscCall(PetscSectionCreate(comm, &sectionAdj));
   PetscCall(PetscSectionSetChart(sectionAdj, globalOffStart, globalOffEnd));
+
+  PetscInt *exclude_leaves, num_exclude_leaves, max_adjacency_size = 0;
+  PetscCall(DMPlexGetMaxAdjacencySize_Internal(dm, useAnchors, &max_adjacency_size));
+  PetscCall(PetscMalloc1(max_adjacency_size, &exclude_leaves));
+
   for (p = pStart; p < pEnd; ++p) {
     PetscInt  numAdj = PETSC_DETERMINE, dof, cdof, off, goff, d, q, anDof;
     PetscBool found  = PETSC_TRUE;
@@ -467,14 +508,18 @@ static PetscErrorCode DMPlexCreateAdjacencySection_Static(DM dm, PetscInt bs, Pe
     PetscCall(PetscSectionGetDof(section, p, &dof));
     PetscCall(PetscSectionGetOffset(sectionGlobal, p, &goff));
     PetscCall(DMPlexGetAdjacency_Internal(dm, p, useCone, useClosure, useAnchors, &numAdj, &tmpAdj));
+    PetscCall(AdjancencyContainsLeafRootPair(numMyRankPair, leavesMyRankPair, rootsMyRankPair, numAdj, tmpAdj, &num_exclude_leaves, exclude_leaves));
     for (q = 0; q < numAdj; ++q) {
       const PetscInt padj = tmpAdj[q];
-      PetscInt       ndof, ncdof, noff;
+      PetscInt       ndof, ncdof, noff, count;
 
       if ((padj < pStart) || (padj >= pEnd)) continue;
       PetscCall(PetscSectionGetDof(section, padj, &ndof));
       PetscCall(PetscSectionGetConstraintDof(section, padj, &ncdof));
       PetscCall(PetscSectionGetOffset(section, padj, &noff));
+      // If leaf-root pair are both on this rank, only count root
+      PetscCall(PetscFindInt(padj, num_exclude_leaves, exclude_leaves, &count));
+      if (count >= 0) continue;
       for (d = goff; d < goff + dof - cdof; ++d) PetscCall(PetscSectionAddDof(sectionAdj, d, ndof - ncdof));
     }
     PetscCall(PetscSectionGetDof(anchorSectionAdj, p, &anDof));
@@ -517,6 +562,7 @@ static PetscErrorCode DMPlexCreateAdjacencySection_Static(DM dm, PetscInt bs, Pe
     }
     if (found) continue;
     PetscCall(DMPlexGetAdjacency_Internal(dm, p, useCone, useClosure, useAnchors, &numAdj, &tmpAdj));
+    PetscCall(AdjancencyContainsLeafRootPair(numMyRankPair, leavesMyRankPair, rootsMyRankPair, numAdj, tmpAdj, &num_exclude_leaves, exclude_leaves));
     PetscCall(PetscSectionGetDof(anchorSectionAdj, p, &anDof));
     PetscCall(PetscSectionGetOffset(anchorSectionAdj, p, &anOff));
     for (d = goff; d < goff + dof - cdof; ++d) {
@@ -525,9 +571,8 @@ static PetscErrorCode DMPlexCreateAdjacencySection_Static(DM dm, PetscInt bs, Pe
       PetscCall(PetscSectionGetDof(sectionAdj, d, &adof));
       PetscCall(PetscSectionGetOffset(sectionAdj, d, &aoff));
       for (q = 0; q < numAdj; ++q) {
-        const PetscInt  padj = tmpAdj[q];
-        PetscInt        ndof, ncdof, ngoff, nd;
-        const PetscInt *ncind;
+        const PetscInt padj = tmpAdj[q], *ncind;
+        PetscInt       ndof, ncdof, ngoff, nd, count;
 
         /* Adjacent points may not be in the section chart */
         if ((padj < pStart) || (padj >= pEnd)) continue;
@@ -535,6 +580,9 @@ static PetscErrorCode DMPlexCreateAdjacencySection_Static(DM dm, PetscInt bs, Pe
         PetscCall(PetscSectionGetConstraintDof(section, padj, &ncdof));
         PetscCall(PetscSectionGetConstraintIndices(section, padj, &ncind));
         PetscCall(PetscSectionGetOffset(sectionGlobal, padj, &ngoff));
+        // If leaf-root pair are both on this rank, only count root
+        PetscCall(PetscFindInt(padj, num_exclude_leaves, exclude_leaves, &count));
+        if (count >= 0) continue;
         for (nd = 0; nd < ndof - ncdof; ++nd, ++i) cols[aoff + i] = ngoff < 0 ? -(ngoff + 1) + nd : ngoff + nd;
       }
       for (q = 0; q < anDof; q++, i++) cols[aoff + i] = anchorAdj[anOff + q];
@@ -544,16 +592,15 @@ static PetscErrorCode DMPlexCreateAdjacencySection_Static(DM dm, PetscInt bs, Pe
   PetscCall(PetscSectionDestroy(&anchorSectionAdj));
   PetscCall(PetscSectionDestroy(&leafSectionAdj));
   PetscCall(PetscSectionDestroy(&rootSectionAdj));
+  PetscCall(PetscFree(exclude_leaves));
+  PetscCall(PetscFree2(rootsMyRankPair, leavesMyRankPair));
   PetscCall(PetscFree(anchorAdj));
   PetscCall(PetscFree(rootAdj));
   PetscCall(PetscFree(tmpAdj));
   /* Debugging */
   if (debug) {
-    IS tmp;
     PetscCall(PetscPrintf(comm, "Column indices\n"));
-    PetscCall(ISCreateGeneral(comm, numCols, cols, PETSC_USE_POINTER, &tmp));
-    PetscCall(ISView(tmp, NULL));
-    PetscCall(ISDestroy(&tmp));
+    PetscCall(PetscSectionArrayView(sectionAdj, cols, PETSC_INT, NULL));
   }
 
   *sA     = sectionAdj;
@@ -662,19 +709,19 @@ static PetscErrorCode DMPlexFillMatrix_Static(DM dm, PetscLayout rLayout, PetscI
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*@C
+/*@
   DMPlexPreallocateOperator - Calculate the matrix nonzero pattern based upon the information in the `DM`,
   the `PetscDS` it contains, and the default `PetscSection`.
 
   Collective
 
   Input Parameters:
-+ dm   - The `DMPLEX`
-. bs   - The matrix blocksize
-. dnz  - An array to hold the number of nonzeros in the diagonal block
-. onz  - An array to hold the number of nonzeros in the off-diagonal block
-. dnzu - An array to hold the number of nonzeros in the upper triangle of the diagonal block
-. onzu - An array to hold the number of nonzeros in the upper triangle of the off-diagonal block
++ dm         - The `DMPLEX`
+. bs         - The matrix blocksize
+. dnz        - An array to hold the number of nonzeros in the diagonal block
+. onz        - An array to hold the number of nonzeros in the off-diagonal block
+. dnzu       - An array to hold the number of nonzeros in the upper triangle of the diagonal block
+. onzu       - An array to hold the number of nonzeros in the upper triangle of the off-diagonal block
 - fillMatrix - If `PETSC_TRUE`, fill the matrix with zeros
 
   Output Parameter:
@@ -682,7 +729,7 @@ static PetscErrorCode DMPlexFillMatrix_Static(DM dm, PetscLayout rLayout, PetscI
 
   Level: advanced
 
-.seealso: [](chapter_unstructured), `DM`, `DMPLEX`, `DMCreateMatrix()`
+.seealso: [](ch_unstructured), `DM`, `DMPLEX`, `DMCreateMatrix()`
 @*/
 PetscErrorCode DMPlexPreallocateOperator(DM dm, PetscInt bs, PetscInt dnz[], PetscInt onz[], PetscInt dnzu[], PetscInt onzu[], Mat A, PetscBool fillMatrix)
 {
@@ -697,42 +744,38 @@ PetscErrorCode DMPlexPreallocateOperator(DM dm, PetscInt bs, PetscInt dnz[], Pet
   PetscInt     Nf, f, idx, locRows;
   PetscLayout  rLayout;
   PetscBool    isSymBlock, isSymSeqBlock, isSymMPIBlock, debug = PETSC_FALSE;
-  PetscMPIInt  size;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(dm, DM_CLASSID, 1);
   PetscValidHeaderSpecific(A, MAT_CLASSID, 7);
-  if (dnz) PetscValidIntPointer(dnz, 3);
-  if (onz) PetscValidIntPointer(onz, 4);
-  if (dnzu) PetscValidIntPointer(dnzu, 5);
-  if (onzu) PetscValidIntPointer(onzu, 6);
-  PetscCall(DMGetPointSF(dm, &sf));
+  if (dnz) PetscAssertPointer(dnz, 3);
+  if (onz) PetscAssertPointer(onz, 4);
+  if (dnzu) PetscAssertPointer(dnzu, 5);
+  if (onzu) PetscAssertPointer(onzu, 6);
+  PetscCall(DMGetIsoperiodicPointSF_Internal(dm, &sf));
   PetscCall(DMGetLocalSection(dm, &section));
   PetscCall(PetscOptionsGetBool(NULL, NULL, "-dm_view_preallocation", &debug, NULL));
   PetscCall(PetscObjectGetComm((PetscObject)dm, &comm));
-  PetscCallMPI(MPI_Comm_size(comm, &size));
   PetscCall(PetscLogEventBegin(DMPLEX_Preallocate, dm, 0, 0, 0));
   /* Create dof SF based on point SF */
   if (debug) {
     PetscSection section, sectionGlobal;
     PetscSF      sf;
 
-    PetscCall(DMGetPointSF(dm, &sf));
+    PetscCall(DMGetIsoperiodicPointSF_Internal(dm, &sf));
     PetscCall(DMGetLocalSection(dm, &section));
     PetscCall(DMGetGlobalSection(dm, &sectionGlobal));
     PetscCall(PetscPrintf(comm, "Input Section for Preallocation:\n"));
     PetscCall(PetscSectionView(section, NULL));
     PetscCall(PetscPrintf(comm, "Input Global Section for Preallocation:\n"));
     PetscCall(PetscSectionView(sectionGlobal, NULL));
-    if (size > 1) {
-      PetscCall(PetscPrintf(comm, "Input SF for Preallocation:\n"));
-      PetscCall(PetscSFView(sf, NULL));
-    }
+    PetscCall(PetscPrintf(comm, "Input SF for Preallocation:\n"));
+    PetscCall(PetscSFView(sf, NULL));
   }
   PetscCall(PetscSFCreateRemoteOffsets(sf, section, section, &remoteOffsets));
   PetscCall(PetscSFCreateSectionSF(sf, section, remoteOffsets, section, &sfDof));
   PetscCall(PetscFree(remoteOffsets));
-  if (debug && size > 1) {
+  if (debug) {
     PetscCall(PetscPrintf(comm, "Dof SF for Preallocation:\n"));
     PetscCall(PetscSFView(sfDof, NULL));
   }
