@@ -45,7 +45,7 @@ static PetscErrorCode ProcessOptions(MPI_Comm comm, AppCtx *options)
   PetscCall(PetscOptionsInt("-verbose", "Verbosity level", EX, options->verbose, &options->verbose, NULL));
   PetscOptionsEnd();
   PetscFunctionReturn(PETSC_SUCCESS);
-};
+}
 
 static PetscErrorCode CreateMesh(AppCtx *options, DM *newdm)
 {
@@ -149,6 +149,8 @@ static PetscErrorCode LoadMesh(AppCtx *options, DM *dmnew)
     PetscCall(DMLoad(dm, v));
   }
   PetscCall(PetscViewerDestroy(&v));
+  DMLabel celltypes;
+  PetscCall(DMPlexGetCellTypeLabel(dm, &celltypes));
 
   PetscCall(DMSetOptionsPrefix(dm, "load_"));
   PetscCall(DMSetFromOptions(dm));
@@ -302,7 +304,7 @@ static PetscErrorCode DMLabelCompareWithCoordinateRepresentation(DM dm, DMLabel
   PetscCall(PetscSynchronizedFlush(comm, PETSC_STDERR));
   PetscCall(ISRestoreIndices(pointsIS, &points));
   PetscCall(ISDestroy(&pointsIS));
-  PetscCall(MPIU_Allreduce(MPI_IN_PLACE, &fail, 1, MPIU_BOOL, MPI_LOR, comm));
+  PetscCallMPI(MPIU_Allreduce(MPI_IN_PLACE, &fail, 1, MPIU_BOOL, MPI_LOR, comm));
   PetscCheck(!fail, comm, PETSC_ERR_PLIB, "Label \"%s\" was not loaded correctly%s", labelName, verbose ? " - see details above" : "");
   PetscFunctionReturn(PETSC_SUCCESS);
 }
@@ -336,7 +338,7 @@ static PetscErrorCode CheckNumLabels(DM dm, AppCtx *ctx)
       PetscCall(PetscSynchronizedFlush(comm, PETSC_STDERR));
     }
   }
-  PetscCall(MPIU_Allreduce(MPI_IN_PLACE, &fail, 1, MPIU_BOOL, MPI_LOR, comm));
+  PetscCallMPI(MPIU_Allreduce(MPI_IN_PLACE, &fail, 1, MPIU_BOOL, MPI_LOR, comm));
   PetscCheck(!fail, comm, PETSC_ERR_PLIB, "Wrong number of labels%s", ctx->verbose ? " - see details above" : "");
   PetscFunctionReturn(PETSC_SUCCESS);
 }
@@ -409,6 +411,7 @@ int main(int argc, char **argv)
     args: -num_labels 1
     args: -outfile ex56_1.h5
     nsize: {{1 3}}
+    output_file: output/empty.out
     test:
       suffix: a
       args: -dm_plex_filename ${DATAFILESPATH}/meshes/hdf5-petsc/petsc-v3.16.0/v1.0.0/annulus-20.h5
@@ -441,6 +444,7 @@ int main(int argc, char **argv)
     args: -num_labels 1
     args: -outfile ex56_2.h5
     nsize: 3
+    output_file: output/empty.out
     test:
       suffix: a
       args: -dm_plex_filename ${DATAFILESPATH}/meshes/hdf5-petsc/petsc-v3.16.0/v1.0.0/annulus-20.h5
@@ -472,6 +476,7 @@ int main(int argc, char **argv)
     args: -num_labels 1
     args: -outfile ex56_3.h5
     nsize: 3
+    output_file: output/empty.out
     test:
       suffix: a
       args: -dm_plex_filename ${DATAFILESPATH}/meshes/hdf5-petsc/petsc-v3.16.0/v1.0.0/annulus-20.h5
