@@ -23,7 +23,7 @@ int main(int argc, char **argv)
   PetscScalar ****arrSol, ****arrRHS;
 
   PetscFunctionBeginUser;
-  PetscCall(PetscInitialize(&argc, &argv, (char *)0, help));
+  PetscCall(PetscInitialize(&argc, &argv, NULL, help));
   /* Note: these defaults are chosen to suit the problem. We allow adjusting
      them to check that things still work when you add unused extra dof */
   dof0 = 0;
@@ -202,24 +202,29 @@ PetscErrorCode ApplyOperator(Mat A, Vec in, Vec out)
    test:
       suffix: 1
       nsize: 1
+      output_file: output/empty.out
 
    test:
       suffix: 2
       nsize: 8
+      output_file: output/empty.out
 
    test:
       suffix: 3
       nsize: 1
       args: -stag_stencil_width 2
+      output_file: output/empty.out
 
    test:
       suffix: 4
       nsize: 8
       args: -stag_grid_x 4 -stag_grid_y 5 -stag_grid_z 4 -stag_stencil_width 2
+      output_file: output/empty.out
 
    test:
       suffix: 5
       nsize: 8
       args: -stag_dof_0 3 -stag_dof_1 2 -stag_dof_2 4 -stag_dof_3 2 -stag_stencil_width 3 -stag_grid_x 6 -stag_grid_y 6 -stag_grid_z 6
+      output_file: output/empty.out
 
 TEST*/
