@@ -355,19 +355,18 @@ PetscErrorCode DMLocalizeCoordinates(DM dm)
   PetscCall(DMGetCoordinateDM(dm, &cdm));
   PetscCall(DMConvert(dm, DMPLEX, &plex));
   PetscCall(DMConvert(cdm, DMPLEX, &cplex));
-  if (cplex) {
-    PetscCall(DMPlexGetDepthStratum(cplex, 0, &vStart, &vEnd));
-    PetscCall(DMPlexGetMaxProjectionHeight(cplex, &maxHeight));
-    PetscCall(DMGetWorkArray(dm, 2 * (maxHeight + 1), MPIU_INT, &pStart));
-    pEnd     = &pStart[maxHeight + 1];
-    newStart = vStart;
-    newEnd   = vEnd;
-    for (h = 0; h <= maxHeight; h++) {
-      PetscCall(DMPlexGetHeightStratum(cplex, h, &pStart[h], &pEnd[h]));
-      newStart = PetscMin(newStart, pStart[h]);
-      newEnd   = PetscMax(newEnd, pEnd[h]);
-    }
-  } else SETERRQ(comm, PETSC_ERR_ARG_WRONG, "Coordinate localization requires a DMPLEX coordinate DM");
+  PetscCheck(cplex, comm, PETSC_ERR_ARG_WRONG, "Coordinate localization requires a DMPLEX coordinate DM");
+  PetscCall(DMPlexGetDepthStratum(cplex, 0, &vStart, &vEnd));
+  PetscCall(DMPlexGetMaxProjectionHeight(cplex, &maxHeight));
+  PetscCall(DMGetWorkArray(dm, 2 * (maxHeight + 1), MPIU_INT, &pStart));
+  pEnd     = &pStart[maxHeight + 1];
+  newStart = vStart;
+  newEnd   = vEnd;
+  for (h = 0; h <= maxHeight; h++) {
+    PetscCall(DMPlexGetHeightStratum(cplex, h, &pStart[h], &pEnd[h]));
+    newStart = PetscMin(newStart, pStart[h]);
+    newEnd   = PetscMax(newEnd, pEnd[h]);
+  }
   PetscCall(DMGetCoordinatesLocal(dm, &coordinates));
   PetscCheck(coordinates, comm, PETSC_ERR_SUP, "Missing local coordinate vector");
   PetscCall(DMGetCoordinateSection(dm, &cs));
@@ -450,39 +449,28 @@ PetscErrorCode DMLocalizeCoordinates(DM dm)
     }
   }
   PetscCall(VecRestoreArray(cVec, &coordsDG));
-  PetscCall(DMClone(cdm, &cdgdm));
+  PetscUseTypeMethod(dm, createcellcoordinatedm, &cdgdm);
   PetscCall(DMSetCellCoordinateDM(dm, cdgdm));
-  PetscCall(DMSetCellCoordinateSection(dm, PETSC_DETERMINE, csDG));
-  PetscCall(DMSetCellCoordinatesLocal(dm, cVec));
-  PetscCall(VecDestroy(&cVec));
+  PetscCall(DMDestroy(&cdgdm));
   // Convert the discretization
   {
-    PetscFE         fe, dgfe;
-    PetscSpace      P;
-    PetscDualSpace  Q, dgQ;
-    PetscQuadrature q, fq;
-    PetscClassId    id;
+    PetscFE      fe;
+    PetscClassId id;
 
     PetscCall(DMGetField(cdm, 0, NULL, (PetscObject *)&fe));
     PetscCall(PetscObjectGetClassId((PetscObject)fe, &id));
     if (id == PETSCFE_CLASSID) {
+      PetscSpace P;
+      PetscInt   degree;
+
       PetscCall(PetscFEGetBasisSpace(fe, &P));
-      PetscCall(PetscObjectReference((PetscObject)P));
-      PetscCall(PetscFEGetDualSpace(fe, &Q));
-      PetscCall(PetscDualSpaceDuplicate(Q, &dgQ));
-      PetscCall(PetscDualSpaceLagrangeSetContinuity(dgQ, PETSC_FALSE));
-      PetscCall(PetscDualSpaceSetUp(dgQ));
-      PetscCall(PetscFEGetQuadrature(fe, &q));
-      PetscCall(PetscObjectReference((PetscObject)q));
-      PetscCall(PetscFEGetFaceQuadrature(fe, &fq));
-      PetscCall(PetscObjectReference((PetscObject)fq));
-      PetscCall(PetscFECreateFromSpaces(P, dgQ, q, fq, &dgfe));
-      PetscCall(DMSetField(cdgdm, 0, NULL, (PetscObject)dgfe));
-      PetscCall(PetscFEDestroy(&dgfe));
-      PetscCall(DMCreateDS(cdgdm));
+      PetscCall(PetscSpaceGetDegree(P, &degree, NULL));
+      PetscCall(DMPlexCreateCoordinateSpace(dm, degree, PETSC_TRUE, PETSC_FALSE));
     }
   }
-  PetscCall(DMDestroy(&cdgdm));
+  PetscCall(DMSetCellCoordinateSection(dm, PETSC_DETERMINE, csDG));
+  PetscCall(DMSetCellCoordinatesLocal(dm, cVec));
+  PetscCall(VecDestroy(&cVec));
 
 end:
   PetscCall(DMRestoreWorkArray(dm, 2 * bs, MPIU_SCALAR, &anchor));
