@@ -1,4 +1,3 @@
-
 static char help[] = "Reads a PETSc matrix and vector from a file and solves a linear system.\n\
 This version first preloads and solves a small system, then loads \n\
 another (larger) system and solves it as well.  This example illustrates\n\
@@ -49,7 +48,7 @@ int main(int argc, char **args)
   char        mtype[PETSC_MAX_PATH_LEN];
 
   PetscFunctionBeginUser;
-  PetscCall(PetscInitialize(&argc, &args, (char *)0, help));
+  PetscCall(PetscInitialize(&argc, &args, NULL, help));
   PetscCallMPI(MPI_Comm_rank(PETSC_COMM_WORLD, &rank));
   PetscCall(PetscOptionsGetBool(NULL, NULL, "-table", &table, NULL));
   PetscCall(PetscOptionsGetBool(NULL, NULL, "-constantnullspace", &constantnullspace, NULL));
@@ -181,7 +180,7 @@ int main(int argc, char **args)
   PetscCall(VecGetSize(b, &m));
   PetscCall(VecGetLocalSize(b, &p));
   preload = (PetscBool)(M != m || p != n); /* Global or local dimension mismatch */
-  PetscCall(MPIU_Allreduce(&preload, &flg, 1, MPIU_BOOL, MPI_LOR, PetscObjectComm((PetscObject)A)));
+  PetscCallMPI(MPIU_Allreduce(&preload, &flg, 1, MPIU_BOOL, MPI_LOR, PetscObjectComm((PetscObject)A)));
   if (flg) { /* Create a new vector b by padding the old one */
     PetscInt     j, mvec, start, end, indx;
     Vec          tmp;
@@ -221,21 +220,26 @@ int main(int argc, char **args)
   flg = PETSC_FALSE;
   PetscCall(PetscOptionsGetBool(NULL, NULL, "-check_scaling", &flg, NULL));
   if (flg) {
-    Vec       max, min;
+    Vec       max, min, l1;
     PetscInt  idx;
     PetscReal val;
 
     PetscCall(VecDuplicate(x, &max));
     PetscCall(VecDuplicate(x, &min));
+    PetscCall(VecDuplicate(x, &l1));
     PetscCall(MatGetRowMaxAbs(A, max, NULL));
     PetscCall(MatGetRowMinAbs(A, min, NULL));
-    {
+    PetscCall(MatGetRowSumAbs(A, l1));
+    if (PETSC_FALSE) {
       PetscCall(PetscViewerASCIIOpen(PETSC_COMM_WORLD, "max.data", &viewer));
       PetscCall(VecView(max, viewer));
       PetscCall(PetscViewerDestroy(&viewer));
       PetscCall(PetscViewerASCIIOpen(PETSC_COMM_WORLD, "min.data", &viewer));
       PetscCall(VecView(min, viewer));
       PetscCall(PetscViewerDestroy(&viewer));
+      PetscCall(PetscViewerASCIIOpen(PETSC_COMM_WORLD, "l1.data", &viewer));
+      PetscCall(VecView(l1, viewer));
+      PetscCall(PetscViewerDestroy(&viewer));
     }
     PetscCall(VecView(max, PETSC_VIEWER_DRAW_WORLD));
     PetscCall(VecMax(max, &idx, &val));
@@ -249,8 +253,15 @@ int main(int argc, char **args)
     PetscCall(VecMax(max, &idx, &val));
     PetscCall(PetscPrintf(PETSC_COMM_WORLD, "Largest row ratio %g at row %" PetscInt_FMT "\n", (double)val, idx));
     PetscCall(VecView(max, PETSC_VIEWER_DRAW_WORLD));
+    PetscCall(VecMax(max, &idx, &val));
+    PetscCall(PetscPrintf(PETSC_COMM_WORLD, "Largest row ratio %g at row %" PetscInt_FMT "\n", (double)val, idx));
+    PetscCall(VecView(max, PETSC_VIEWER_DRAW_WORLD));
+    PetscCall(VecView(max, PETSC_VIEWER_DRAW_WORLD));
+    PetscCall(VecMax(l1, &idx, &val));
+    PetscCall(PetscPrintf(PETSC_COMM_WORLD, "Largest l1 row element %g at row %" PetscInt_FMT "\n", (double)val, idx));
     PetscCall(VecDestroy(&max));
     PetscCall(VecDestroy(&min));
+    PetscCall(VecDestroy(&l1));
   }
 
   /*  PetscCall(MatView(A,PETSC_VIEWER_STDOUT_WORLD)); */
@@ -383,8 +394,8 @@ int main(int argc, char **args)
       PetscCall(PetscViewerDestroy(&viewer));
     } else {
       PetscCall(PetscPrintf(PETSC_COMM_WORLD, "Number of iterations = %3" PetscInt_FMT "\n", its));
-      if (!PetscIsNanScalar(norm)) {
-        if (norm < 1.e-12 && !PetscIsNanScalar((PetscScalar)norm)) {
+      if (!PetscIsNanReal(norm)) {
+        if (norm < 1.e-12) {
           PetscCall(PetscPrintf(PETSC_COMM_WORLD, "  Residual norm < 1.e-12\n"));
         } else {
           PetscCall(PetscPrintf(PETSC_COMM_WORLD, "Residual norm %g\n", (double)norm));
@@ -459,7 +470,7 @@ int main(int argc, char **args)
       nsize: 2
       requires: datafilespath double !defined(PETSC_USE_64BIT_INDICES)
       args: -f0 ${DATAFILESPATH}/matrices/medium
-      args:  -ksp_type bicg
+      args: -ksp_type bicg
       test:
          suffix: 2
 
@@ -521,7 +532,7 @@ int main(int argc, char **args)
       suffix: 9
       requires: datafilespath double !defined(PETSC_USE_64BIT_INDICES)
       args: -f0 ${DATAFILESPATH}/matrices/medium
-      args: -viewer_binary_skip_info  -matload_block_size {{1 2 3 4 5 6 7}separate output} -ksp_max_it 100 -ksp_gmres_cgs_refinement_type refine_always -ksp_rtol 1.0e-15 -ksp_monitor_short
+      args: -viewer_binary_skip_info -matload_block_size {{1 2 3 4 5 6 7}separate output} -ksp_max_it 100 -ksp_gmres_cgs_refinement_type refine_always -ksp_rtol 1.0e-15 -ksp_monitor_short
       test:
          suffix: a
          args: -mat_type seqbaij
@@ -586,6 +597,10 @@ int main(int argc, char **args)
          suffix: 18
          requires: hypre !defined(PETSC_HAVE_HYPRE_DEVICE)
          args: -pc_type hypre -pc_hypre_type euclid
+      test:
+         suffix: 20
+         requires: hypre !defined(PETSC_HAVE_HYPRE_DEVICE)
+         args: -pc_type hypre -pc_hypre_type ilu
 
    testset:
       suffix: 19
@@ -626,11 +641,9 @@ int main(int argc, char **args)
       test:
          suffix: boomeramg_euclid
          args: -pc_hypre_boomeramg_smooth_type Euclid -pc_hypre_boomeramg_smooth_num_levels 2 -pc_hypre_boomeramg_eu_level 1 -pc_hypre_boomeramg_eu_droptolerance 0.01
-         TODO: Need to determine if deprecated
       test:
          suffix: boomeramg_euclid_bj
          args: -pc_hypre_boomeramg_smooth_type Euclid -pc_hypre_boomeramg_smooth_num_levels 2 -pc_hypre_boomeramg_eu_level 1 -pc_hypre_boomeramg_eu_droptolerance 0.01 -pc_hypre_boomeramg_eu_bj
-         TODO: Need to determine if deprecated
       test:
          suffix: boomeramg_parasails
          args: -pc_hypre_boomeramg_smooth_type ParaSails -pc_hypre_boomeramg_smooth_num_levels 2
@@ -687,11 +700,11 @@ int main(int argc, char **args)
 
    testset:
       nsize: 4
-      requires: datafilespath double !defined(PETSC_USE_64BIT_INDICES) !defined(PETSC_HAVE_I_MPI_NUMVERSION)
+      requires: datafilespath double !defined(PETSC_USE_64BIT_INDICES) !defined(PETSC_HAVE_I_MPI)
       args: -ksp_monitor_short -ksp_view
       test:
          suffix: xxt
-         args: -f0 ${DATAFILESPATH}/matrices/poisson1 -check_symmetry -ksp_type cg -pc_type tfs
+         args: -f0 ${DATAFILESPATH}/matrices/poisson1 -check_symmetry -check_scaling -ksp_type cg -pc_type tfs
       test:
          suffix: xyt
          args: -f0 ${DATAFILESPATH}/matrices/medium -ksp_type gmres -pc_type tfs
@@ -757,12 +770,12 @@ int main(int argc, char **args)
       requires: datafilespath double !defined(PETSC_USE_64BIT_INDICES) pastix
       output_file: output/ex72_mumps.out
       nsize: {{1 2}}
-      args: -f0 ${DATAFILESPATH}/matrices/small -ksp_type preonly -pc_factor_mat_solver_type pastix -num_numfac 2 -num_rhs 2 -pc_type cholesky -mat_type sbaij -mat_ignore_lower_triangular
+      args: -f0 ${DATAFILESPATH}/matrices/small -ksp_type preonly -pc_factor_mat_solver_type pastix -num_numfac 2 -num_rhs 2 -pc_type cholesky -mat_type sbaij -mat_ignore_lower_triangular -mat_pastix_thread_nbr 1
 
    testset:
       suffix: pastix_lu
       requires: datafilespath double !defined(PETSC_USE_64BIT_INDICES) pastix
-      args: -f0 ${DATAFILESPATH}/matrices/small -ksp_type preonly -pc_type lu -pc_factor_mat_solver_type pastix -num_numfac 2 -num_rhs 2
+      args: -f0 ${DATAFILESPATH}/matrices/small -ksp_type preonly -pc_type lu -pc_factor_mat_solver_type pastix -num_numfac 2 -num_rhs 2 -mat_pastix_thread_nbr 1
       output_file: output/ex72_mumps.out
       test:
          args: -mat_type seqaij
@@ -775,7 +788,7 @@ int main(int argc, char **args)
       output_file: output/ex72_mumps_redundant.out
       nsize: 8
       requires: datafilespath double !defined(PETSC_USE_64BIT_INDICES) pastix
-      args: -f0 ${DATAFILESPATH}/matrices/medium -ksp_type preonly -pc_type redundant -pc_redundant_number {{8 7 6 5 4 3 2 1}} -redundant_pc_factor_mat_solver_type pastix -num_numfac 2 -num_rhs 2
+      args: -f0 ${DATAFILESPATH}/matrices/medium -ksp_type preonly -pc_type redundant -pc_redundant_number {{8 7 6 5 4 3 2 1}} -redundant_pc_factor_mat_solver_type pastix -num_numfac 2 -num_rhs 2 -mat_pastix_thread_nbr 1
 
    testset:
       suffix: superlu_dist_lu
@@ -804,8 +817,8 @@ int main(int argc, char **args)
 
    testset:
       suffix: zeropivot
-      requires: datafilespath double !defined(PETSC_USE_64BIT_INDICES) mumps
-      args: -f0 ${DATAFILESPATH}/matrices/small -test_zeropivot -ksp_converged_reason -ksp_type fgmres -pc_type ksp
+      requires: datafilespath double !defined(PETSC_USE_64BIT_INDICES)
+      args: -f0 ${DATAFILESPATH}/matrices/small -test_zeropivot -ksp_converged_reason -ksp_type fgmres -pc_type ksp -fp_trap 0
       test:
          nsize: 3
          args: -ksp_pc_type bjacobi
@@ -828,7 +841,7 @@ int main(int argc, char **args)
          output_file: output/ex72_aij_gdsw.out
          suffix: is_gdsw
          nsize: 4
-         args: -pc_type mg -pc_mg_levels 2  -pc_mg_adapt_interp_coarse_space gdsw -pc_mg_galerkin -mg_levels_pc_type asm
+         args: -pc_type mg -pc_mg_levels 2 -pc_mg_adapt_interp_coarse_space gdsw -pc_mg_galerkin -mg_levels_pc_type asm
       test:
          suffix: is_asm
          nsize: {{1 2}separate output}
@@ -867,12 +880,81 @@ int main(int argc, char **args)
          suffix: hpddm_gen_non_hermitian
          output_file: output/ex72_2.out
          nsize: 4
-         args: -f0 ${DATAFILESPATH}/matrices/arco1 -pc_type hpddm -pc_hpddm_define_subdomains -pc_hpddm_levels_1_sub_pc_type lu -pc_hpddm_levels_1_eps_nev 10 -pc_hpddm_levels_1_st_share_sub_ksp -pc_hpddm_levels_1_eps_gen_non_hermitian -pc_hpddm_coarse_mat_type baij -pc_hpddm_block_splitting -pc_hpddm_levels_1_eps_threshold 0.7 -pc_hpddm_coarse_pc_type lu -ksp_pc_side right
+         args: -f0 ${DATAFILESPATH}/matrices/arco1 -pc_type hpddm -pc_hpddm_define_subdomains -pc_hpddm_levels_1_sub_pc_type lu -pc_hpddm_levels_1_eps_nev 10 -pc_hpddm_levels_1_st_share_sub_ksp -pc_hpddm_levels_1_eps_gen_non_hermitian -pc_hpddm_coarse_mat_type baij -pc_hpddm_block_splitting -pc_hpddm_levels_1_eps_threshold_absolute 0.7 -ksp_pc_side right
       test:
          requires: datafilespath double !defined(PETSC_USE_64BIT_INDICES) mumps !defined(PETSCTEST_VALGRIND)
          suffix: hpddm_gen_non_hermitian_baij
-         output_file: output/ex72_5.out
+         output_file: output/ex72_10.out
          nsize: 4
          timeoutfactor: 2
-         args: -f0 ${DATAFILESPATH}/matrices/arco6 -pc_type hpddm -pc_hpddm_define_subdomains -pc_hpddm_levels_1_sub_pc_type lu -pc_hpddm_levels_1_eps_nev 30 -pc_hpddm_levels_1_st_share_sub_ksp -pc_hpddm_levels_1_eps_gen_non_hermitian -pc_hpddm_coarse_mat_type baij -pc_hpddm_block_splitting -pc_hpddm_levels_1_eps_threshold 0.8 -pc_hpddm_coarse_pc_type lu -ksp_pc_side right -mat_type baij -pc_hpddm_levels_1_sub_pc_factor_mat_solver_type mumps -pc_hpddm_levels_1_eps_tol 1.0e-2
+         args: -f0 ${DATAFILESPATH}/matrices/arco6 -pc_type hpddm -pc_hpddm_define_subdomains -pc_hpddm_levels_1_sub_pc_type lu -pc_hpddm_levels_1_eps_nev 30 -pc_hpddm_levels_1_st_share_sub_ksp -pc_hpddm_levels_1_eps_gen_non_hermitian -pc_hpddm_coarse_mat_type baij -pc_hpddm_block_splitting -pc_hpddm_levels_1_eps_threshold_absolute 0.8 -ksp_pc_side right -mat_type baij -pc_hpddm_levels_1_sub_pc_factor_mat_solver_type mumps -pc_hpddm_levels_1_eps_tol 1.0e-2 -ksp_monitor_short
+      test:
+         requires: datafilespath double !defined(PETSC_USE_64BIT_INDICES)
+         suffix: hpddm_too_much_oversampling
+         output_file: output/ex72_2.out
+         nsize: 2
+         filter: sed -e "s/Number of iterations =   3/Number of iterations =  10/g"
+         args: -f0 ${DATAFILESPATH}/matrices/small -pc_type hpddm -pc_hpddm_levels_1_svd_nsv 1 -pc_hpddm_levels_1_st_share_sub_ksp -pc_hpddm_levels_1_sub_pc_type lu -pc_hpddm_harmonic_overlap 3 -pc_hpddm_coarse_mat_type aij
+
+   # BDDC multiple subdomains per process tests
+   test:
+     requires: datafilespath double !defined(PETSC_USE_64BIT_INDICES)
+     suffix: matis_bddc_multisub_3d
+     nsize: {{1 2 3 4 5 6 7 8}}
+     args: -f ${DATAFILESPATH}/matrices/matis/poisson_DMDA_9x9x9_3x3x3.dat -pc_type bddc -ksp_type cg -ksp_norm_type natural -ksp_error_if_not_converged -mat_type is -pc_bddc_use_faces
+
+   test:
+     requires: datafilespath double !defined(PETSC_USE_64BIT_INDICES)
+     suffix: matis_bddc_multisub_2d
+     nsize: {{1 2 3 4 5 6 7 8}}
+     args: -f ${DATAFILESPATH}/matrices/matis/poisson_DMDA_9x9_3x3.dat -pc_type bddc -ksp_type cg -ksp_norm_type natural -ksp_error_if_not_converged -mat_type is
+
+   test:
+     requires: datafilespath double !defined(PETSC_USE_64BIT_INDICES)
+     suffix: matis_bddc_multisub_plex_2d
+     nsize: {{1 2 3 4 5 6 7 8}}
+     args: -f ${DATAFILESPATH}/matrices/matis/poisson_DMPLEX_32x32_16.dat -pc_type bddc -ksp_type cg -ksp_norm_type natural -ksp_error_if_not_converged -mat_type is
+
+   test:
+     requires: datafilespath double !defined(PETSC_USE_64BIT_INDICES)
+     suffix: matis_bddc_multisub_plex_3d
+     nsize: {{1 2 3 4 5 6 7 8}}
+     args: -f ${DATAFILESPATH}/matrices/matis/poisson_DMPLEX_16x16x16_16.dat -pc_type bddc -ksp_type cg -ksp_norm_type natural -ksp_error_if_not_converged -mat_type is
+
+   test:
+     requires: datafilespath double !defined(PETSC_USE_64BIT_INDICES)
+     suffix: matis_bddc_multisub_plex_3d_deluxe
+     nsize: {{1 2 3 4 5 6 7 8}}
+     args: -f ${DATAFILESPATH}/matrices/matis/poisson_DMPLEX_16x16x16_16.dat -pc_type bddc -ksp_type cg -ksp_norm_type natural -ksp_error_if_not_converged -mat_type is -pc_bddc_use_deluxe_scaling
+
+   test:
+     requires: datafilespath double !defined(PETSC_USE_64BIT_INDICES)
+     suffix: matis_bddc_multisub_hcurl_2d
+     nsize: {{1 2 3 4 5 6 7 8}}
+     args: -f ${DATAFILESPATH}/matrices/matis/hcurl_mfem_amrquad2_16.dat -pc_bddc_load ${DATAFILESPATH}/matrices/matis/bddc_hcurl_mfem_amrquad2_16.dat -pc_type bddc -ksp_type cg -ksp_norm_type natural -ksp_error_if_not_converged -mat_type is -pc_bddc_local_mat_graph_square 1
+
+   test:
+     requires: datafilespath double mumps !defined(PETSC_USE_64BIT_INDICES)
+     suffix: matis_bddc_multisub_hcurl_2d_adaptive
+     nsize: {{1 2 3 4 5 6 7 8}}
+     args: -f ${DATAFILESPATH}/matrices/matis/hcurl_mfem_amrquad2_16.dat -pc_bddc_load ${DATAFILESPATH}/matrices/matis/bddc_hcurl_mfem_amrquad2_16.dat -pc_type bddc -ksp_type cg -ksp_norm_type natural -ksp_error_if_not_converged -mat_type is -pc_bddc_local_mat_graph_square 1 -pc_bddc_use_deluxe_scaling -pc_bddc_adaptive_threshold 2 -pc_bddc_schur_exact {{0 1}}
+
+   test:
+     requires: datafilespath double !defined(PETSC_USE_64BIT_INDICES)
+     suffix: matis_bddc_multisub_hdiv_3d
+     nsize: {{1 2 3 4 5 6 7 8}}
+     args: -f ${DATAFILESPATH}/matrices/matis/hdiv_mfem_inlinehex2_16.dat -pc_bddc_load ${DATAFILESPATH}/matrices/matis/bddc_hdiv_mfem_inlinehex2_16.dat -pc_type bddc -ksp_type cg -ksp_norm_type natural -ksp_error_if_not_converged -mat_type is -pc_bddc_use_local_mat_graph 0
+
+   test:
+     requires: datafilespath double !defined(PETSC_USE_64BIT_INDICES)
+     suffix: matis_bddc_multisub_hcurl_3d
+     nsize: {{1 3 4 8}}
+     args: -f ${DATAFILESPATH}/matrices/matis/hcurl_mfem_inlinehex_16.dat -pc_bddc_load ${DATAFILESPATH}/matrices/matis/bddc_hcurl_mfem_inlinehex_16.dat -pc_type bddc -ksp_type cg -ksp_norm_type natural -ksp_error_if_not_converged -mat_type is -pc_bddc_local_mat_graph_square 1
+
+   test:
+     requires: datafilespath double !defined(PETSC_USE_64BIT_INDICES)
+     suffix: matis_bddc_multisub_hcurl_3d_amr
+     nsize: {{1 3 4 8}}
+     args: -f ${DATAFILESPATH}/matrices/matis/hcurl_mfem_amrhex_16.dat -pc_bddc_load ${DATAFILESPATH}/matrices/matis/bddc_hcurl_mfem_amrhex_16.dat -pc_type bddc -ksp_type cg -ksp_norm_type natural -ksp_error_if_not_converged -mat_type is -pc_bddc_local_mat_graph_square 1
+
 TEST*/
