@@ -54,7 +54,7 @@ static PetscErrorCode DMGlobalToLocalSolve_project1(PetscInt dim, PetscReal time
   Input Parameters:
 + dm - The `DM` object
 . x  - The local vector
-- y  - The global vector: the input value of globalVec is used as an initial guess
+- y  - The global vector: the input value of this variable is used as an initial guess
 
   Output Parameter:
 . y - The least-squares solution
@@ -169,32 +169,12 @@ PetscErrorCode DMGlobalToLocalSolve(DM dm, Vec x, Vec y)
 + dm    - The `DM`
 . time  - The time
 . U     - The input field vector
-. funcs - The functions to evaluate, one per field
+. funcs - The functions to evaluate, one per field, see `PetscPointFn`
 - mode  - The insertion mode for values
 
   Output Parameter:
 . X - The output vector
 
-  Calling sequence of `funcs`:
-+ dim          - The spatial dimension
-. Nf           - The number of input fields
-. NfAux        - The number of input auxiliary fields
-. uOff         - The offset of each field in `u`
-. uOff_x       - The offset of each field in `u_x`
-. u            - The field values at this point in space
-. u_t          - The field time derivative at this point in space (or `NULL`)
-. u_x          - The field derivatives at this point in space
-. aOff         - The offset of each auxiliary field in `u`
-. aOff_x       - The offset of each auxiliary field in `u_x`
-. a            - The auxiliary field values at this point in space
-. a_t          - The auxiliary field time derivative at this point in space (or `NULL`)
-. a_x          - The auxiliary field derivatives at this point in space
-. t            - The current time
-. x            - The coordinates of this point
-. numConstants - The number of constants
-. constants    - The value of each constant
-- f            - The value of the function at this point in space
-
   Level: advanced
 
   Note:
@@ -203,9 +183,9 @@ PetscErrorCode DMGlobalToLocalSolve(DM dm, Vec x, Vec y)
   a subdomain. You can also output a different number of fields than the input, with different discretizations. Last the auxiliary `DM`, attached to the
   auxiliary field vector, which is attached to `dm`, can also be different. It can have a different topology, number of fields, and discretizations.
 
-.seealso: [](ch_dmbase), `DM`, `DMProjectFieldLocal()`, `DMProjectFieldLabelLocal()`, `DMProjectFunction()`, `DMComputeL2Diff()`
+.seealso: [](ch_dmbase), `DM`, `PetscPointFn`, `DMProjectFieldLocal()`, `DMProjectFieldLabelLocal()`, `DMProjectFunction()`, `DMComputeL2Diff()`
 @*/
-PetscErrorCode DMProjectField(DM dm, PetscReal time, Vec U, void (**funcs)(PetscInt dim, PetscInt Nf, PetscInt NfAux, const PetscInt uOff[], const PetscInt uOff_x[], const PetscScalar u[], const PetscScalar u_t[], const PetscScalar u_x[], const PetscInt aOff[], const PetscInt aOff_x[], const PetscScalar a[], const PetscScalar a_t[], const PetscScalar a_x[], PetscReal t, const PetscReal x[], PetscInt numConstants, const PetscScalar constants[], PetscScalar f[]), InsertMode mode, Vec X)
+PetscErrorCode DMProjectField(DM dm, PetscReal time, Vec U, PetscPointFn **funcs, InsertMode mode, Vec X)
 {
   Vec localX, localU;
   DM  dmIn;
@@ -726,6 +706,135 @@ PetscErrorCode DMSwarmProjectFields(DM sw, DM dm, PetscInt nfields, const char *
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
+// Project weak divergence of particles to field
+//   \int_X psi_i div u_f = \int_X psi_i div u_p
+//   \int_X grad psi_i . \sum_j u_f \psi_j = \int_X grad psi_i . \sum_p u_p \delta(x - x_p)
+//   D_f u_f = D_p u_p
+//   u_f = D^+_f D_p u_p
+static PetscErrorCode DMSwarmProjectGradientField_Conservative_PLEX(DM sw, DM dm, Vec u_p, Vec u_f)
+{
+  DM          gdm;
+  KSP         ksp;
+  Mat         D_f, D_p; // TODO Should cache these
+  Vec         rhs;
+  const char *prefix;
+
+  PetscFunctionBegin;
+  PetscCall(VecGetDM(u_f, &gdm));
+  PetscCall(DMCreateGradientMatrix(dm, gdm, &D_f));
+  PetscCall(DMCreateGradientMatrix(sw, dm, &D_p));
+  PetscCall(DMGetGlobalVector(dm, &rhs));
+  PetscCall(PetscObjectSetName((PetscObject)rhs, "D u"));
+  PetscCall(MatMultTranspose(D_p, u_p, rhs));
+  PetscCall(VecViewFromOptions(rhs, NULL, "-rhs_view"));
+
+  PetscCall(KSPCreate(PetscObjectComm((PetscObject)sw), &ksp));
+  PetscCall(PetscObjectGetOptionsPrefix((PetscObject)sw, &prefix));
+  PetscCall(KSPSetOptionsPrefix(ksp, prefix));
+  PetscCall(KSPAppendOptionsPrefix(ksp, "gptof_"));
+  PetscCall(KSPSetFromOptions(ksp));
+
+  PetscCall(KSPSetOperators(ksp, D_f, D_f));
+  PetscCall(KSPSolveTranspose(ksp, rhs, u_f));
+
+  PetscCall(MatMultTranspose(D_f, u_f, rhs));
+  PetscCall(VecViewFromOptions(rhs, NULL, "-rhs_view"));
+
+  PetscCall(DMRestoreGlobalVector(dm, &rhs));
+  PetscCall(KSPDestroy(&ksp));
+  PetscCall(MatDestroy(&D_f));
+  PetscCall(MatDestroy(&D_p));
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+
+// Project weak divergence of field to particles
+//   D_p u_p = D_f u_f
+//   u_p = D^+_p D_f u_f
+static PetscErrorCode DMSwarmProjectGradientParticles_Conservative_PLEX(DM sw, DM dm, Vec u_p, Vec u_f)
+{
+  KSP         ksp;
+  PC          pc;
+  Mat         D_f, D_p, PD_p;
+  Vec         rhs;
+  PetscBool   isBjacobi;
+  const char *prefix;
+
+  PetscFunctionBegin;
+  PetscCall(DMCreateGradientMatrix(dm, dm, &D_f));
+  PetscCall(DMCreateGradientMatrix(sw, dm, &D_p));
+  PetscCall(DMGetGlobalVector(dm, &rhs));
+  PetscCall(MatMult(D_f, u_f, rhs));
+
+  PetscCall(KSPCreate(PetscObjectComm((PetscObject)sw), &ksp));
+  PetscCall(PetscObjectGetOptionsPrefix((PetscObject)sw, &prefix));
+  PetscCall(KSPSetOptionsPrefix(ksp, prefix));
+  PetscCall(KSPAppendOptionsPrefix(ksp, "gftop_"));
+  PetscCall(KSPSetFromOptions(ksp));
+
+  PetscCall(KSPGetPC(ksp, &pc));
+  PetscCall(PetscObjectTypeCompare((PetscObject)pc, PCBJACOBI, &isBjacobi));
+  if (isBjacobi) {
+    PetscCall(DMSwarmCreateMassMatrixSquare(sw, dm, &PD_p));
+  } else {
+    PD_p = D_p;
+    PetscCall(PetscObjectReference((PetscObject)PD_p));
+  }
+  PetscCall(KSPSetOperators(ksp, D_p, PD_p));
+  PetscCall(KSPSolveTranspose(ksp, rhs, u_p));
+
+  PetscCall(DMRestoreGlobalVector(dm, &rhs));
+  PetscCall(KSPDestroy(&ksp));
+  PetscCall(MatDestroy(&D_f));
+  PetscCall(MatDestroy(&D_p));
+  PetscCall(MatDestroy(&PD_p));
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+
+static PetscErrorCode DMSwarmProjectGradientFields_Plex_Internal(DM sw, DM dm, PetscInt Nf, const char *fieldnames[], Vec vec, ScatterMode mode)
+{
+  PetscDS  ds;
+  Vec      u;
+  PetscInt f = 0, cdim, bs, *Nc;
+
+  PetscFunctionBegin;
+  PetscCall(DMGetCoordinateDim(dm, &cdim));
+  PetscCall(DMGetDS(dm, &ds));
+  PetscCall(PetscDSGetComponents(ds, &Nc));
+  PetscCall(PetscCitationsRegister(SwarmProjCitation, &SwarmProjcite));
+  PetscCheck(Nf == 1, PetscObjectComm((PetscObject)sw), PETSC_ERR_SUP, "Currently supported only for a single field");
+  PetscCall(DMSwarmVectorDefineFields(sw, Nf, fieldnames));
+  PetscCall(DMSwarmCreateGlobalVectorFromField(sw, fieldnames[f], &u));
+  PetscCall(VecGetBlockSize(u, &bs));
+  PetscCheck(Nc[f] * cdim == bs, PetscObjectComm((PetscObject)sw), PETSC_ERR_SUP, "Field %" PetscInt_FMT " components %" PetscInt_FMT " * %" PetscInt_FMT " coordinate dim != %" PetscInt_FMT " blocksize for swarm field %s", f, Nc[f], cdim, bs, fieldnames[f]);
+  if (mode == SCATTER_FORWARD) {
+    PetscCall(DMSwarmProjectGradientField_Conservative_PLEX(sw, dm, u, vec));
+  } else {
+    PetscCall(DMSwarmProjectGradientParticles_Conservative_PLEX(sw, dm, u, vec));
+  }
+  PetscCall(DMSwarmDestroyGlobalVectorFromField(sw, fieldnames[0], &u));
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+
+PetscErrorCode DMSwarmProjectGradientFields(DM sw, DM dm, PetscInt nfields, const char *fieldnames[], Vec fields[], ScatterMode mode)
+{
+  PetscBool isPlex;
+  MPI_Comm  comm;
+
+  PetscFunctionBegin;
+  DMSWARMPICVALID(sw);
+  PetscCall(PetscObjectGetComm((PetscObject)sw, &comm));
+  if (!dm) PetscCall(DMSwarmGetCellDM(sw, &dm));
+  PetscCall(PetscObjectTypeCompare((PetscObject)dm, DMPLEX, &isPlex));
+  if (isPlex) {
+    PetscInt Nf;
+
+    PetscCall(DMGetNumFields(dm, &Nf));
+    PetscCheck(Nf == nfields, comm, PETSC_ERR_ARG_WRONG, "Number of DM fields %" PetscInt_FMT " != %" PetscInt_FMT " number of requested Swarm fields", Nf, nfields);
+    PetscCall(DMSwarmProjectGradientFields_Plex_Internal(sw, dm, nfields, fieldnames, fields[0], mode));
+  } else SETERRQ(PetscObjectComm((PetscObject)sw), PETSC_ERR_SUP, "Only supported for cell DMs of type DMPLEX");
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+
 /*
   InitializeParticles_Regular - Initialize a regular grid of particles in each cell
 
