@@ -160,7 +160,6 @@ PETSC_INTERN PetscErrorCode MatSetValues_MPIAIJ(Mat, PetscInt, const PetscInt[],
 PETSC_INTERN PetscErrorCode MatSetValues_MPIAIJ_CopyFromCSRFormat(Mat, const PetscInt[], const PetscInt[], const PetscScalar[]);
 PETSC_INTERN PetscErrorCode MatSetValues_MPIAIJ_CopyFromCSRFormat_Symbolic(Mat, const PetscInt[], const PetscInt[]);
 PETSC_INTERN PetscErrorCode MatSetOption_MPIAIJ(Mat, MatOption, PetscBool);
-PETSC_INTERN PetscErrorCode MatSetMPIAIJWithSplitSeqAIJ(Mat, Mat, Mat, PetscInt *);
 
 PETSC_INTERN PetscErrorCode MatTransposeMatMultSymbolic_MPIAIJ_MPIAIJ_nonscalable(Mat, Mat, PetscReal, Mat);
 PETSC_INTERN PetscErrorCode MatTransposeMatMultSymbolic_MPIAIJ_MPIAIJ(Mat, Mat, PetscReal, Mat);
@@ -183,6 +182,8 @@ PETSC_INTERN PetscErrorCode MatSetSeqMats_MPIAIJ(Mat, IS, IS, IS, MatStructure,
 
 PETSC_INTERN PetscErrorCode MatSetPreallocationCOO_MPIAIJ(Mat, PetscCount, PetscInt[], PetscInt[]);
 
+PETSC_INTERN PetscErrorCode MatGetCurrentMemType_MPIAIJ(Mat, PetscMemType *);
+
 /* compute apa = A[i,:]*P = Ad[i,:]*P_loc + Ao*[i,:]*P_oth using sparse axpy */
 #define AProw_scalable(i, ad, ao, p_loc, p_oth, api, apj, apa) \
   do { \
@@ -192,8 +193,8 @@ PETSC_INTERN PetscErrorCode MatSetPreallocationCOO_MPIAIJ(Mat, PetscCount, Petsc
     /* diagonal portion of A */ \
     _ai  = ad->i; \
     _anz = _ai[i + 1] - _ai[i]; \
-    _aj  = ad->j + _ai[i]; \
-    _aa  = ad->a + _ai[i]; \
+    _aj  = PetscSafePointerPlusOffset(ad->j, _ai[i]); \
+    _aa  = PetscSafePointerPlusOffset(ad->a, _ai[i]); \
     for (_j = 0; _j < _anz; _j++) { \
       _row = _aj[_j]; \
       _pi  = p_loc->i; \
@@ -214,8 +215,8 @@ PETSC_INTERN PetscErrorCode MatSetPreallocationCOO_MPIAIJ(Mat, PetscCount, Petsc
     if (p_oth) { \
       _ai  = ao->i; \
       _anz = _ai[i + 1] - _ai[i]; \
-      _aj  = ao->j + _ai[i]; \
-      _aa  = ao->a + _ai[i]; \
+      _aj  = PetscSafePointerPlusOffset(ao->j, _ai[i]); \
+      _aa  = PetscSafePointerPlusOffset(ao->a, _ai[i]); \
       for (_j = 0; _j < _anz; _j++) { \
         _row = _aj[_j]; \
         _pi  = p_oth->i; \
