@@ -527,7 +527,7 @@ static PetscErrorCode MatMultTransposeAdd_BlockMat(Mat A, Vec x, Vec y, Vec z)
 }
 
 /*
-     Adds diagonal pointers to sparse matrix structure.
+     Adds diagonal pointers to sparse matrix nonzero structure.
 */
 static PetscErrorCode MatMarkDiagonal_BlockMat(Mat A)
 {
@@ -747,12 +747,12 @@ static struct _MatOps MatOps_Values = {MatSetValues_BlockMat,
                                        NULL,
                                        NULL,
                                        NULL,
-                                       NULL,
+                                       MatLoad_BlockMat,
                                        /* 79*/ NULL,
                                        NULL,
                                        NULL,
                                        NULL,
-                                       MatLoad_BlockMat,
+                                       NULL,
                                        /* 84*/ NULL,
                                        NULL,
                                        NULL,
@@ -812,18 +812,6 @@ static struct _MatOps MatOps_Values = {MatSetValues_BlockMat,
                                        NULL,
                                        NULL,
                                        NULL,
-                                       NULL,
-                                       /*144*/ NULL,
-                                       NULL,
-                                       NULL,
-                                       NULL,
-                                       NULL,
-                                       NULL,
-                                       /*150*/ NULL,
-                                       NULL,
-                                       NULL,
-                                       NULL,
-                                       NULL,
                                        NULL};
 
 /*@C
@@ -886,13 +874,12 @@ static PetscErrorCode MatBlockMatSetPreallocation_BlockMat(Mat A, PetscInt bs, P
   PetscCall(VecCreateSeq(PETSC_COMM_SELF, bs, &bmat->left));
 
   if (!bmat->imax) PetscCall(PetscMalloc2(A->rmap->n, &bmat->imax, A->rmap->n, &bmat->ilen));
-  if (PetscLikely(nnz)) {
-    nz = 0;
-    for (i = 0; i < A->rmap->n / A->rmap->bs; i++) {
-      bmat->imax[i] = nnz[i];
-      nz += nnz[i];
-    }
-  } else SETERRQ(PETSC_COMM_SELF, PETSC_ERR_SUP, "Currently requires block row by row preallocation");
+  PetscCheck(PetscLikely(nnz), PETSC_COMM_SELF, PETSC_ERR_SUP, "Currently requires block row by row preallocation");
+  nz = 0;
+  for (i = 0; i < A->rmap->n / A->rmap->bs; i++) {
+    bmat->imax[i] = nnz[i];
+    nz += nnz[i];
+  }
 
   /* bmat->ilen will count nonzeros in each row so far. */
   PetscCall(PetscArrayzero(bmat->ilen, bmat->mbs));
