@@ -19,11 +19,11 @@ static PetscMPIInt Petsc_Elemental_keyval = MPI_KEYVAL_INVALID;
 static PetscErrorCode MatView_Elemental(Mat A, PetscViewer viewer)
 {
   Mat_Elemental *a = (Mat_Elemental *)A->data;
-  PetscBool      iascii;
+  PetscBool      isascii;
 
   PetscFunctionBegin;
-  PetscCall(PetscObjectTypeCompare((PetscObject)viewer, PETSCVIEWERASCII, &iascii));
-  if (iascii) {
+  PetscCall(PetscObjectTypeCompare((PetscObject)viewer, PETSCVIEWERASCII, &isascii));
+  if (isascii) {
     PetscViewerFormat format;
     PetscCall(PetscViewerGetFormat(viewer, &format));
     if (format == PETSC_VIEWER_ASCII_INFO) {
@@ -68,14 +68,14 @@ static PetscErrorCode MatGetInfo_Elemental(Mat A, MatInfoType flag, MatInfo *inf
     info->nz_allocated = (*a->emat).AllocatedMemory(); /* locally allocated */
     info->nz_used      = info->nz_allocated;
   } else if (flag == MAT_GLOBAL_MAX) {
-    //PetscCall(MPIU_Allreduce(isend,irecv,5,MPIU_REAL,MPIU_MAX,PetscObjectComm((PetscObject)matin)));
+    //PetscCallMPI(MPIU_Allreduce(isend,irecv,5,MPIU_REAL,MPIU_MAX,PetscObjectComm((PetscObject)matin)));
     /* see MatGetInfo_MPIAIJ() for getting global info->nz_allocated! */
     //SETERRQ(PETSC_COMM_SELF,PETSC_ERR_SUP," MAT_GLOBAL_MAX not written yet");
   } else if (flag == MAT_GLOBAL_SUM) {
     //SETERRQ(PETSC_COMM_SELF,PETSC_ERR_SUP," MAT_GLOBAL_SUM not written yet");
     info->nz_allocated = (*a->emat).AllocatedMemory(); /* locally allocated */
     info->nz_used      = info->nz_allocated;           /* assume Elemental does accurate allocation */
-    //PetscCall(MPIU_Allreduce(isend,irecv,1,MPIU_REAL,MPIU_SUM,PetscObjectComm((PetscObject)A)));
+    //PetscCallMPI(MPIU_Allreduce(isend,irecv,1,MPIU_REAL,MPIU_SUM,PetscObjectComm((PetscObject)A)));
     //PetscPrintf(PETSC_COMM_SELF,"    ... [%d] locally allocated %g\n",rank,info->nz_allocated);
   }
 
@@ -95,18 +95,11 @@ static PetscErrorCode MatSetOption_Elemental(Mat A, MatOption op, PetscBool flg)
 
   PetscFunctionBegin;
   switch (op) {
-  case MAT_NEW_NONZERO_LOCATIONS:
-  case MAT_NEW_NONZERO_LOCATION_ERR:
-  case MAT_NEW_NONZERO_ALLOCATION_ERR:
-  case MAT_SYMMETRIC:
-  case MAT_SORTED_FULL:
-  case MAT_HERMITIAN:
-    break;
   case MAT_ROW_ORIENTED:
     a->roworiented = flg;
     break;
   default:
-    SETERRQ(PETSC_COMM_SELF, PETSC_ERR_SUP, "unknown option %s", MatOptions[op]);
+    break;
   }
   PetscFunctionReturn(PETSC_SUCCESS);
 }
@@ -394,7 +387,7 @@ static PetscErrorCode MatMatMultNumeric_Elemental_MPIDense(Mat A, Mat B, Mat C)
 
   PetscFunctionBegin;
   PetscCall(MatConvert(B, MATELEMENTAL, MAT_INITIAL_MATRIX, &Be));
-  PetscCall(MatMatMult(A, Be, MAT_INITIAL_MATRIX, PETSC_DEFAULT, &Ce));
+  PetscCall(MatMatMult(A, Be, MAT_INITIAL_MATRIX, PETSC_DETERMINE, &Ce));
   PetscCall(MatConvert(Ce, MATMPIDENSE, MAT_REUSE_MATRIX, &C));
   PetscCall(MatDestroy(&Be));
   PetscCall(MatDestroy(&Ce));
@@ -775,7 +768,7 @@ static PetscErrorCode MatGetFactor_elemental_elemental(Mat A, MatFactorType ftyp
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PETSC_EXTERN PetscErrorCode MatSolverTypeRegister_Elemental(void)
+PETSC_INTERN PetscErrorCode MatSolverTypeRegister_Elemental(void)
 {
   PetscFunctionBegin;
   PetscCall(MatSolverTypeRegister(MATSOLVERELEMENTAL, MATELEMENTAL, MAT_FACTOR_LU, MatGetFactor_elemental_elemental));
@@ -1079,7 +1072,7 @@ static PetscErrorCode MatDestroy_Elemental(Mat A)
 {
   Mat_Elemental      *a = (Mat_Elemental *)A->data;
   Mat_Elemental_Grid *commgrid;
-  PetscBool           flg;
+  PetscMPIInt         iflg;
   MPI_Comm            icomm;
 
   PetscFunctionBegin;
@@ -1089,7 +1082,7 @@ static PetscErrorCode MatDestroy_Elemental(Mat A)
 
   El::mpi::Comm cxxcomm(PetscObjectComm((PetscObject)A));
   PetscCall(PetscCommDuplicate(cxxcomm.comm, &icomm, nullptr));
-  PetscCallMPI(MPI_Comm_get_attr(icomm, Petsc_Elemental_keyval, (void **)&commgrid, (int *)&flg));
+  PetscCallMPI(MPI_Comm_get_attr(icomm, Petsc_Elemental_keyval, (void **)&commgrid, &iflg));
   if (--commgrid->grid_refct == 0) {
     delete commgrid->grid;
     PetscCall(PetscFree(commgrid));
@@ -1247,57 +1240,57 @@ static struct _MatOps MatOps_Values = {MatSetValues_Elemental,
                                        nullptr,
                                        nullptr,
                                        /*69*/ nullptr,
-                                       nullptr,
                                        MatConvert_Elemental_Dense,
                                        nullptr,
                                        nullptr,
+                                       nullptr,
                                        /*74*/ nullptr,
                                        nullptr,
                                        nullptr,
                                        nullptr,
-                                       nullptr,
+                                       MatLoad_Elemental,
                                        /*79*/ nullptr,
                                        nullptr,
                                        nullptr,
                                        nullptr,
-                                       MatLoad_Elemental,
+                                       nullptr,
                                        /*84*/ nullptr,
-                                       nullptr,
-                                       nullptr,
-                                       nullptr,
-                                       nullptr,
-                                       /*89*/ nullptr,
-                                       nullptr,
                                        MatMatMultNumeric_Elemental,
                                        nullptr,
                                        nullptr,
-                                       /*94*/ nullptr,
-                                       nullptr,
-                                       nullptr,
                                        MatMatTransposeMultNumeric_Elemental,
-                                       nullptr,
-                                       /*99*/ MatProductSetFromOptions_Elemental,
+                                       /*89*/ nullptr,
+                                       MatProductSetFromOptions_Elemental,
                                        nullptr,
                                        nullptr,
                                        MatConjugate_Elemental,
-                                       nullptr,
-                                       /*104*/ nullptr,
+                                       /*94*/ nullptr,
                                        nullptr,
                                        nullptr,
                                        nullptr,
                                        nullptr,
-                                       /*109*/ MatMatSolve_Elemental,
+                                       /*99*/ nullptr,
+                                       MatMatSolve_Elemental,
                                        nullptr,
                                        nullptr,
                                        nullptr,
-                                       MatMissingDiagonal_Elemental,
+                                       /*104*/ MatMissingDiagonal_Elemental,
+                                       nullptr,
+                                       nullptr,
+                                       nullptr,
+                                       nullptr,
+                                       /*109*/ nullptr,
+                                       nullptr,
+                                       MatHermitianTranspose_Elemental,
+                                       nullptr,
+                                       nullptr,
                                        /*114*/ nullptr,
                                        nullptr,
                                        nullptr,
                                        nullptr,
                                        nullptr,
                                        /*119*/ nullptr,
-                                       MatHermitianTranspose_Elemental,
+                                       nullptr,
                                        nullptr,
                                        nullptr,
                                        nullptr,
@@ -1320,15 +1313,6 @@ static struct _MatOps MatOps_Values = {MatSetValues_Elemental,
                                        /*140*/ nullptr,
                                        nullptr,
                                        nullptr,
-                                       nullptr,
-                                       nullptr,
-                                       /*145*/ nullptr,
-                                       nullptr,
-                                       nullptr,
-                                       nullptr,
-                                       nullptr,
-                                       /*150*/ nullptr,
-                                       nullptr,
                                        nullptr};
 
 /*MC
@@ -1357,7 +1341,8 @@ M*/
 PETSC_EXTERN PetscErrorCode MatCreate_Elemental(Mat A)
 {
   Mat_Elemental      *a;
-  PetscBool           flg, flg1;
+  PetscBool           flg;
+  PetscMPIInt         iflg;
   Mat_Elemental_Grid *commgrid;
   MPI_Comm            icomm;
   PetscInt            optv1;
@@ -1374,18 +1359,18 @@ PETSC_EXTERN PetscErrorCode MatCreate_Elemental(Mat A)
 
   /* Grid needs to be shared between multiple Mats on the same communicator, implement by attribute caching on the MPI_Comm */
   if (Petsc_Elemental_keyval == MPI_KEYVAL_INVALID) {
-    PetscCallMPI(MPI_Comm_create_keyval(MPI_COMM_NULL_COPY_FN, MPI_COMM_NULL_DELETE_FN, &Petsc_Elemental_keyval, (void *)0));
+    PetscCallMPI(MPI_Comm_create_keyval(MPI_COMM_NULL_COPY_FN, MPI_COMM_NULL_DELETE_FN, &Petsc_Elemental_keyval, nullptr));
     PetscCall(PetscCitationsRegister(ElementalCitation, &ElementalCite));
   }
   PetscCall(PetscCommDuplicate(cxxcomm.comm, &icomm, NULL));
-  PetscCallMPI(MPI_Comm_get_attr(icomm, Petsc_Elemental_keyval, (void **)&commgrid, (int *)&flg));
-  if (!flg) {
+  PetscCallMPI(MPI_Comm_get_attr(icomm, Petsc_Elemental_keyval, (void **)&commgrid, &iflg));
+  if (!iflg) {
     PetscCall(PetscNew(&commgrid));
 
     PetscOptionsBegin(PetscObjectComm((PetscObject)A), ((PetscObject)A)->prefix, "Elemental Options", "Mat");
     /* displayed default grid sizes (CommSize,1) are set by us arbitrarily until El::Grid() is called */
-    PetscCall(PetscOptionsInt("-mat_elemental_grid_height", "Grid Height", "None", El::mpi::Size(cxxcomm), &optv1, &flg1));
-    if (flg1) {
+    PetscCall(PetscOptionsInt("-mat_elemental_grid_height", "Grid Height", "None", El::mpi::Size(cxxcomm), &optv1, &flg));
+    if (flg) {
       PetscCheck((El::mpi::Size(cxxcomm) % optv1) == 0, PetscObjectComm((PetscObject)A), PETSC_ERR_ARG_INCOMP, "Grid Height %" PetscInt_FMT " must evenly divide CommSize %" PetscInt_FMT, optv1, (PetscInt)El::mpi::Size(cxxcomm));
       commgrid->grid = new El::Grid(cxxcomm, optv1); /* use user-provided grid height */
     } else {
