@@ -420,8 +420,10 @@ static PetscErrorCode MatHYPRE_CreateCOOMat(Mat mat)
     matType = MATAIJHIPSPARSE;
   #elif defined(HYPRE_USING_CUDA)
     matType = MATAIJCUSPARSE;
+  #elif defined(HYPRE_USING_SYCL) && defined(PETSC_HAVE_KOKKOS_KERNELS)
+    matType = MATAIJKOKKOS;
   #else
-    SETERRQ(comm, PETSC_ERR_SUP, "Do not know the HYPRE device");
+    SETERRQ(comm, PETSC_ERR_SUP, "No HYPRE device available. Suggest re-installing with Kokkos Kernels");
   #endif
   }
 #endif
@@ -595,12 +597,20 @@ static PetscErrorCode MatSetValuesCOOFromCSRMatrix_Private(Mat A, hypre_CSRMatri
 
 PETSC_INTERN PetscErrorCode MatConvert_AIJ_HYPRE(Mat A, MatType type, MatReuse reuse, Mat *B)
 {
-  MPI_Comm   comm = PetscObjectComm((PetscObject)A);
-  Mat        M = NULL, dH = NULL, oH = NULL, dA = NULL, oA = NULL;
-  PetscBool  ismpiaij, issbaij, isbaij;
-  Mat_HYPRE *hA;
+  MPI_Comm     comm = PetscObjectComm((PetscObject)A);
+  Mat          M = NULL, dH = NULL, oH = NULL, dA = NULL, oA = NULL;
+  PetscBool    ismpiaij, issbaij, isbaij, boundtocpu = PETSC_TRUE;
+  Mat_HYPRE   *hA;
+  PetscMemType memtype = PETSC_MEMTYPE_HOST;
 
   PetscFunctionBegin;
+  if (PetscDefined(HAVE_HYPRE_DEVICE)) {
+    PetscCall(MatGetCurrentMemType(A, &memtype));
+    PetscHYPREInitialize();
+    boundtocpu = PetscMemTypeHost(memtype) ? PETSC_TRUE : PETSC_FALSE;
+    PetscCallExternal(HYPRE_SetMemoryLocation, boundtocpu ? HYPRE_MEMORY_HOST : HYPRE_MEMORY_DEVICE);
+  }
+
   PetscCall(PetscObjectTypeCompareAny((PetscObject)A, &issbaij, MATSEQSBAIJ, MATMPIBAIJ, ""));
   PetscCall(PetscObjectTypeCompareAny((PetscObject)A, &isbaij, MATSEQBAIJ, MATMPIBAIJ, ""));
   if (isbaij || issbaij) { /* handle BAIJ and SBAIJ */
@@ -620,21 +630,12 @@ PETSC_INTERN PetscErrorCode MatConvert_AIJ_HYPRE(Mat A, MatType type, MatReuse r
       PetscCall(MatConvert(A, newtype, MAT_INPLACE_MATRIX, &A));
       PetscCall(MatConvert(A, MATHYPRE, MAT_INPLACE_MATRIX, &A));
     }
+#if defined(PETSC_HAVE_DEVICE)
+    (*B)->boundtocpu = boundtocpu;
+#endif
     PetscFunctionReturn(PETSC_SUCCESS);
   }
 
-#if defined(PETSC_HAVE_HYPRE_DEVICE)
-  {
-    PetscBool isaij;
-    // Hypre defaults to GPU when configured with GPU. We make it default to the memory location associated with the PETSc matrix,
-    // i.e., when A is a host matrix, Hypre will be on the host; otherwise, when A is of type aijcusparse, aijhipsarse, aijkokkos etc,
-    // Hypre will be on the device.
-    PetscCall(PetscObjectTypeCompareAny((PetscObject)A, &isaij, MATSEQAIJ, MATMPIAIJ, ""));
-    PetscHYPREInitialize();
-    PetscCallExternal(HYPRE_SetMemoryLocation, isaij ? HYPRE_MEMORY_HOST : HYPRE_MEMORY_DEVICE);
-  }
-#endif
-
   dA = A;
   PetscCall(PetscObjectBaseTypeCompare((PetscObject)A, MATMPIAIJ, &ismpiaij));
   if (ismpiaij) PetscCall(MatMPIAIJGetSeqAIJ(A, &dA, &oA, NULL));
@@ -696,6 +697,9 @@ PETSC_INTERN PetscErrorCode MatConvert_AIJ_HYPRE(Mat A, MatType type, MatReuse r
   }
 
   if (reuse == MAT_INPLACE_MATRIX) PetscCall(MatHeaderReplace(A, &M));
+#if defined(PETSC_HAVE_DEVICE)
+  (*B)->boundtocpu = boundtocpu;
+#endif
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
@@ -807,8 +811,8 @@ static PetscErrorCode MatAIJGetParCSR_Private(Mat A, hypre_ParCSRMatrix **hA)
   PetscCall(PetscObjectBaseTypeCompare((PetscObject)A, MATMPIAIJ, &ismpiaij));
   PetscCall(PetscObjectBaseTypeCompare((PetscObject)A, MATSEQAIJ, &isseqaij));
   PetscCheck(ismpiaij || isseqaij, comm, PETSC_ERR_SUP, "Unsupported type %s", ((PetscObject)A)->type_name);
-  PetscCall(PetscObjectTypeCompareAny((PetscObject)A, &iscuda, MATSEQAIJHIPSPARSE, MATMPIAIJCUSPARSE, ""));
-  PetscCall(PetscObjectTypeCompareAny((PetscObject)A, &iship, MATSEQAIJCUSPARSE, MATMPIAIJHIPSPARSE, ""));
+  PetscCall(PetscObjectTypeCompareAny((PetscObject)A, &iscuda, MATSEQAIJCUSPARSE, MATMPIAIJCUSPARSE, ""));
+  PetscCall(PetscObjectTypeCompareAny((PetscObject)A, &iship, MATSEQAIJHIPSPARSE, MATMPIAIJHIPSPARSE, ""));
   PetscHYPREInitialize();
   if (ismpiaij) {
     Mat_MPIAIJ *a = (Mat_MPIAIJ *)A->data;
@@ -945,15 +949,16 @@ static PetscErrorCode MatAIJRestoreParCSR_Private(Mat A, hypre_ParCSRMatrix **hA
 {
   hypre_CSRMatrix *hdiag, *hoffd;
   PetscBool        ismpiaij, sameint = (PetscBool)(sizeof(PetscInt) == sizeof(HYPRE_Int));
-#if defined(PETSC_HAVE_HYPRE_DEVICE)
-  PetscBool iscuda = PETSC_FALSE;
-#endif
+  PetscBool        iscuda, iship;
 
   PetscFunctionBegin;
   PetscCall(PetscObjectBaseTypeCompare((PetscObject)A, MATMPIAIJ, &ismpiaij));
-#if defined(PETSC_HAVE_HYPRE_DEVICE)
   PetscCall(PetscObjectTypeCompareAny((PetscObject)A, &iscuda, MATSEQAIJCUSPARSE, MATMPIAIJCUSPARSE, ""));
+  PetscCall(PetscObjectTypeCompareAny((PetscObject)A, &iship, MATSEQAIJHIPSPARSE, MATMPIAIJHIPSPARSE, ""));
+#if defined(HYPRE_USING_CUDA) && defined(PETSC_HAVE_CUDA)
   if (iscuda) sameint = PETSC_TRUE;
+#elif defined(HYPRE_USING_HIP) && defined(PETSC_HAVE_HIP)
+  if (iship) sameint = PETSC_TRUE;
 #endif
   hdiag = hypre_ParCSRMatrixDiag(*hA);
   hoffd = hypre_ParCSRMatrixOffd(*hA);
@@ -2403,6 +2408,16 @@ static PetscErrorCode MatSetValuesCOO_HYPRE(Mat mat, const PetscScalar v[], Inse
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
+static PetscErrorCode MatGetCurrentMemType_HYPRE(Mat A, PetscMemType *m)
+{
+  PetscBool petsconcpu;
+
+  PetscFunctionBegin;
+  PetscCall(MatBoundToCPU(A, &petsconcpu));
+  *m = petsconcpu ? PETSC_MEMTYPE_HOST : PETSC_MEMTYPE_DEVICE;
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+
 /*MC
    MATHYPRE - "hypre" - A matrix type to be used for sequential and parallel sparse matrices
           based on the hypre IJ interface.
@@ -2411,7 +2426,6 @@ static PetscErrorCode MatSetValuesCOO_HYPRE(Mat mat, const PetscScalar v[], Inse
 
 .seealso: [](ch_matrices), `Mat`, `MatCreate()`, `MatHYPRESetPreallocation`
 M*/
-
 PETSC_EXTERN PetscErrorCode MatCreate_HYPRE(Mat B)
 {
   Mat_HYPRE *hB;
@@ -2453,6 +2467,7 @@ PETSC_EXTERN PetscErrorCode MatCreate_HYPRE(Mat B)
   B->ops->getdiagonal           = MatGetDiagonal_HYPRE;
   B->ops->axpy                  = MatAXPY_HYPRE;
   B->ops->productsetfromoptions = MatProductSetFromOptions_HYPRE;
+  B->ops->getcurrentmemtype     = MatGetCurrentMemType_HYPRE;
 #if defined(PETSC_HAVE_HYPRE_DEVICE)
   B->ops->bindtocpu = MatBindToCPU_HYPRE;
   /* Get hypre's default memory location. Users can control this using the corresponding HYPRE_SetMemoryLocation API */
