@@ -228,9 +228,8 @@ static PetscErrorCode MatConvert_NormalHermitian_AIJ(Mat A, MatType newtype, Mat
   }
   PetscCall(MatProductNumeric(B));
   if (PetscDefined(USE_COMPLEX)) PetscCall(MatDestroy(&conjugate));
-  if (reuse == MAT_INPLACE_MATRIX) {
-    PetscCall(MatHeaderReplace(A, &B));
-  } else if (reuse == MAT_INITIAL_MATRIX) *newmat = B;
+  if (reuse == MAT_INPLACE_MATRIX) PetscCall(MatHeaderReplace(A, &B));
+  else if (reuse == MAT_INITIAL_MATRIX) *newmat = B;
   PetscCall(MatConvert(*newmat, MATAIJ, MAT_INPLACE_MATRIX, newmat));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
@@ -261,7 +260,7 @@ static PetscErrorCode MatConvert_NormalHermitian_HYPRE(Mat A, MatType type, MatR
 M*/
 
 /*@
-  MatCreateNormalHermitian - Creates a new matrix object `MATNORMALHERMITIAN` that behaves like (A*)'*A.
+  MatCreateNormalHermitian - Creates a new matrix object `MATNORMALHERMITIAN` that behaves like $A^* A$.
 
   Collective
 
@@ -269,14 +268,16 @@ M*/
 . A - the (possibly rectangular complex) matrix
 
   Output Parameter:
-. N - the matrix that represents (A*)'*A
+. N - the matrix that represents $ A^* A$
 
   Level: intermediate
 
   Note:
-  The product (A*)'*A is NOT actually formed! Rather the new matrix
+  The product $ A^* A$ is NOT actually formed! Rather the new matrix
   object performs the matrix-vector product, `MatMult()`, by first multiplying by
-  A and then (A*)'
+  $A$ and then $A^*$
+
+  If `MatGetFactor()` is called on this matrix with `MAT_FACTOR_QR` then the inner matrix `A` is used for the factorization
 
 .seealso: [](ch_matrices), `Mat`, `MATNORMAL`, `MATNORMALHERMITIAN`, `MatNormalHermitianGetMat()`
 @*/
