@@ -191,7 +191,7 @@ PetscErrorCode MatDestroy_SeqSBAIJ(Mat A)
   PetscCall(ISDestroy(&a->col));
   PetscCall(ISDestroy(&a->icol));
   PetscCall(PetscFree(a->idiag));
-  PetscCall(PetscFree(a->inode.size));
+  PetscCall(PetscFree(a->inode.size_csr));
   if (a->free_imax_ilen) PetscCall(PetscFree2(a->imax, a->ilen));
   PetscCall(PetscFree(a->solve_work));
   PetscCall(PetscFree(a->sor_work));
@@ -541,13 +541,13 @@ static PetscErrorCode MatView_SeqSBAIJ_Draw(Mat A, PetscViewer viewer)
 
 PetscErrorCode MatView_SeqSBAIJ(Mat A, PetscViewer viewer)
 {
-  PetscBool iascii, isbinary, isdraw;
+  PetscBool isascii, isbinary, isdraw;
 
   PetscFunctionBegin;
-  PetscCall(PetscObjectTypeCompare((PetscObject)viewer, PETSCVIEWERASCII, &iascii));
+  PetscCall(PetscObjectTypeCompare((PetscObject)viewer, PETSCVIEWERASCII, &isascii));
   PetscCall(PetscObjectTypeCompare((PetscObject)viewer, PETSCVIEWERBINARY, &isbinary));
   PetscCall(PetscObjectTypeCompare((PetscObject)viewer, PETSCVIEWERDRAW, &isdraw));
-  if (iascii) {
+  if (isascii) {
     PetscCall(MatView_SeqSBAIJ_ASCII(A, viewer));
   } else if (isbinary) {
     PetscCall(MatView_SeqSBAIJ_Binary(A, viewer));
@@ -658,8 +658,8 @@ PetscErrorCode MatSetValuesBlocked_SeqSBAIJ(Mat A, PetscInt m, const PetscInt im
       col = in[l];
       PetscCheck(col < a->nbs, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Block index column too large %" PetscInt_FMT " max %" PetscInt_FMT, col, a->nbs - 1);
       if (col < row) {
-        if (a->ignore_ltriangular) continue; /* ignore lower triangular block */
-        else SETERRQ(PETSC_COMM_SELF, PETSC_ERR_USER, "Lower triangular value cannot be set for sbaij format. Ignoring these values, run with -mat_ignore_lower_triangular or call MatSetOption(mat,MAT_IGNORE_LOWER_TRIANGULAR,PETSC_TRUE)");
+        PetscCheck(a->ignore_ltriangular, PETSC_COMM_SELF, PETSC_ERR_USER, "Lower triangular value cannot be set for sbaij format. Ignoring these values, run with -mat_ignore_lower_triangular or call MatSetOption(mat,MAT_IGNORE_LOWER_TRIANGULAR,PETSC_TRUE)");
+        continue; /* ignore lower triangular block */
       }
       if (roworiented) value = v + k * (stepval + bs) * bs + l * bs;
       else value = v + l * (stepval + bs) * bs + k * bs;
@@ -822,8 +822,8 @@ PetscErrorCode MatSetValues_SeqSBAIJ(Mat A, PetscInt m, const PetscInt im[], Pet
       bcol = col / bs; /* block col number */
 
       if (brow > bcol) {
-        if (a->ignore_ltriangular) continue; /* ignore lower triangular values */
-        else SETERRQ(PETSC_COMM_SELF, PETSC_ERR_USER, "Lower triangular value cannot be set for sbaij format. Ignoring these values, run with -mat_ignore_lower_triangular or call MatSetOption(mat,MAT_IGNORE_LOWER_TRIANGULAR,PETSC_TRUE)");
+        PetscCheck(a->ignore_ltriangular, PETSC_COMM_SELF, PETSC_ERR_USER, "Lower triangular value cannot be set for sbaij format. Ignoring these values, run with -mat_ignore_lower_triangular or call MatSetOption(mat,MAT_IGNORE_LOWER_TRIANGULAR,PETSC_TRUE)");
+        continue; /* ignore lower triangular values */
       }
 
       ridx = row % bs;
@@ -1317,52 +1317,52 @@ static struct _MatOps MatOps_Values = {MatSetValues_SeqSBAIJ,
                                        NULL,
                                        NULL,
                                        NULL,
-                                       NULL,
-                                       /* 69*/ MatGetRowMaxAbs_SeqSBAIJ,
-                                       NULL,
+                                       MatGetRowMaxAbs_SeqSBAIJ,
+                                       /* 69*/ NULL,
                                        MatConvert_MPISBAIJ_Basic,
                                        NULL,
                                        NULL,
+                                       NULL,
                                        /* 74*/ NULL,
                                        NULL,
                                        NULL,
-                                       NULL,
-                                       NULL,
-                                       /* 79*/ NULL,
-                                       NULL,
-                                       NULL,
                                        MatGetInertia_SeqSBAIJ,
                                        MatLoad_SeqSBAIJ,
-                                       /* 84*/ NULL,
+                                       /* 79*/ NULL,
                                        NULL,
                                        MatIsStructurallySymmetric_SeqSBAIJ,
                                        NULL,
                                        NULL,
+                                       /* 84*/ NULL,
+                                       NULL,
+                                       NULL,
+                                       NULL,
+                                       NULL,
                                        /* 89*/ NULL,
                                        NULL,
                                        NULL,
                                        NULL,
-                                       NULL,
+                                       MatConjugate_SeqSBAIJ,
                                        /* 94*/ NULL,
                                        NULL,
-                                       NULL,
-                                       NULL,
-                                       NULL,
-                                       /* 99*/ NULL,
-                                       NULL,
-                                       NULL,
-                                       MatConjugate_SeqSBAIJ,
-                                       NULL,
-                                       /*104*/ NULL,
                                        MatRealPart_SeqSBAIJ,
                                        MatImaginaryPart_SeqSBAIJ,
                                        MatGetRowUpperTriangular_SeqSBAIJ,
-                                       MatRestoreRowUpperTriangular_SeqSBAIJ,
+                                       /* 99*/ MatRestoreRowUpperTriangular_SeqSBAIJ,
+                                       NULL,
+                                       NULL,
+                                       NULL,
+                                       NULL,
+                                       /*104*/ MatMissingDiagonal_SeqSBAIJ,
+                                       NULL,
+                                       NULL,
+                                       NULL,
+                                       NULL,
                                        /*109*/ NULL,
                                        NULL,
                                        NULL,
                                        NULL,
-                                       MatMissingDiagonal_SeqSBAIJ,
+                                       NULL,
                                        /*114*/ NULL,
                                        NULL,
                                        NULL,
@@ -1376,36 +1376,23 @@ static struct _MatOps MatOps_Values = {MatSetValues_SeqSBAIJ,
                                        /*124*/ NULL,
                                        NULL,
                                        NULL,
-                                       NULL,
+                                       MatSetBlockSizes_Default,
                                        NULL,
                                        /*129*/ NULL,
                                        NULL,
-                                       NULL,
+                                       MatCreateMPIMatConcatenateSeqMat_SeqSBAIJ,
                                        NULL,
                                        NULL,
                                        /*134*/ NULL,
                                        NULL,
                                        NULL,
-                                       NULL,
-                                       NULL,
-                                       /*139*/ MatSetBlockSizes_Default,
-                                       NULL,
-                                       NULL,
-                                       NULL,
-                                       NULL,
-                                       /*144*/ MatCreateMPIMatConcatenateSeqMat_SeqSBAIJ,
-                                       NULL,
-                                       NULL,
-                                       NULL,
-                                       NULL,
-                                       NULL,
-                                       /*150*/ NULL,
                                        MatEliminateZeros_SeqSBAIJ,
                                        NULL,
+                                       /*139*/ NULL,
                                        NULL,
                                        NULL,
-                                       /*155*/ NULL,
-                                       MatCopyHashToXAIJ_Seq_Hash};
+                                       MatCopyHashToXAIJ_Seq_Hash,
+                                       NULL};
 
 static PetscErrorCode MatStoreValues_SeqSBAIJ(Mat mat)
 {
@@ -1456,7 +1443,7 @@ static PetscErrorCode MatSeqSBAIJSetPreallocation_SeqSBAIJ(Mat B, PetscInt bs, P
   }
   if (nz >= 0 || nnz) realalloc = PETSC_TRUE;
 
-  PetscCall(MatSetBlockSize(B, PetscAbs(bs)));
+  PetscCall(MatSetBlockSize(B, bs));
   PetscCall(PetscLayoutSetUp(B->rmap));
   PetscCall(PetscLayoutSetUp(B->cmap));
   PetscCheck(B->rmap->N <= B->cmap->N, PETSC_COMM_SELF, PETSC_ERR_SUP, "SEQSBAIJ matrix cannot have more rows %" PetscInt_FMT " than columns %" PetscInt_FMT, B->rmap->N, B->cmap->N);
@@ -1755,15 +1742,14 @@ PETSC_INTERN PetscErrorCode MatGetFactor_seqsbaij_petsc(Mat A, MatFactorType fty
 
   PetscCall(MatCreate(PetscObjectComm((PetscObject)A), B));
   PetscCall(MatSetSizes(*B, n, n, n, n));
-  if (ftype == MAT_FACTOR_CHOLESKY || ftype == MAT_FACTOR_ICC) {
-    PetscCall(MatSetType(*B, MATSEQSBAIJ));
-    PetscCall(MatSeqSBAIJSetPreallocation(*B, A->rmap->bs, MAT_SKIP_ALLOCATION, NULL));
+  PetscCheck(ftype == MAT_FACTOR_CHOLESKY || ftype == MAT_FACTOR_ICC, PETSC_COMM_SELF, PETSC_ERR_SUP, "Factor type not supported");
+  PetscCall(MatSetType(*B, MATSEQSBAIJ));
+  PetscCall(MatSeqSBAIJSetPreallocation(*B, A->rmap->bs, MAT_SKIP_ALLOCATION, NULL));
 
-    (*B)->ops->choleskyfactorsymbolic = MatCholeskyFactorSymbolic_SeqSBAIJ;
-    (*B)->ops->iccfactorsymbolic      = MatICCFactorSymbolic_SeqSBAIJ;
-    PetscCall(PetscStrallocpy(MATORDERINGNATURAL, (char **)&(*B)->preferredordering[MAT_FACTOR_CHOLESKY]));
-    PetscCall(PetscStrallocpy(MATORDERINGNATURAL, (char **)&(*B)->preferredordering[MAT_FACTOR_ICC]));
-  } else SETERRQ(PETSC_COMM_SELF, PETSC_ERR_SUP, "Factor type not supported");
+  (*B)->ops->choleskyfactorsymbolic = MatCholeskyFactorSymbolic_SeqSBAIJ;
+  (*B)->ops->iccfactorsymbolic      = MatICCFactorSymbolic_SeqSBAIJ;
+  PetscCall(PetscStrallocpy(MATORDERINGNATURAL, (char **)&(*B)->preferredordering[MAT_FACTOR_CHOLESKY]));
+  PetscCall(PetscStrallocpy(MATORDERINGNATURAL, (char **)&(*B)->preferredordering[MAT_FACTOR_ICC]));
 
   (*B)->factortype     = ftype;
   (*B)->canuseordering = PETSC_TRUE;
@@ -1915,7 +1901,7 @@ PETSC_EXTERN PetscErrorCode MatCreate_SeqSBAIJ(Mat B)
   if (no_unroll) PetscCall(PetscInfo(B, "Not using Inode routines due to -mat_no_unroll\n"));
   PetscCall(PetscOptionsBool("-mat_no_inode", "Do not optimize for inodes (slower)", NULL, no_inode, &no_inode, NULL));
   if (no_inode) PetscCall(PetscInfo(B, "Not using Inode routines due to -mat_no_inode\n"));
-  PetscCall(PetscOptionsInt("-mat_inode_limit", "Do not use inodes larger then this value", NULL, b->inode.limit, &b->inode.limit, NULL));
+  PetscCall(PetscOptionsInt("-mat_inode_limit", "Do not use inodes larger than this value", NULL, b->inode.limit, &b->inode.limit, NULL));
   PetscOptionsEnd();
   b->inode.use = (PetscBool)(!(no_unroll || no_inode));
   if (b->inode.limit > b->inode.max_limit) b->inode.limit = b->inode.max_limit;
