@@ -77,7 +77,7 @@ int main(int argc, char **args)
   PetscBool    testaxpy = PETSC_TRUE, testaxpyd = PETSC_TRUE, testaxpyerr = PETSC_FALSE;
 
   PetscFunctionBeginUser;
-  PetscCall(PetscInitialize(&argc, &args, (char *)0, help));
+  PetscCall(PetscInitialize(&argc, &args, NULL, help));
   PetscCallMPI(MPI_Comm_rank(PETSC_COMM_WORLD, &rank));
   PetscCallMPI(MPI_Comm_size(PETSC_COMM_WORLD, &size));
   PetscCall(PetscOptionsGetInt(NULL, NULL, "-M", &M, NULL));
@@ -436,14 +436,14 @@ int main(int argc, char **args)
    testset:
      suffix: rect
      requires: !single
-     output_file: output/ex221_1.out
+     output_file: output/empty.out
      nsize: {{1 3}}
      args: -loop 3 -keep {{0 1}} -M {{12 19}} -N {{19 12}} -submat {{0 1}} -test_axpy_different {{0 1}}
 
    testset:
      suffix: square
      requires: !single
-     output_file: output/ex221_1.out
+     output_file: output/empty.out
      nsize: {{1 3}}
      args: -M 21 -N 21 -loop 4 -rows_only {{0 1}} -keep {{0 1}} -submat {{0 1}} -test_axpy_different {{0 1}}
 TEST*/
