@@ -25,11 +25,11 @@ static PetscErrorCode SNESSetFromOptions_NRichardson(SNES snes, PetscOptionItems
 
 static PetscErrorCode SNESView_NRichardson(SNES snes, PetscViewer viewer)
 {
-  PetscBool iascii;
+  PetscBool isascii;
 
   PetscFunctionBegin;
-  PetscCall(PetscObjectTypeCompare((PetscObject)viewer, PETSCVIEWERASCII, &iascii));
-  if (iascii) { }
+  PetscCall(PetscObjectTypeCompare((PetscObject)viewer, PETSCVIEWERASCII, &isascii));
+  if (isascii) { }
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
@@ -65,9 +65,8 @@ static PetscErrorCode SNESSolve_NRichardson(SNES snes)
     }
     PetscCall(VecNorm(F, NORM_2, &fnorm));
   } else {
-    if (!snes->vec_func_init_set) {
-      PetscCall(SNESComputeFunction(snes, X, F));
-    } else snes->vec_func_init_set = PETSC_FALSE;
+    if (!snes->vec_func_init_set) PetscCall(SNESComputeFunction(snes, X, F));
+    else snes->vec_func_init_set = PETSC_FALSE;
 
     PetscCall(VecNorm(F, NORM_2, &fnorm));
     SNESCheckFunctionNorm(snes, fnorm);
@@ -170,7 +169,7 @@ static PetscErrorCode SNESSolve_NRichardson(SNES snes)
    The update, especially without inner nonlinear preconditioner, may be ill-scaled.  If using the basic
    linesearch, one may have to scale the update with `-snes_linesearch_damping`
 
-   This uses no derivative information provided with `SNESSetJacobian()` thus it will be much slower then Newton's method obtained with `-snes_type ls`
+   This uses no derivative information provided with `SNESSetJacobian()` thus it will be much slower than Newton's method obtained with `-snes_type ls`
 
    Only supports left non-linear preconditioning.
 
@@ -195,7 +194,7 @@ PETSC_EXTERN PetscErrorCode SNESCreate_NRichardson(SNES snes)
   snes->npcside = PC_LEFT;
 
   PetscCall(SNESGetLineSearch(snes, &linesearch));
-  if (!((PetscObject)linesearch)->type_name) PetscCall(SNESLineSearchSetType(linesearch, SNESLINESEARCHL2));
+  if (!((PetscObject)linesearch)->type_name) PetscCall(SNESLineSearchSetType(linesearch, SNESLINESEARCHSECANT));
 
   snes->alwayscomputesfinalresidual = PETSC_TRUE;
 
