@@ -1,4 +1,3 @@
-
 #include <petsc/private/snesimpl.h> /*I  "petscsnes.h"   I*/
 /* matimpl.h is needed only for logging of matrix operation */
 #include <petsc/private/matimpl.h>
@@ -25,7 +24,7 @@ typedef struct {                 /* default context for matrix-free SNES */
   void        *data;             /* implementation-specific data */
 } MFCtx_Private;
 
-PetscErrorCode SNESMatrixFreeDestroy2_Private(Mat mat)
+static PetscErrorCode SNESMatrixFreeDestroy2_Private(Mat mat)
 {
   MFCtx_Private *ctx;
 
@@ -41,15 +40,15 @@ PetscErrorCode SNESMatrixFreeDestroy2_Private(Mat mat)
 /*
    SNESMatrixFreeView2_Private - Views matrix-free parameters.
  */
-PetscErrorCode SNESMatrixFreeView2_Private(Mat J, PetscViewer viewer)
+static PetscErrorCode SNESMatrixFreeView2_Private(Mat J, PetscViewer viewer)
 {
   MFCtx_Private *ctx;
-  PetscBool      iascii;
+  PetscBool      isascii;
 
   PetscFunctionBegin;
   PetscCall(MatShellGetContext(J, &ctx));
-  PetscCall(PetscObjectTypeCompare((PetscObject)viewer, PETSCVIEWERASCII, &iascii));
-  if (iascii) {
+  PetscCall(PetscObjectTypeCompare((PetscObject)viewer, PETSCVIEWERASCII, &isascii));
+  if (isascii) {
     PetscCall(PetscViewerASCIIPrintf(viewer, "  SNES matrix-free approximation:\n"));
     if (ctx->jorge) PetscCall(PetscViewerASCIIPrintf(viewer, "    using Jorge's method of determining differencing parameter\n"));
     PetscCall(PetscViewerASCIIPrintf(viewer, "    err=%g (relative error in function evaluation)\n", (double)ctx->error_rel));
@@ -67,7 +66,7 @@ PetscErrorCode SNESMatrixFreeView2_Private(Mat J, PetscViewer viewer)
         u = current iterate
         h = difference interval
 */
-PetscErrorCode SNESMatrixFreeMult2_Private(Mat mat, Vec a, Vec y)
+static PetscErrorCode SNESMatrixFreeMult2_Private(Mat mat, Vec a, Vec y)
 {
   MFCtx_Private *ctx;
   SNES           snes;
@@ -105,7 +104,7 @@ PetscErrorCode SNESMatrixFreeMult2_Private(Mat mat, Vec a, Vec y)
     } else {
       /* Compute error if desired */
       PetscCall(SNESGetIterationNumber(snes, &iter));
-      if ((ctx->need_err) || ((ctx->compute_err_freq) && (ctx->compute_err_iter != iter) && (!((iter - 1) % ctx->compute_err_freq)))) {
+      if (ctx->need_err || (ctx->compute_err_freq && (ctx->compute_err_iter != iter) && (!((iter - 1) % ctx->compute_err_freq)))) {
         /* Use Jorge's method to compute noise */
         PetscCall(SNESDiffParameterCompute_More(snes, ctx->data, U, a, &noise, &h));
 
@@ -148,53 +147,53 @@ PetscErrorCode SNESMatrixFreeMult2_Private(Mat mat, Vec a, Vec y)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*@C
-   MatCreateSNESMFMore - Creates a matrix-free matrix
-   context for use with a `SNES` solver that uses the More method to compute an optimal h based on the noise of the function.  This matrix can be used as
-   the Jacobian argument for the routine `SNESSetJacobian()`.
+/*@
+  MatCreateSNESMFMore - Creates a matrix-free matrix
+  context for use with a `SNES` solver that uses the More method to compute an optimal h based on the noise of the function.  This matrix can be used as
+  the Jacobian argument for the routine `SNESSetJacobian()`.
 
-   Input Parameters:
-+  snes - the `SNES` context
--  x - vector where `SNES` solution is to be stored.
+  Input Parameters:
++ snes - the `SNES` context
+- x    - vector where `SNES` solution is to be stored.
 
-   Output Parameter:
-.  J - the matrix-free matrix
+  Output Parameter:
+. J - the matrix-free matrix
 
-   Options Database Keys:
-+  -snes_mf_err <error_rel> - see `MatCreateSNESMF()`
-.  -snes_mf_umin <umin> - see `MatCreateSNESMF()`
-.  -snes_mf_compute_err - compute the square root or relative error in function
-.  -snes_mf_freq_err <freq> - set the frequency to recompute the parameters
--  -snes_mf_jorge - use the method of Jorge More
+  Options Database Keys:
++ -snes_mf_err <error_rel> - see `MatCreateSNESMF()`
+. -snes_mf_umin <umin>     - see `MatCreateSNESMF()`
+. -snes_mf_compute_err     - compute the square root or relative error in function
+. -snes_mf_freq_err <freq> - set the frequency to recompute the parameters
+- -snes_mf_jorge           - use the method of Jorge More
 
-   Level: advanced
+  Level: advanced
 
-   Notes:
-   This is an experimental approach, use `MatCreateSNESMF()`.
+  Notes:
+  This is an experimental approach, use `MatCreateSNESMF()`.
 
-   The matrix-free matrix context merely contains the function pointers
-   and work space for performing finite difference approximations of
-   Jacobian-vector products, J(u)*a, via
+  The matrix-free matrix context merely contains the function pointers
+  and work space for performing finite difference approximations of
+  Jacobian-vector products, J(u)*a, via
 
-$       J(u)*a = [J(u+h*a) - J(u)]/h,
-$   where by default
-$        h = error_rel*u'a/||a||^2                        if  |u'a| > umin*||a||_{1}
-$          = error_rel*umin*sign(u'a)*||a||_{1}/||a||^2   otherwise
-$   where
-$        error_rel = square root of relative error in
-$                    function evaluation
-$        umin = minimum iterate parameter
-$   Alternatively, the differencing parameter, h, can be set using
-$   Jorge's nifty new strategy if one specifies the option
-$          -snes_mf_jorge
+.vb
+       J(u)*a = [J(u+h*a) - J(u)]/h,
+   where by default
+        h = error_rel*u'a/||a||^2                        if  |u'a| > umin*||a||_{1}
+          = error_rel*umin*sign(u'a)*||a||_{1}/||a||^2   otherwise
+   where
+        error_rel = square root of relative error in function evaluation
+        umin = minimum iterate parameter
+   Alternatively, the differencing parameter, h, can be set using
+   Jorge's nifty new strategy if one specifies the option
+          -snes_mf_jorge
+.ve
 
-   The user can set these parameters via `MatMFFDSetFunctionError()`.
-   See Users-Manual: ch_snes for details
+  The user can set these parameters via `MatMFFDSetFunctionError()`.
 
-   The user should call `MatDestroy()` when finished with the matrix-free
-   matrix context.
+  The user should call `MatDestroy()` when finished with the matrix-free
+  matrix context.
 
-.seealso: `SNESCreateMF()`, `MatCreateMFFD()`, `MatDestroy()`, `MatMFFDSetFunctionError()`
+.seealso: [](ch_snes), `SNESCreateMF()`, `MatCreateMFFD()`, `MatDestroy()`, `MatMFFDSetFunctionError()`
 @*/
 PetscErrorCode MatCreateSNESMFMore(SNES snes, Vec x, Mat *J)
 {
@@ -229,9 +228,8 @@ PetscErrorCode MatCreateSNESMFMore(SNES snes, Vec x, Mat *J)
     mfctx->compute_err = PETSC_TRUE;
   }
   if (mfctx->compute_err) mfctx->need_err = PETSC_TRUE;
-  if (mfctx->jorge || mfctx->compute_err) {
-    PetscCall(SNESDiffParameterCreate_More(snes, x, &mfctx->data));
-  } else mfctx->data = NULL;
+  if (mfctx->jorge || mfctx->compute_err) PetscCall(SNESDiffParameterCreate_More(snes, x, &mfctx->data));
+  else mfctx->data = NULL;
 
   PetscCall(PetscOptionsHasHelp(((PetscObject)snes)->options, &flg));
   PetscCall(PetscStrncpy(p, "-", sizeof(p)));
@@ -257,34 +255,33 @@ PetscErrorCode MatCreateSNESMFMore(SNES snes, Vec x, Mat *J)
   PetscCall(MatShellSetOperation(*J, MATOP_DESTROY, (void (*)(void))SNESMatrixFreeDestroy2_Private));
   PetscCall(MatShellSetOperation(*J, MATOP_VIEW, (void (*)(void))SNESMatrixFreeView2_Private));
   PetscCall(MatSetUp(*J));
-
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*@C
-   MatSNESMFMoreSetParameters - Sets the parameters for the approximation of
-   matrix-vector products using finite differences, see  `MatCreateSNESMFMore()`
+/*@
+  MatSNESMFMoreSetParameters - Sets the parameters for the approximation of
+  matrix-vector products using finite differences, see  `MatCreateSNESMFMore()`
 
-   Input Parameters:
-+  mat - the matrix
-.  error_rel - relative error (should be set to the square root of the relative error in the function evaluations)
-.  umin - minimum allowable u-value
--  h - differencing parameter
+  Input Parameters:
++ mat   - the matrix
+. error - relative error (should be set to the square root of the relative error in the function evaluations)
+. umin  - minimum allowable u-value
+- h     - differencing parameter
 
-   Options Database Keys:
-+  -snes_mf_err <error_rel> - see `MatCreateSNESMF()`
-.  -snes_mf_umin <umin> - see `MatCreateSNESMF()`
-.  -snes_mf_compute_err - compute the square root or relative error in function
-.  -snes_mf_freq_err <freq> - set the frequency to recompute the parameters
--  -snes_mf_jorge - use the method of Jorge More
+  Options Database Keys:
++ -snes_mf_err <error_rel> - see `MatCreateSNESMF()`
+. -snes_mf_umin <umin>     - see `MatCreateSNESMF()`
+. -snes_mf_compute_err     - compute the square root or relative error in function
+. -snes_mf_freq_err <freq> - set the frequency to recompute the parameters
+- -snes_mf_jorge           - use the method of Jorge More
 
-   Level: advanced
+  Level: advanced
 
-   Note:
-   If the user sets the parameter h directly, then this value will be used
-   instead of the default computation as discussed in `MatCreateSNESMFMore()`
+  Note:
+  If the user sets the parameter `h` directly, then this value will be used
+  instead of the default computation as discussed in `MatCreateSNESMFMore()`
 
-.seealso: `MatCreateSNESMF()`, `MatCreateSNESMFMore()`
+.seealso: [](ch_snes), `SNES`, `MatCreateSNESMF()`, `MatCreateSNESMFMore()`
 @*/
 PetscErrorCode MatSNESMFMoreSetParameters(Mat mat, PetscReal error, PetscReal umin, PetscReal h)
 {
