@@ -1,4 +1,3 @@
-
 /*
       Code for opening and closing files.
 */
@@ -24,42 +23,42 @@
 /*
    Private routine to delete tmp/shared storage
 
-   This is called by MPI, not by users.
-
-   Note: this is declared extern "C" because it is passed to MPI_Comm_create_keyval()
+   This is called by MPI, not by users, when communicator attributes are deleted
 
 */
-PETSC_EXTERN PetscMPIInt MPIAPI Petsc_DelTmpShared(MPI_Comm comm, PetscMPIInt keyval, void *count_val, void *extra_state)
+static PetscMPIInt MPIAPI Petsc_DelTmpShared(MPI_Comm comm, PetscMPIInt keyval, void *count_val, void *extra_state)
 {
   PetscFunctionBegin;
-  PetscCallMPI(PetscInfo(NULL, "Deleting tmp/shared data in an MPI_Comm %ld\n", (long)comm));
-  PetscCallMPI(PetscFree(count_val));
+  PetscCallReturnMPI(PetscInfo(NULL, "Deleting tmp/shared data in an MPI_Comm %ld\n", (long)comm));
+  PetscCallReturnMPI(PetscFree(count_val));
   PetscFunctionReturn(MPI_SUCCESS);
 }
 
+// "Unknown section 'Environmental Variables'"
+// PetscClangLinter pragma disable: -fdoc-section-header-unknown
 /*@C
-   PetscGetTmp - Gets the name of the tmp directory
+  PetscGetTmp - Gets the name of the "tmp" directory, often this is `/tmp`
 
-   Collective
+  Collective
 
-   Input Parameters:
-+  comm - MPI_Communicator that may share /tmp
--  len - length of string to hold name
+  Input Parameters:
++ comm - MPI_Communicator that may share tmp
+- len  - length of string to hold name
 
-   Output Parameter:
-.  dir - directory name
+  Output Parameter:
+. dir - directory name
 
-   Options Database Keys:
-+    -shared_tmp  - indicates the directory is shared among the MPI ranks
-.    -not_shared_tmp - indicates the directory is not shared among the MPI ranks
--    -tmp tmpdir - name of the directory you wish to use as /tmp
+  Options Database Keys:
++ -shared_tmp     - indicates the directory is known to be shared among the MPI processes
+. -not_shared_tmp - indicates the directory is known to be not shared among the MPI processes
+- -tmp tmpdir     - name of the directory you wish to use as tmp
 
-   Environmental Variables:
-+     `PETSC_SHARED_TMP` - indicates the directory is shared among the MPI ranks
-.     `PETSC_NOT_SHARED_TMP` - indicates the directory is not shared among the MPI ranks
--     `PETSC_TMP` - name of the directory you wish to use as /tmp
+  Environmental Variables:
++ `PETSC_SHARED_TMP`     - indicates the directory is known to be shared among the MPI processes
+. `PETSC_NOT_SHARED_TMP` - indicates the directory is known to be not shared among the MPI processes
+- `PETSC_TMP`            - name of the directory you wish to use as tmp
 
-   Level: developer
+  Level: developer
 
 .seealso: `PetscSharedTmp()`, `PetscSharedWorkingDirectory()`, `PetscGetWorkingDirectory()`, `PetscGetHomeDirectory()`
 @*/
@@ -73,52 +72,55 @@ PetscErrorCode PetscGetTmp(MPI_Comm comm, char dir[], size_t len)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*@C
-   PetscSharedTmp - Determines if all processors in a communicator share a
-         /tmp or have different ones.
+// "Unknown section 'Environmental Variables'"
+// PetscClangLinter pragma disable: -fdoc-section-header-unknown
+/*@
+  PetscSharedTmp - Determines if all processors in a communicator share a
+  tmp directory or have different ones.
 
-   Collective
+  Collective
 
-   Input Parameter:
-.  comm - MPI_Communicator that may share /tmp
+  Input Parameter:
+. comm - MPI_Communicator that may share tmp
 
-   Output Parameter:
-.  shared - `PETSC_TRUE` or `PETSC_FALSE`
+  Output Parameter:
+. shared - `PETSC_TRUE` or `PETSC_FALSE`
 
-   Options Database Keys:
-+    -shared_tmp  - indicates the directory is shared among the MPI ranks
-.    -not_shared_tmp - indicates the directory is not shared among the MPI ranks
--    -tmp tmpdir - name of the directory you wish to use as /tmp
+  Options Database Keys:
++ -shared_tmp     - indicates the directory is known to be shared among the MPI processes
+. -not_shared_tmp - indicates the directory is known to be not shared among the MPI processes
+- -tmp tmpdir     - name of the directory you wish to use as tmp
 
-   Environmental Variables:
-+     `PETSC_SHARED_TMP`  - indicates the directory is shared among the MPI ranks
-.     `PETSC_NOT_SHARED_TMP` - indicates the directory is not shared among the MPI ranks
--     `PETSC_TMP` - name of the directory you wish to use as /tmp
+  Environmental Variables:
++ `PETSC_SHARED_TMP`     - indicates the directory is known to be shared among the MPI processes
+. `PETSC_NOT_SHARED_TMP` - indicates the directory is known to be not shared among the MPI processes
+- `PETSC_TMP`            - name of the directory you wish to use as tmp
 
-   Level: developer
+  Level: developer
 
-   Notes:
-   Stores the status as a MPI attribute so it does not have
-    to be redetermined each time.
+  Notes:
+  Stores the status as a MPI attribute so it does not have
+  to be redetermined each time.
 
-      Assumes that all processors in a communicator either
-       1) have a common /tmp or
-       2) each has a separate /tmp
-      eventually we can write a fancier one that determines which processors
-      share a common /tmp.
+  Assumes that all processors in a communicator either
+  1) have a common tmp or
+  2) each has a separate tmp
+  eventually we can write a fancier one that determines which processors
+  share a common tmp.
 
-   This will be very slow on runs with a large number of processors since
-   it requires O(p*p) file opens.
+  This will be very slow on runs with a large number of processors since
+  it requires O(p*p) file opens.
 
-   If the environmental variable `PETSC_TMP` is set it will use this directory
-  as the "/tmp" directory.
+  If the environmental variable `PETSC_TMP` is set it will use this directory
+  as the "tmp" directory.
 
 .seealso: `PetscGetTmp()`, `PetscSharedWorkingDirectory()`, `PetscGetWorkingDirectory()`, `PetscGetHomeDirectory()`
 @*/
 PetscErrorCode PetscSharedTmp(MPI_Comm comm, PetscBool *shared)
 {
   PetscMPIInt size, rank, *tagvalp, sum, cnt, i;
-  PetscBool   flg, iflg;
+  PetscBool   flg;
+  PetscMPIInt iflg;
   FILE       *fd;
   int         err;
 
@@ -143,7 +145,7 @@ PetscErrorCode PetscSharedTmp(MPI_Comm comm, PetscBool *shared)
 
   if (Petsc_SharedTmp_keyval == MPI_KEYVAL_INVALID) PetscCallMPI(MPI_Comm_create_keyval(MPI_COMM_NULL_COPY_FN, Petsc_DelTmpShared, &Petsc_SharedTmp_keyval, NULL));
 
-  PetscCallMPI(MPI_Comm_get_attr(comm, Petsc_SharedTmp_keyval, (void **)&tagvalp, (int *)&iflg));
+  PetscCallMPI(MPI_Comm_get_attr(comm, Petsc_SharedTmp_keyval, (void **)&tagvalp, &iflg));
   if (!iflg) {
     char filename[PETSC_MAX_PATH_LEN], tmpname[PETSC_MAX_PATH_LEN];
 
@@ -151,8 +153,8 @@ PetscErrorCode PetscSharedTmp(MPI_Comm comm, PetscBool *shared)
     PetscCall(PetscMalloc1(1, &tagvalp));
     PetscCallMPI(MPI_Comm_set_attr(comm, Petsc_SharedTmp_keyval, tagvalp));
 
-    PetscCall(PetscOptionsGetenv(comm, "PETSC_TMP", tmpname, 238, &iflg));
-    if (!iflg) {
+    PetscCall(PetscOptionsGetenv(comm, "PETSC_TMP", tmpname, 238, &flg));
+    if (!flg) {
       PetscCall(PetscStrncpy(filename, "/tmp", sizeof(filename)));
     } else {
       PetscCall(PetscStrncpy(filename, tmpname, sizeof(filename)));
@@ -182,7 +184,7 @@ PetscErrorCode PetscSharedTmp(MPI_Comm comm, PetscBool *shared)
         }
       } else cnt = 0;
 
-      PetscCall(MPIU_Allreduce(&cnt, &sum, 1, MPI_INT, MPI_SUM, comm));
+      PetscCallMPI(MPIU_Allreduce(&cnt, &sum, 1, MPI_INT, MPI_SUM, comm));
       if (rank == i) unlink(filename);
 
       if (sum == size) {
@@ -191,12 +193,14 @@ PetscErrorCode PetscSharedTmp(MPI_Comm comm, PetscBool *shared)
       } else PetscCheck(sum == 1, PETSC_COMM_SELF, PETSC_ERR_SUP_SYS, "Subset of processes share /tmp ");
     }
     *tagvalp = (int)*shared;
-    PetscCall(PetscInfo(NULL, "processors %s %s\n", (*shared) ? "share" : "do NOT share", (iflg ? tmpname : "/tmp")));
+    PetscCall(PetscInfo(NULL, "processors %s %s\n", *shared ? "share" : "do NOT share", flg ? tmpname : "/tmp"));
   } else *shared = (PetscBool)*tagvalp;
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*@C
+// "Unknown section 'Environmental Variables'"
+// PetscClangLinter pragma disable: -fdoc-section-header-unknown
+/*@
   PetscSharedWorkingDirectory - Determines if all processors in a communicator share a working directory or have different ones.
 
   Collective
@@ -208,12 +212,12 @@ PetscErrorCode PetscSharedTmp(MPI_Comm comm, PetscBool *shared)
 . shared - `PETSC_TRUE` or `PETSC_FALSE`
 
   Options Database Keys:
-+ -shared_working_directory - indicates the directory is shared among the MPI ranks
-- -not_shared_working_directory - indicates the directory is shared among the MPI ranks
++ -shared_working_directory     - indicates the directory is known to be shared among the MPI processes
+- -not_shared_working_directory - indicates the directory is known to be not shared among the MPI processes
 
   Environmental Variables:
-+ `PETSC_SHARED_WORKING_DIRECTORY` - indicates the directory is shared among the MPI ranks
-- `PETSC_NOT_SHARED_WORKING_DIRECTORY` - indicates the directory is shared among the MPI ranks
++ `PETSC_SHARED_WORKING_DIRECTORY`     - indicates the directory is known to be shared among the MPI processes
+- `PETSC_NOT_SHARED_WORKING_DIRECTORY` - indicates the directory is known to be not shared among the MPI processes
 
   Level: developer
 
@@ -234,7 +238,8 @@ PetscErrorCode PetscSharedTmp(MPI_Comm comm, PetscBool *shared)
 PetscErrorCode PetscSharedWorkingDirectory(MPI_Comm comm, PetscBool *shared)
 {
   PetscMPIInt size, rank, *tagvalp, sum, cnt, i;
-  PetscBool   flg, iflg;
+  PetscBool   flg;
+  PetscMPIInt iflg;
   FILE       *fd;
   int         err;
 
@@ -259,7 +264,7 @@ PetscErrorCode PetscSharedWorkingDirectory(MPI_Comm comm, PetscBool *shared)
 
   if (Petsc_SharedWD_keyval == MPI_KEYVAL_INVALID) PetscCallMPI(MPI_Comm_create_keyval(MPI_COMM_NULL_COPY_FN, Petsc_DelTmpShared, &Petsc_SharedWD_keyval, NULL));
 
-  PetscCallMPI(MPI_Comm_get_attr(comm, Petsc_SharedWD_keyval, (void **)&tagvalp, (int *)&iflg));
+  PetscCallMPI(MPI_Comm_get_attr(comm, Petsc_SharedWD_keyval, (void **)&tagvalp, &iflg));
   if (!iflg) {
     char filename[PETSC_MAX_PATH_LEN];
 
@@ -267,7 +272,7 @@ PetscErrorCode PetscSharedWorkingDirectory(MPI_Comm comm, PetscBool *shared)
     PetscCall(PetscMalloc1(1, &tagvalp));
     PetscCallMPI(MPI_Comm_set_attr(comm, Petsc_SharedWD_keyval, tagvalp));
 
-    PetscCall(PetscGetWorkingDirectory(filename, 240));
+    PetscCall(PetscGetWorkingDirectory(filename, sizeof(filename) - 16));
     PetscCall(PetscStrlcat(filename, "/petsctestshared", sizeof(filename)));
     PetscCallMPI(MPI_Comm_rank(comm, &rank));
 
@@ -292,7 +297,7 @@ PetscErrorCode PetscSharedWorkingDirectory(MPI_Comm comm, PetscBool *shared)
         }
       } else cnt = 0;
 
-      PetscCall(MPIU_Allreduce(&cnt, &sum, 1, MPI_INT, MPI_SUM, comm));
+      PetscCallMPI(MPIU_Allreduce(&cnt, &sum, 1, MPI_INT, MPI_SUM, comm));
       if (rank == i) unlink(filename);
 
       if (sum == size) {
@@ -307,25 +312,26 @@ PetscErrorCode PetscSharedWorkingDirectory(MPI_Comm comm, PetscBool *shared)
 }
 
 /*@C
-    PetscFileRetrieve - Obtains a file from a URL or a compressed file
-        and copies into local disk space as uncompressed.
+  PetscFileRetrieve - Obtains a file from a URL or a compressed file
+  and copies into local disk space as uncompressed.
 
-    Collective
+  Collective
 
-    Input Parameters:
-+   comm     - processors accessing the file
-.   url      - name of file, including entire URL (with or without .gz)
--   llen     - length of localname
+  Input Parameters:
++ comm - processors accessing the file
+. url  - name of file, including entire URL (with or without .gz)
+- llen - length of `localname`
 
-    Output Parameters:
-+   localname - name of local copy of file - valid on only process zero
--   found - if found or retrieved the file - valid on all processes
+  Output Parameters:
++ localname - name of local copy of file - valid on only process zero
+- found     - if found or retrieved the file - valid on all processes
 
-    Level: intermediate
+  Level: developer
 
-    Note:
-    if the file already exists local this function just returns without downloading it.
+  Note:
+  if the file already exists locally this function just returns without downloading it.
 
+.seealso: `PetscDLLibraryRetrieve()`
 @*/
 PetscErrorCode PetscFileRetrieve(MPI_Comm comm, const char url[], char localname[], size_t llen, PetscBool *found)
 {
@@ -440,6 +446,6 @@ PetscErrorCode PetscFileRetrieve(MPI_Comm comm, const char url[], char localname
   }
 done:
   PetscCallMPI(MPI_Bcast(found, 1, MPIU_BOOL, 0, comm));
-  PetscCallMPI(MPI_Bcast(localname, llen, MPI_CHAR, 0, comm));
+  PetscCallMPI(MPI_Bcast(localname, (PetscMPIInt)llen, MPI_CHAR, 0, comm));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
