@@ -103,7 +103,7 @@ int main(int argc, char **argv)
   PetscLogStage stages[1];
 
   PetscFunctionBeginUser;
-  PetscCall(PetscInitialize(&argc, &argv, (char *)0, help));
+  PetscCall(PetscInitialize(&argc, &argv, NULL, help));
   user.mx = 32;
   PetscOptionsBegin(PETSC_COMM_WORLD, NULL, "hyperbolic example", NULL);
   PetscCall(PetscOptionsInt("-mx", "Number of grid points in each direction", "", user.mx, &user.mx, NULL));
@@ -455,9 +455,8 @@ PetscErrorCode StateMatBlockPrecMult(PC PC_shell, Vec X, Vec Y)
   PetscFunctionBegin;
   PetscCall(PCShellGetContext(PC_shell, &user));
   i = user->block_index;
-  if (user->c_formed) {
-    PetscCall(MatSOR(user->C[i], X, 1.0, (MatSORType)(SOR_ZERO_INITIAL_GUESS | SOR_LOCAL_SYMMETRIC_SWEEP), 0.0, 1, 1, Y));
-  } else SETERRQ(PETSC_COMM_SELF, PETSC_ERR_SUP, "Not formed");
+  PetscCheck(user->c_formed, PETSC_COMM_SELF, PETSC_ERR_SUP, "Not formed");
+  PetscCall(MatSOR(user->C[i], X, 1.0, (MatSORType)(SOR_ZERO_INITIAL_GUESS | SOR_LOCAL_SYMMETRIC_SWEEP), 0.0, 1, 1, Y));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
@@ -470,9 +469,8 @@ PetscErrorCode StateMatBlockPrecMultTranspose(PC PC_shell, Vec X, Vec Y)
   PetscCall(PCShellGetContext(PC_shell, &user));
 
   i = user->block_index;
-  if (user->c_formed) {
-    PetscCall(MatSOR(user->C[i], X, 1.0, (MatSORType)(SOR_ZERO_INITIAL_GUESS | SOR_LOCAL_SYMMETRIC_SWEEP), 0.0, 1, 1, Y));
-  } else SETERRQ(PETSC_COMM_SELF, PETSC_ERR_SUP, "Not formed");
+  PetscCheck(user->c_formed, PETSC_COMM_SELF, PETSC_ERR_SUP, "Not formed");
+  PetscCall(MatSOR(user->C[i], X, 1.0, (MatSORType)(SOR_ZERO_INITIAL_GUESS | SOR_LOCAL_SYMMETRIC_SWEEP), 0.0, 1, 1, Y));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
@@ -486,9 +484,9 @@ PetscErrorCode StateMatInvMult(Mat J_shell, Vec X, Vec Y)
 
   if (Y == user->ytrue) {
     /* First solve is done using true solution to set up problem */
-    PetscCall(KSPSetTolerances(user->solver, 1e-4, 1e-20, PETSC_DEFAULT, PETSC_DEFAULT));
+    PetscCall(KSPSetTolerances(user->solver, 1e-4, 1e-20, PETSC_CURRENT, PETSC_CURRENT));
   } else {
-    PetscCall(KSPSetTolerances(user->solver, PETSC_DEFAULT, PETSC_DEFAULT, PETSC_DEFAULT, PETSC_DEFAULT));
+    PetscCall(KSPSetTolerances(user->solver, PETSC_CURRENT, PETSC_CURRENT, PETSC_CURRENT, PETSC_CURRENT));
   }
   PetscCall(Scatter_yi(X, user->yi, user->yi_scatter, user->nt));
   PetscCall(Scatter_yi(Y, user->yiwork, user->yi_scatter, user->nt));
@@ -597,7 +595,6 @@ PetscErrorCode FormConstraints(Tao tao, Vec X, Vec C, void *ptr)
 
   PetscCall(Gather_yi(C, user->yiwork, user->yi_scatter, user->nt));
   PetscCall(VecAXPY(C, -1.0, user->q));
-
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
@@ -1212,11 +1209,11 @@ PetscErrorCode HyperbolicMonitor(Tao tao, void *ptr)
 
    test:
       requires: !single
-      args: -tao_cmonitor -tao_max_funcs 10 -tao_type lcl -tao_gatol 1.e-5
+      args: -tao_monitor_constraint_norm -tao_max_funcs 10 -tao_type lcl -tao_gatol 1.e-5
 
    test:
       suffix: guess_pod
       requires: !single
-      args: -tao_cmonitor -tao_max_funcs 10 -tao_type lcl -ksp_guess_type pod -tao_gatol 1.e-5
+      args: -tao_monitor_constraint_norm -tao_max_funcs 10 -tao_type lcl -ksp_guess_type pod -tao_gatol 1.e-5
 
 TEST*/
