@@ -105,7 +105,7 @@ int main(int argc, char **argv)
   PetscLogStage stages[1];
 
   PetscFunctionBeginUser;
-  PetscCall(PetscInitialize(&argc, &argv, (char *)0, help));
+  PetscCall(PetscInitialize(&argc, &argv, NULL, help));
   user.mx = 8;
   PetscOptionsBegin(PETSC_COMM_WORLD, NULL, "parabolic example", NULL);
   PetscCall(PetscOptionsInt("-mx", "Number of grid points in each direction", "", user.mx, &user.mx, NULL));
@@ -340,7 +340,7 @@ PetscErrorCode FormJacobianState(Tao tao, Vec X, Mat J, Mat JPre, Mat JInv, void
   if (user->dsg_formed) {
     PetscCall(MatProductNumeric(user->DSG));
   } else {
-    PetscCall(MatMatMult(user->Divwork, user->Grad, MAT_INITIAL_MATRIX, PETSC_DEFAULT, &user->DSG));
+    PetscCall(MatMatMult(user->Divwork, user->Grad, MAT_INITIAL_MATRIX, PETSC_DETERMINE, &user->DSG));
     user->dsg_formed = PETSC_TRUE;
   }
 
@@ -445,7 +445,6 @@ PetscErrorCode DesignMatMult(Mat J_shell, Vec X, Vec Y)
     PetscCall(VecScale(user->yiwork[i], user->ht));
   }
   PetscCall(Gather_i(Y, user->yiwork, user->yi_scatter, user->nt));
-
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
@@ -498,9 +497,8 @@ PetscErrorCode StateMatBlockPrecMult(PC PC_shell, Vec X, Vec Y)
   PetscFunctionBegin;
   PetscCall(PCShellGetContext(PC_shell, &user));
 
-  if (user->dsg_formed) {
-    PetscCall(MatSOR(user->DSG, X, 1.0, (MatSORType)(SOR_ZERO_INITIAL_GUESS | SOR_LOCAL_SYMMETRIC_SWEEP), 0.0, 1, 1, Y));
-  } else SETERRQ(PETSC_COMM_SELF, PETSC_ERR_SUP, "DSG not formed");
+  PetscCheck(user->dsg_formed, PETSC_COMM_SELF, PETSC_ERR_SUP, "DSG not formed");
+  PetscCall(MatSOR(user->DSG, X, 1.0, (MatSORType)(SOR_ZERO_INITIAL_GUESS | SOR_LOCAL_SYMMETRIC_SWEEP), 0.0, 1, 1, Y));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
@@ -514,9 +512,9 @@ PetscErrorCode StateMatInvMult(Mat J_shell, Vec X, Vec Y)
 
   if (Y == user->ytrue) {
     /* First solve is done with true solution to set up problem */
-    PetscCall(KSPSetTolerances(user->solver, 1e-8, PETSC_DEFAULT, PETSC_DEFAULT, PETSC_DEFAULT));
+    PetscCall(KSPSetTolerances(user->solver, 1e-8, PETSC_CURRENT, PETSC_CURRENT, PETSC_CURRENT));
   } else {
-    PetscCall(KSPSetTolerances(user->solver, PETSC_DEFAULT, PETSC_DEFAULT, PETSC_DEFAULT, PETSC_DEFAULT));
+    PetscCall(KSPSetTolerances(user->solver, PETSC_CURRENT, PETSC_CURRENT, PETSC_CURRENT, PETSC_CURRENT));
   }
 
   PetscCall(Scatter_i(X, user->yi, user->yi_scatter, user->nt));
@@ -1024,7 +1022,7 @@ PetscErrorCode ParabolicInitialize(AppCtx *user)
   PetscCall(MatProductCreate(user->Div, user->Grad, NULL, &user->DSG));
   PetscCall(MatProductSetType(user->DSG, MATPRODUCT_AB));
   PetscCall(MatProductSetAlgorithm(user->DSG, "default"));
-  PetscCall(MatProductSetFill(user->DSG, PETSC_DEFAULT));
+  PetscCall(MatProductSetFill(user->DSG, PETSC_DETERMINE));
   PetscCall(MatProductSetFromOptions(user->DSG));
   PetscCall(MatProductSymbolic(user->DSG));
 
@@ -1036,7 +1034,7 @@ PetscErrorCode ParabolicInitialize(AppCtx *user)
   if (user->dsg_formed) {
     PetscCall(MatProductNumeric(user->DSG));
   } else {
-    PetscCall(MatMatMult(user->Div, user->Grad, MAT_INITIAL_MATRIX, PETSC_DEFAULT, &user->DSG));
+    PetscCall(MatMatMult(user->Div, user->Grad, MAT_INITIAL_MATRIX, PETSC_DETERMINE, &user->DSG));
     user->dsg_formed = PETSC_TRUE;
   }
   /* B = speye(nx^3) + ht*DSG; */
@@ -1060,7 +1058,7 @@ PetscErrorCode ParabolicInitialize(AppCtx *user)
   if (user->dsg_formed) {
     PetscCall(MatProductNumeric(user->DSG));
   } else {
-    PetscCall(MatMatMult(user->Div, user->Grad, MAT_INITIAL_MATRIX, PETSC_DEFAULT, &user->DSG));
+    PetscCall(MatMatMult(user->Div, user->Grad, MAT_INITIAL_MATRIX, PETSC_DETERMINE, &user->DSG));
 
     user->dsg_formed = PETSC_TRUE;
   }
@@ -1267,7 +1265,7 @@ PetscErrorCode ParabolicMonitor(Tao tao, void *ptr)
       requires: !complex
 
    test:
-      args: -tao_cmonitor -tao_type lcl -ns 1 -tao_gatol 1.e-4 -ksp_max_it 30
+      args: -tao_monitor_constraint_norm -tao_type lcl -ns 1 -tao_gatol 1.e-4 -ksp_max_it 30
       requires: !single
 
 TEST*/
