@@ -48,14 +48,12 @@ static PetscErrorCode TSThetaGetX0AndXdot(TS ts, DM dm, Vec *X0, Vec *Xdot)
 
   PetscFunctionBegin;
   if (X0) {
-    if (dm && dm != ts->dm) {
-      PetscCall(DMGetNamedGlobalVector(dm, "TSTheta_X0", X0));
-    } else *X0 = ts->vec_sol;
+    if (dm && dm != ts->dm) PetscCall(DMGetNamedGlobalVector(dm, "TSTheta_X0", X0));
+    else *X0 = ts->vec_sol;
   }
   if (Xdot) {
-    if (dm && dm != ts->dm) {
-      PetscCall(DMGetNamedGlobalVector(dm, "TSTheta_Xdot", Xdot));
-    } else *Xdot = th->Xdot;
+    if (dm && dm != ts->dm) PetscCall(DMGetNamedGlobalVector(dm, "TSTheta_Xdot", Xdot));
+    else *Xdot = th->Xdot;
   }
   PetscFunctionReturn(PETSC_SUCCESS);
 }
@@ -1102,11 +1100,11 @@ static PetscErrorCode TSSetFromOptions_Theta(TS ts, PetscOptionItems PetscOption
 static PetscErrorCode TSView_Theta(TS ts, PetscViewer viewer)
 {
   TS_Theta *th = (TS_Theta *)ts->data;
-  PetscBool iascii;
+  PetscBool isascii;
 
   PetscFunctionBegin;
-  PetscCall(PetscObjectTypeCompare((PetscObject)viewer, PETSCVIEWERASCII, &iascii));
-  if (iascii) {
+  PetscCall(PetscObjectTypeCompare((PetscObject)viewer, PETSCVIEWERASCII, &isascii));
+  if (isascii) {
     PetscCall(PetscViewerASCIIPrintf(viewer, "  Theta=%g\n", (double)th->Theta));
     PetscCall(PetscViewerASCIIPrintf(viewer, "  Extrapolation=%s\n", th->extrapolate ? "yes" : "no"));
   }
