@@ -82,6 +82,7 @@ PetscErrorCode TSMonitorSetFromOptions(TS ts, const char name[], const char help
     PetscCall(PetscViewerAndFormatCreate(viewer, format, &vf));
     vf->view_interval = 1;
     PetscCall(PetscOptionsGetInt(((PetscObject)ts)->options, ((PetscObject)ts)->prefix, interval_key, &vf->view_interval, NULL));
+
     PetscCall(PetscViewerDestroy(&viewer));
     if (monitorsetup) PetscCall((*monitorsetup)(ts, vf));
     PetscCall(TSMonitorSet(ts, (PetscErrorCode (*)(TS, PetscInt, PetscReal, Vec, void *))monitor, vf, (PetscCtxDestroyFn *)PetscViewerAndFormatDestroy));
@@ -185,21 +186,21 @@ PetscErrorCode TSMonitorCancel(TS ts)
   This is not called directly by users, rather one calls `TSMonitorSet()`, with this function as an argument, to cause the monitor
   to be used during the `TS` integration.
 
-.seealso: [](ch_ts), `TSMonitorSet()`, `TSDMSwarmMonitorMoments()`, `TSMonitorExtreme()`, `TSMonitorDrawSolution()`,
+.seealso: [](ch_ts), `TSMonitorSet()`, `TSDMSwarmMonitorMoments()`, `TSMonitorWallClockTime()`, `TSMonitorExtreme()`, `TSMonitorDrawSolution()`,
           `TSMonitorDrawSolutionPhase()`, `TSMonitorDrawSolutionFunction()`, `TSMonitorDrawError()`, `TSMonitorSolution()`, `TSMonitorSolutionVTK()`,
           `TSMonitorLGSolution()`, `TSMonitorLGError()`, `TSMonitorSPSwarmSolution()`, `TSMonitorError()`, `TSMonitorEnvelope()`
 @*/
 PetscErrorCode TSMonitorDefault(TS ts, PetscInt step, PetscReal ptime, Vec v, PetscViewerAndFormat *vf)
 {
   PetscViewer viewer = vf->viewer;
-  PetscBool   iascii, ibinary;
+  PetscBool   isascii, ibinary;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(viewer, PETSC_VIEWER_CLASSID, 5);
-  PetscCall(PetscObjectTypeCompare((PetscObject)viewer, PETSCVIEWERASCII, &iascii));
+  PetscCall(PetscObjectTypeCompare((PetscObject)viewer, PETSCVIEWERASCII, &isascii));
   PetscCall(PetscObjectTypeCompare((PetscObject)viewer, PETSCVIEWERBINARY, &ibinary));
   PetscCall(PetscViewerPushFormat(viewer, vf->format));
-  if (iascii) {
+  if (isascii) {
     PetscCall(PetscViewerASCIIAddTab(viewer, ((PetscObject)ts)->tablevel));
     if (step == -1) { /* this indicates it is an interpolated solution */
       PetscCall(PetscViewerASCIIPrintf(viewer, "Interpolated solution at time %g between steps %" PetscInt_FMT " and %" PetscInt_FMT "\n", (double)ptime, ts->steps - 1, ts->steps));
@@ -225,6 +226,95 @@ PetscErrorCode TSMonitorDefault(TS ts, PetscInt step, PetscReal ptime, Vec v, Pe
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
+typedef struct {
+  PetscLogDouble time_start;
+  PetscLogDouble time_last;
+  PetscInt       snes_its;
+  PetscInt       ksp_its;
+} *TSMonitorWallClockTimeContext;
+
+/*@C
+  TSMonitorWallClockTimeSetUp - Setup routine passed to `TSMonitorSetFromOptions()` when using `-ts_monitor_wall_clock_time`
+
+  Input Parameters:
++ ts - the `TS` context
+- vf - the viewer and format
+
+  Level: intermediate
+
+  Note:
+  This is not called directly by users, rather one calls `TSMonitorSetFromOptions()`, with `TSMonitorWallClockTime()` and this function as arguments, to cause the monitor
+  to be used during the `TS` integration.
+
+.seealso: [](ch_ts), `TSMonitorSet()`
+@*/
+PetscErrorCode TSMonitorWallClockTimeSetUp(TS ts, PetscViewerAndFormat *vf)
+{
+  TSMonitorWallClockTimeContext speed;
+
+  PetscFunctionBegin;
+  PetscCall(PetscNew(&speed));
+  speed->time_start = PETSC_DECIDE;
+  vf->data_destroy  = PetscCtxDestroyDefault;
+  vf->data          = speed;
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+
+/*@C
+  TSMonitorWallClockTime - Monitor wall-clock time, KSP iterations, and SNES iterations per step.
+
+  Input Parameters:
++ ts    - the `TS` context
+. step  - iteration number (after the final time step the monitor routine may be called with a step of -1, this indicates the solution has been interpolated to this time)
+. ptime - current time
+. v     - current solution
+- vf    - the viewer and format
+
+  Options Database Key:
+. -ts_monitor_wall_clock_time - Monitor wall-clock time, KSP iterations, and SNES iterations per step.
+
+  Level: intermediate
+
+  Note:
+  This is not called directly by users, rather one calls `TSMonitorSetFromOptions()`, with this function and `TSMonitorWallClockTimeSetUp()` as arguments, to cause the monitor
+  to be used during the `TS` integration.
+
+.seealso: [](ch_ts), `TSMonitorSet()`, `TSMonitorDefault()`, `TSMonitorExtreme()`, `TSMonitorDrawSolution()`,
+          `TSMonitorDrawSolutionPhase()`, `TSMonitorDrawSolutionFunction()`, `TSMonitorDrawError()`, `TSMonitorSolution()`, `TSMonitorSolutionVTK()`,
+          `TSMonitorLGSolution()`, `TSMonitorLGError()`, `TSMonitorSPSwarmSolution()`, `TSMonitorError()`, `TSMonitorEnvelope()`, `TSDMSwarmMonitorMoments()`
+@*/
+PetscErrorCode TSMonitorWallClockTime(TS ts, PetscInt step, PetscReal ptime, Vec v, PetscViewerAndFormat *vf)
+{
+  PetscViewer                   viewer = vf->viewer;
+  TSMonitorWallClockTimeContext speed  = (TSMonitorWallClockTimeContext)vf->data;
+  PetscBool                     isascii;
+  PetscLogDouble                now;
+  PetscInt                      snes_its, ksp_its;
+
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(viewer, PETSC_VIEWER_CLASSID, 5);
+  PetscCall(PetscTime(&now));
+  if (speed->time_start == PETSC_DECIDE) {
+    speed->time_start = now;
+    speed->time_last  = now;
+  }
+  PetscCall(TSGetSNESIterations(ts, &snes_its));
+  PetscCall(TSGetKSPIterations(ts, &ksp_its));
+  PetscCall(PetscObjectTypeCompare((PetscObject)viewer, PETSCVIEWERASCII, &isascii));
+  PetscCall(PetscViewerPushFormat(viewer, vf->format));
+  if (isascii) {
+    PetscCall(PetscViewerASCIIAddTab(viewer, ((PetscObject)ts)->tablevel));
+    PetscCall(PetscViewerASCIIPrintf(viewer, "%" PetscInt_FMT " TS dt %g time %g%s elapsed %.6f of %.6f snes %" PetscInt_FMT " ksp %" PetscInt_FMT "\n", step, (double)ts->time_step, (double)ptime, ts->steprollback ? " (r)" : "", now - speed->time_last,
+                                     now - speed->time_start, snes_its - speed->snes_its, ksp_its - speed->ksp_its));
+    PetscCall(PetscViewerASCIISubtractTab(viewer, ((PetscObject)ts)->tablevel));
+  }
+  PetscCall(PetscViewerPopFormat(viewer));
+  speed->time_last = now;
+  speed->snes_its  = snes_its;
+  speed->ksp_its   = ksp_its;
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+
 /*@C
   TSMonitorExtreme - Prints the extreme values of the solution at each timestep
 
@@ -246,14 +336,14 @@ PetscErrorCode TSMonitorDefault(TS ts, PetscInt step, PetscReal ptime, Vec v, Pe
 PetscErrorCode TSMonitorExtreme(TS ts, PetscInt step, PetscReal ptime, Vec v, PetscViewerAndFormat *vf)
 {
   PetscViewer viewer = vf->viewer;
-  PetscBool   iascii;
+  PetscBool   isascii;
   PetscReal   max, min;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(viewer, PETSC_VIEWER_CLASSID, 5);
-  PetscCall(PetscObjectTypeCompare((PetscObject)viewer, PETSCVIEWERASCII, &iascii));
+  PetscCall(PetscObjectTypeCompare((PetscObject)viewer, PETSCVIEWERASCII, &isascii));
   PetscCall(PetscViewerPushFormat(viewer, vf->format));
-  if (iascii) {
+  if (isascii) {
     PetscCall(VecMax(v, NULL, &max));
     PetscCall(VecMin(v, NULL, &min));
     PetscCall(PetscViewerASCIIAddTab(viewer, ((PetscObject)ts)->tablevel));
@@ -737,6 +827,31 @@ PetscErrorCode TSMonitorDrawError(TS ts, PetscInt step, PetscReal ptime, Vec u,
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
+/*@C
+  TSMonitorSolutionSetup - Setups the context for `TSMonitorSolution()`
+
+  Collective
+
+  Input Parameters:
++ ts - the `TS` context
+- vf - viewer and its format
+
+  Level: intermediate
+
+.seealso: [](ch_ts), `TS`, `TSMonitorSolution()`, `TSMonitorSet()`, `TSMonitorDefault()`, `VecView()`, `TSMonitorSetFromOptions()`
+@*/
+PetscErrorCode TSMonitorSolutionSetup(TS ts, PetscViewerAndFormat *vf)
+{
+  TSMonitorSolutionCtx ctx;
+
+  PetscFunctionBegin;
+  PetscCall(PetscNew(&ctx));
+  PetscCall(PetscOptionsGetBool(((PetscObject)ts)->options, ((PetscObject)ts)->prefix, "-ts_monitor_solution_skip_initial", &ctx->skip_initial, NULL));
+  vf->data         = ctx;
+  vf->data_destroy = PetscCtxDestroyDefault;
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+
 /*@C
   TSMonitorSolution - Monitors progress of the `TS` solvers by `VecView()` for the solution at each timestep. Normally the viewer is a binary file or a `PetscDraw` object
 
@@ -755,11 +870,14 @@ PetscErrorCode TSMonitorDrawError(TS ts, PetscInt step, PetscReal ptime, Vec u,
   This is not called directly by users, rather one calls `TSMonitorSet()`, with this function as an argument, to cause the monitor
   to be used during the `TS` integration.
 
-.seealso: [](ch_ts), `TS`, `TSMonitorSet()`, `TSMonitorDefault()`, `VecView()`
+.seealso: [](ch_ts), `TS`, `TSMonitorSet()`, `TSMonitorDefault()`, `VecView()`, `TSMonitorSolutionSetup()`,
 @*/
 PetscErrorCode TSMonitorSolution(TS ts, PetscInt step, PetscReal ptime, Vec u, PetscViewerAndFormat *vf)
 {
+  TSMonitorSolutionCtx ctx = (TSMonitorSolutionCtx)vf->data;
+
   PetscFunctionBegin;
+  if (ctx->skip_initial && step == ts->start_step) PetscFunctionReturn(PETSC_SUCCESS);
   if ((vf->view_interval > 0 && !(step % vf->view_interval)) || (vf->view_interval && ts->reason)) {
     PetscCall(PetscViewerPushFormat(vf->viewer, vf->format));
     PetscCall(VecView(u, vf->viewer));
@@ -1286,7 +1404,7 @@ PetscErrorCode TSMonitorLGError(TS ts, PetscInt step, PetscReal ptime, Vec u, vo
   This is not called directly by users, rather one calls `TSMonitorSet()`, with this function as an argument, to cause the monitor
   to be used during the `TS` integration.
 
-.seealso: [](ch_ts), `TS`, `TSMonitoSet()`, `DMSWARM`, `TSMonitorSPCtxCreate()`
+.seealso: [](ch_ts), `TS`, `TSMonitorSet()`, `DMSWARM`, `TSMonitorSPCtxCreate()`
 @*/
 PetscErrorCode TSMonitorSPSwarmSolution(TS ts, PetscInt step, PetscReal ptime, Vec u, void *dctx)
 {
@@ -1379,7 +1497,7 @@ PetscErrorCode TSMonitorSPSwarmSolution(TS ts, PetscInt step, PetscReal ptime, V
   This is not called directly by users, rather one calls `TSMonitorSet()`, with this function as an argument, to cause the monitor
   to be used during the `TS` integration.
 
-.seealso: `TSMonitoSet()`
+.seealso: `TSMonitorSet()`
 @*/
 PetscErrorCode TSMonitorHGSwarmSolution(TS ts, PetscInt step, PetscReal ptime, Vec u, void *dctx)
 {
@@ -1705,7 +1823,8 @@ PetscErrorCode TSMonitorEnvelopeCtxDestroy(TSMonitorEnvelopeCtx *ctx)
 - vf   - not used
 
   Options Database Key:
-. -ts_dmswarm_monitor_moments - Monitor moments of particle distribution
++ -ts_dmswarm_monitor_moments          - Monitor moments of particle distribution
+- -ts_dmswarm_monitor_moments_interval - Interval of timesteps between monitor outputs
 
   Level: intermediate
 
@@ -1729,7 +1848,7 @@ PetscErrorCode TSDMSwarmMonitorMoments(TS ts, PetscInt step, PetscReal t, Vec U,
   (void)t;
   (void)vf;
   PetscCall(TSGetDM(ts, &sw));
-  if (!sw || step % ts->monitorFrequency != 0) PetscFunctionReturn(PETSC_SUCCESS);
+  if (!sw || step % vf->view_interval != 0) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(PetscObjectGetComm((PetscObject)ts, &comm));
   PetscCall(DMGetDimension(sw, &dim));
   PetscCall(VecGetLocalSize(U, &Np));
