@@ -474,7 +474,7 @@ int main(int argc, char **argv)
   PetscCall(TSSetExactFinalTime(ts, TS_EXACTFINALTIME_MATCHSTEP));
   PetscCall(TSSetFromOptions(ts));
   PetscCall(TSSetComputeInitialCondition(ts, SetInitialConditions));
-  PetscCall(TSSetResize(ts, TransferSetUp, TransferVecs, &ctx));
+  PetscCall(TSSetResize(ts, PETSC_FALSE, TransferSetUp, TransferVecs, &ctx));
 
   PetscCall(DMCreateGlobalVector(dm, &u));
   PetscCall(DMTSCheckFromOptions(ts, u));
@@ -669,9 +669,9 @@ int main(int argc, char **argv)
   test:
     # For a nice picture, -bd_dm_refine 2 -dm_refine 1 -dm_view hdf5:${PETSC_DIR}/sol.h5 -ts_monitor_solution hdf5:${PETSC_DIR}/sol.h5::append
     suffix: egads_sphere
-    requires: egads ctetgen
+    requires: egads ctetgen datafilespath
     args: -sol_type quadratic_linear \
-          -dm_plex_boundary_filename ${wPETSC_DIR}/share/petsc/datafiles/meshes/sphere_example.egadslite -dm_plex_boundary_label marker \
+          -dm_plex_boundary_filename ${DATAFILESPATH}/meshes/cad/sphere_example.egadslite -dm_plex_boundary_label marker \
           -temp_petscspace_degree 2 -dmts_check .0001 \
           -ts_type beuler -ts_max_steps 5 -ts_dt 0.1 -snes_error_if_not_converged -pc_type lu
 
@@ -679,5 +679,6 @@ int main(int argc, char **argv)
     suffix: remesh
     requires: triangle mmg
     args: -sol_type quadratic_trig -dm_refine 2 -temp_petscspace_degree 1 -ts_type beuler -ts_dt 0.01 -snes_error_if_not_converged -pc_type lu -grad_petscspace_degree 1 -dm_adaptor mmg -dm_plex_hash_location -remesh_every 5
+    output_file: output/empty.out
 
 TEST*/
