@@ -1222,7 +1222,9 @@ static PetscScalar ScalarReciprocal_Function(PetscScalar x)
 PetscErrorCode VecReciprocalAsync_Private(Vec v, PetscDeviceContext dctx)
 {
   PetscFunctionBegin;
+  PetscCall(PetscLogEventBegin(VEC_Reciprocal, v, NULL, NULL, NULL));
   PetscCall(VecApplyUnary_Private(v, dctx, VecAsyncFnName(Reciprocal), v->ops->reciprocal, ScalarReciprocal_Function));
+  PetscCall(PetscLogEventEnd(VEC_Reciprocal, v, NULL, NULL, NULL));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
@@ -1740,7 +1742,7 @@ PetscErrorCode VecEqual(Vec vec1, Vec vec2, PetscBool *flg)
       }
     }
     /* combine results from all processors */
-    PetscCallMPI(MPIU_Allreduce(&flg1, flg, 1, MPIU_BOOL, MPI_MIN, PetscObjectComm((PetscObject)vec1)));
+    PetscCallMPI(MPIU_Allreduce(&flg1, flg, 1, MPIU_BOOL, MPI_LAND, PetscObjectComm((PetscObject)vec1)));
   }
   PetscFunctionReturn(PETSC_SUCCESS);
 }
